/* Analysis 0: Test of Balance */
/* Last Modified 31 Dec 2009 */

clear
set more off
set mem 256m

version 10

set sortseed 10000

capture log close
log using "$output\Coding_files_output\analysis0.log",replace


/* CREATE LOG NUMBER OF HH IN RT FROM SURVEY METER LISTING FORM */

use "$codeddata/intermediate_data/coding_treatment.dta", clear
gen LOGNUMBERHH = log(numhhsls_dec)
gen COMMUNITY = (maintreatment==2)
gen HYBRID = (maintreatment==3)
tempfile a
save `a',replace 

/* MERGE WITH SUSETI DATA */

use "$codeddata\intermediate_data\hhhead.dta", clear
mmerge hhid using "$codeddata\coding_suseti_pmt"
recode  EDUCATIONHHHEAD (95 98=.)

collapse(mean) CONSUMPTION EDUCATIONHHHEAD PMTSCORE SHAREAGRICULTURALHH, by( hhea)

mmerge hhea using "$codeddata\intermediate_data\rthead"

destring hhea, replace
mmerge hhea using `a'
drop _m

/* MERGE WITH PODES08 */
mmerge prop kab kec desa using "$codeddata\intermediate_data\coding_podes08.dta"

keep if _m==3
drop _m

keep hhea main CONSUMPTION PMTSCORE EDUCATIONHHHEAD SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH COMMUNITY HYBRID kecagroup DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH
sum

compress
sort hhea

save "$codeddata\intermediate_data\analysis0.dta", replace


/***************************************************

use "$codeddata\intermediate_data\analysis0.dta", clear


//Generate variables for stacked regression for 10 outcomes

expand 10

//Labeling each observation so that each is used only for one category in the stacked regression

bys hhea: egen subsample = seq()

sort hhea
gen indic_1 = 0
replace indic_1 = 1 if subsample ==1
gen outcome = CONSUMPTION if indic_1 == 1

gen indic_2 = 0
replace indic_2 = 1 if subsample ==2
replace outcome =  EDUCATIONHHHEAD if indic_2 == 1

gen indic_3 = 0
replace indic_3 = 1 if subsample ==3
replace outcome = PMTSCORE if indic_3 == 1

gen indic_4 = 0
replace indic_4 = 1 if subsample ==4
replace outcome =  SHAREAGRICULTURALHH if indic_4 == 1

gen indic_5 = 0
replace indic_5 = 1 if subsample ==5
replace outcome = EDUCATIONRTHEAD if indic_5 == 1

gen indic_6 = 0
replace indic_6 = 1 if subsample ==6
replace outcome = LOGNUMBERHH if indic_6 == 1

gen indic_7 = 0
replace indic_7 = 1 if subsample ==7
replace outcome = DISTANCEKEC if indic_7 == 1

gen indic_8 = 0
replace indic_8 = 1 if subsample ==8
replace outcome = LOGVILLAGESIZE if indic_8 == 1

gen indic_9 = 0
replace indic_9 = 1 if subsample ==9
replace outcome = RELIGIOUSBUILDINGPERHH if indic_9 == 1

gen indic_10 = 0
replace indic_10 = 1 if subsample ==10
replace outcome = PRIMARYSCHOOLPERHH if indic_10 == 1

foreach X of var indic_1 indic_2 indic_3 indic_4 indic_5 indic_6 indic_7 indic_8 indic_9 indic_10 {
		gen `X'_COMMUNITY = `X'*COMMUNITY
		gen `X'_HYBRID = `X'*HYBRID		
}

local COMMUNITY "indic_1_COMMUNITY indic_2_COMMUNITY indic_3_COMMUNITY indic_4_COMMUNITY indic_5_COMMUNITY indic_6_COMMUNITY indic_7_COMMUNITY indic_8_COMMUNITY indic_9_COMMUNITY indic_10_COMMUNITY"
local HYBRID "indic_1_HYBRID indic_2_HYBRID indic_3_HYBRID indic_4_HYBRID indic_5_HYBRID indic_6_HYBRID indic_7_HYBRID indic_8_HYBRID indic_9_HYBRID indic_10_HYBRID"

//Run stacked regressions

** No Fixed Effect

reg outcome indic_? `COMMUNITY' `HYBRID', cluster(hhea)
outreg using "$output\analysis0_nofe.xls", bdec(5,5,5) se 3aster replace
testparm indic*_COMMUNITY
testparm indic*_HYBRID
testparm indic*_COMMUNITY *_HYBRID

gen category = ""
gen commhybrid_nofe = .

replace category = "Per capita expenditure from SUSETI" in 1
replace category = "se/sd" in 2
replace category = "Education level of HH head" in 3
replace category = "se/sd" in 4
replace category = "PMT score calculated from assets in SUSETI data" in 5
replace category = "se/sd" in 6
replace category = "% of households that are agricultural" in 7
replace category = "se/sd" in 8
replace category = "Education level of RT head" in 9
replace category = "se/sd" in 10
replace category = "Log number of households" in 11
replace category = "se/sd" in 12
replace category = "Distance to kecamatan in km" in 13
replace category = "se/sd" in 14
replace category = "Log size of villages in heactares" in 15
replace category = "se/sd" in 16
replace category = "Religious building per household" in 17
replace category = "se/sd" in 18
replace category = "Primary school per household" in 19
replace category = "se/sd" in 20

lincom indic_1_HYBRID - indic_1_COM
replace commhybrid_nofe = r(estimate) in 1
replace commhybrid_nofe = r(se) in 2
	
lincom indic_2_HYBRID - indic_2_COM
replace commhybrid_nofe = r(estimate) in 3
replace commhybrid_nofe = r(se) in 4

lincom indic_3_HYBRID - indic_3_COM
replace commhybrid_nofe = r(estimate) in 5
replace commhybrid_nofe = r(se) in 6

lincom indic_4_HYBRID - indic_4_COM
replace commhybrid_nofe = r(estimate) in 7
replace commhybrid_nofe = r(se) in 8

lincom indic_5_HYBRID - indic_5_COM
replace commhybrid_nofe = r(estimate) in 9
replace commhybrid_nofe = r(se) in 10

lincom indic_6_HYBRID - indic_6_COM
replace commhybrid_nofe = r(estimate) in 11
replace commhybrid_nofe = r(se) in 12

lincom indic_7_HYBRID - indic_7_COM
replace commhybrid_nofe = r(estimate) in 13
replace commhybrid_nofe = r(se) in 14

lincom indic_8_HYBRID - indic_8_COM
replace commhybrid_nofe = r(estimate) in 15
replace commhybrid_nofe = r(se) in 16

lincom indic_9_HYBRID - indic_9_COM
replace commhybrid_nofe = r(estimate) in 17
replace commhybrid_nofe = r(se) in 18

lincom indic_10_HYBRID - indic_10_COM
replace commhybrid_nofe = r(estimate) in 19
replace commhybrid_nofe = r(se) in 20


test indic_1_HYBRID - indic_1_COM = 0
test indic_2_HYBRID - indic_2_COM = 0, accum
test indic_3_HYBRID - indic_3_COM = 0, accum
test indic_4_HYBRID - indic_4_COM = 0, accum
test indic_5_HYBRID - indic_5_COM = 0, accum
test indic_6_HYBRID - indic_6_COM = 0, accum
test indic_7_HYBRID - indic_7_COM = 0, accum
test indic_8_HYBRID - indic_8_COM = 0, accum
test indic_9_HYBRID - indic_9_COM = 0, accum
test indic_10_HYBRID - indic_10_COM = 0, accum

** Fixed Effect

egen kecagroup_indic = group(kecagroup indic_? indic_??)
areg outcome `COMMUNITY' `HYBRID', absorb(kecagroup_indic) cluster(hhea)
outreg using "$output\analysis0_fe.xls", bdec(5,5,5) se 3aster replace
testparm indic*_COMMUNITY
testparm indic*_HYBRID
testparm indic*_COMMUNITY *_HYBRID

gen commhybrid_fe = .

lincom indic_1_HYBRID - indic_1_COM
replace commhybrid_fe = r(estimate) in 1
replace commhybrid_fe = r(se) in 2
	
lincom indic_2_HYBRID - indic_2_COM
replace commhybrid_fe = r(estimate) in 3
replace commhybrid_fe = r(se) in 4

lincom indic_3_HYBRID - indic_3_COM
replace commhybrid_fe = r(estimate) in 5
replace commhybrid_fe = r(se) in 6

lincom indic_4_HYBRID - indic_4_COM
replace commhybrid_fe = r(estimate) in 7
replace commhybrid_fe = r(se) in 8

lincom indic_5_HYBRID - indic_5_COM
replace commhybrid_fe = r(estimate) in 9
replace commhybrid_fe = r(se) in 10

lincom indic_6_HYBRID - indic_6_COM
replace commhybrid_fe = r(estimate) in 11
replace commhybrid_fe = r(se) in 12

lincom indic_7_HYBRID - indic_7_COM
replace commhybrid_fe = r(estimate) in 13
replace commhybrid_fe = r(se) in 14

lincom indic_8_HYBRID - indic_8_COM
replace commhybrid_fe = r(estimate) in 15
replace commhybrid_fe = r(se) in 16

lincom indic_9_HYBRID - indic_9_COM
replace commhybrid_fe = r(estimate) in 17
replace commhybrid_fe = r(se) in 18

lincom indic_10_HYBRID - indic_10_COM
replace commhybrid_fe = r(estimate) in 19
replace commhybrid_fe = r(se) in 20

test indic_1_HYBRID - indic_1_COM = 0
test indic_2_HYBRID - indic_2_COM = 0, accum
test indic_3_HYBRID - indic_3_COM = 0, accum
test indic_4_HYBRID - indic_4_COM = 0, accum
test indic_5_HYBRID - indic_5_COM = 0, accum
test indic_6_HYBRID - indic_6_COM = 0, accum
test indic_7_HYBRID - indic_7_COM = 0, accum
test indic_8_HYBRID - indic_8_COM = 0, accum
test indic_9_HYBRID - indic_9_COM = 0, accum
test indic_10_HYBRID - indic_10_COM = 0, accum

gen PMTmean = .
gen Commmean = .
gen hybridmean = .

	summ outcome if indic_1 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 1 
	replace PMTmean = r(sd) in 2 

	summ outcome if indic_2 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 3 
	replace PMTmean = r(sd) in 4 

	summ outcome if indic_3 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 5 
	replace PMTmean = r(sd) in 6 

	summ outcome if indic_4 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 7 
	replace PMTmean = r(sd) in 8 

	summ outcome if indic_5 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 9 
	replace PMTmean = r(sd) in 10 

	summ outcome if indic_6 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 11 
	replace PMTmean = r(sd) in 12 

	summ outcome if indic_7 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 13 
	replace PMTmean = r(sd) in 14 

	summ outcome if indic_8 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 15 
	replace PMTmean = r(sd) in 16 

	summ outcome if indic_9 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 17 
	replace PMTmean = r(sd) in 18 

	summ outcome if indic_10 == 1 & maintreatment == 1
	replace PMTmean = r(mean) in 19 
	replace PMTmean = r(sd) in 20 

	summ outcome if indic_1 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 1 
	replace Commmean = r(sd) in 2 

	summ outcome if indic_2 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 3 
	replace Commmean = r(sd) in 4 

	summ outcome if indic_3 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 5 
	replace Commmean = r(sd) in 6 

	summ outcome if indic_4 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 7 
	replace Commmean = r(sd) in 8 

	summ outcome if indic_5 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 9 
	replace Commmean = r(sd) in 10 

	summ outcome if indic_6 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 11 
	replace Commmean = r(sd) in 12 

	summ outcome if indic_7 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 13 
	replace Commmean = r(sd) in 14 

	summ outcome if indic_8 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 15 
	replace Commmean = r(sd) in 16 

	summ outcome if indic_9 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 17 
	replace Commmean = r(sd) in 18 

	summ outcome if indic_10 == 1 & maintreatment == 2
	replace Commmean = r(mean) in 19 
	replace Commmean = r(sd) in 20 

	summ outcome if indic_1 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 1 
	replace hybridmean = r(sd) in 2

	summ outcome if indic_2 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 3 
	replace hybridmean = r(sd) in 4 

	summ outcome if indic_3 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 5
	replace hybridmean = r(sd) in 6 

	summ outcome if indic_4 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 7
	replace hybridmean = r(sd) in 8

	summ outcome if indic_5 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 9
	replace hybridmean = r(sd) in 10

	summ outcome if indic_6 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 11
	replace hybridmean = r(sd) in 12 

	summ outcome if indic_7 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 13 
	replace hybridmean = r(sd) in 14 

	summ outcome if indic_8 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 15
	replace hybridmean = r(sd) in 16 

	summ outcome if indic_9 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 17 
	replace hybridmean = r(sd) in 18 

	summ outcome if indic_10 == 1 & maintreatment == 3
	replace hybridmean = r(mean) in 19 
	replace hybridmean = r(sd) in 20 

outsheet category commhybrid_nofe kecagroup_indic commhybrid_fe PMTmean Commmean hybridmean in 1/20 using "$output\analysis0_commhybrid_nofe.xls", replace

*/

log close
