/* Analysis 0.11: Basic regression  */
*
/* Create RANK.dta & analysis01.dta */
/* Last Modified 7 June 2009 */

clear
set more off
set mem 256m

version 10

capture log close
log using "$output\Coding_files_output\analysis01.log",replace

****

// RANK FROM THE SUSETI

use "$codeddata\intermediate_data\hh_rank.dta", replace
sort hhid_who_rank rank
bys hhid_who_rank: gen x=_n
count if x!= rank
drop x

/* drop HH who rank themselves and reposition the rank */
drop if hhid == hhid_who_rank
sort hhid_who_rank rank
bys hhid_who_rank: gen x=_n
replace rank=x 
drop x

egen nhhrank=max(rank)
label var nhhrank "number of household in village"

gen RANK= rank/nhhrank

label var RANK "percentile rank within the village"

save "$codeddata\intermediate_data\RANK.dta", replace

****

use "$codeddata/intermediate_data/coding_treatment.dta", clear
keep hhea kecagroup
tempfile x1
save `x1', replace

use "$codeddata\intermediate_data\consumption.dta", clear
destring hhea, replace
mmerge hhea using `x1'

gen inequality = .
forvalue i = 1/640 {
	qui fastgini CONSUMPTION if hhea==`i'
	qui replace inequality=r(gini) if hhea==`i'
}

preserve

keep hhea inequality
bys hhea: keep if _n==1

save "$codeddata/intermediate_data/inequality.dta", replace
restore

mmerge hhid using "$codeddata\coding_suseti_pmt", type(1:1)

mmerge hhid using "$codeddata\intermediate_data\gendertarget", type(1:1)

/* merge with subjective ranking */
mmerge hhid using "$codeddata\intermediate_data\hh_sw", type(1:1)

/* merge with minority variable */
mmerge hhid using "$codeddata\intermediate_data\minority.dta", type(1:1)

/* merge with geographycally isolated */
mmerge hhid using "$codeddata\intermediate_data\coding_gps.dta", type(1:1)
drop  idrt att RTHEAD _merge 

/* merge with percent kids of agegroup 0-4, 4-9, 10-15 */
mmerge hhid using "$codeddata\intermediate_data\children.dta", type(1:1)
drop children0_4 children5_9 children10_15 nchildren nchildren0_4 nchildren5_9 nchildren10_15

tempfile x2
save `x2', replace


// INDIVIDUAL LEVEL VARIABLES

/* shock */

use "$codeddata\intermediate_data\hhshock.dta", clear
gen shock =( ge01a ==1| ge01b ==1| ge01c ==1| ge01d ==1| ge01e ==1| ge01f ==1| ge01g ==1| ge01h ==1| ge01v ==1)
tempfile a
save `a', replace

/* Conspicuousness */

use "$codeddata\intermediate_data\hhasset.dta", clear
keep hhid hr0625 hr0623 hr0626 hr0617
tempfile b1
save `b1', replace

use "$codeddata\intermediate_data\hhcharacteristic.dta", clear
keep  hhid troof twall
mmerge hhid using `b1', type(1:1)
tempfile b2
save `b2', replace

use "$codeddata\intermediate_data\haji.dta", clear
mmerge hhid using `b2', type(1:1)
tempfile b3
save `b3', replace

use "$codeddata\intermediate_data\consumption.dta", clear
keep hhid CONSUMPTION
mmerge hhid using `b3', type(1:1)
drop _m

egen nvisible = rsum(hr0625 hr0623 hr0626 hr0617 troof twall nHAJI)
label var nvisible "number of visible asset"

gen conspicuousness = nvisible/CONSUMPTION
gen conspicuousness_2 = nvisible
label var conspicuousness_2 "conspicuousness without the denominator (CONSUMPTION)"

save "$codeddata/intermediate_data/conspicuousness.dta", replace

mmerge hhid using `a', type(1:1)

tempfile b4
save `b4', replace

/* connectedness */

use "$codeddata\intermediate_data\socialconnection.dta", clear
drop pm16a pm16b pm16c pm16d pm16e groupwithinRT groupoutsideRT vote*
gen hhea = substr(hhid,1,3)
tempfile c1
save `c1', replace

use "$codeddata\intermediate_data\nELITE.dta", clear
mmerge hhea using `c1'
destring hhea, replace
tempfile c2
save `c2', replace

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea  numhhsls_dec
rename numhhsls_dec N
mmerge hhea using `c2'
drop _m

gen connectedness = HHRELATED/N
gen elite_connectedness = HHRELATED_ELITE/nELITE

bys hhea: egen avg_connectedness= mean(connectedness)

mmerge hhid using `b4', type(1:1)
tempfile c3
save `c3', replace

/* Really poor */
/*
use "$codeddata\analysis1_hh.dta", clear
keep hhid_suseti poor verypoor
rename hhid_suseti hhid
mmerge hhid using `c3', type(1:1)
drop _m
*/
compress
sort hhid
save "$codeddata/intermediate_data/aggregatevar.dta", replace

mmerge hhid using `x2', type(1:1)

mmerge hhid using "$codeddata\intermediate_data\RANK.dta"
keep if _m==3
tempfile d1
save `d1', replace

// CHARACTERISTIC FROM THE PERSON WHO DO THE RANKING

use "$codeddata\intermediate_data\characteristic_respondent.dta", clear
gen MALERESPONDENT = (GENDERRESPONDENT==1)

mmerge hhid using "$codeddata\intermediate_data\consumption.dta", type(1:1)

mmerge hhid using "$codeddata\intermediate_data\aggregatevar.dta", type(1:1)

mmerge hhid using "$codeddata\intermediate_data\rthead.dta"
replace RTHEAD=0 if RTHEAD==.

mmerge hhid using "$codeddata\intermediate_data\formalleader.dta"
drop if _m==2
replace FORMALLEADER=0 if FORMALLEADER==.

mmerge hhid using "$codeddata\intermediate_data\informalleader.dta"
drop if _m==2
replace INFORMALLEADER=0 if INFORMALLEADER==.

gen otherELITE = (FORMALLEADER==1|INFORMALLEADER==1)
replace otherELITE = 0 if RTHEAD==1

keep  hhid MALERESPONDENT YREDUCRESPONDENT CONSUMPTION connectedness LOGCONSUMPTION RTHEAD otherELITE

foreach var of varlist hhid MALERESPONDENT YREDUCRESPONDENT CONSUMPTION connectedness LOGCONSUMPTION RTHEAD otherELITE {
	rename `var' `var'_who_rank
}

mmerge hhid_who_rank using `d1'
keep if _m==3
tempfile d2
save `d2', replace

// merge with family members between ranker and rankee

use "$codeddata\intermediate_data\hh_cr01.dta", clear
keep hhid hhid_cr01 family
preserve
rename hhid_cr01 hhid_who_rank
mmerge hhid hhid_who_rank using `d2'
keep if _m==3
keep hhid* family
tempfile d3
save `d3'
restore

rename hhid hhid_who_rank
rename hhid_cr01 hhid
mmerge hhid hhid_who_rank using `d2'
keep if _m==3
keep hhid* family

append using `d3'
bys hhid hhid_who_rank: keep if _n==1
mmerge hhid hhid_who_rank using `d2'
replace family=0 if family==.

tempfile d4
save `d4', replace

// Create same type of social group

use "$codeddata\intermediate_data\hh_pm2.dta", clear
keep if pm06x==1 /* Just keep the groups that respondent join */
keep hhid pm04 pm03line
reshape wide pm04, i(hhid) j(pm03line)

gen socialgroupA=( pm041=="A"| pm042=="A"| pm043=="A"|  pm044=="A"|  pm045=="A"|  pm046=="A"| pm047=="A"| pm048=="A"| pm049=="A"| pm0410=="A"| pm0411=="A"| pm0412=="A")
gen socialgroupB=( pm041=="B"| pm042=="B"| pm043=="B"|  pm044=="B"|  pm045=="B"|  pm046=="B"| pm047=="B"| pm048=="B"| pm049=="B"| pm0410=="B"| pm0411=="B"| pm0412=="B")
gen socialgroupC=( pm041=="C"| pm042=="C"| pm043=="C"|  pm044=="C"|  pm045=="C"|  pm046=="C"| pm047=="C"| pm048=="C"| pm049=="C"| pm0410=="C"| pm0411=="C"| pm0412=="C")
gen socialgroupD=( pm041=="D"| pm042=="D"| pm043=="D"|  pm044=="D"|  pm045=="D"|  pm046=="D"| pm047=="D"| pm048=="D"| pm049=="D"| pm0410=="D"| pm0411=="D"| pm0412=="D")
gen socialgroupE=( pm041=="E"| pm042=="E"| pm043=="E"|  pm044=="E"|  pm045=="E"|  pm046=="E"| pm047=="E"| pm048=="E"| pm049=="E"| pm0410=="E"| pm0411=="E"| pm0412=="E")
gen socialgroupF=( pm041=="F"| pm042=="F"| pm043=="F"|  pm044=="F"|  pm045=="F"|  pm046=="F"| pm047=="F"| pm048=="F"| pm049=="F"| pm0410=="F"| pm0411=="F"| pm0412=="F")
gen socialgroupG=( pm041=="G"| pm042=="G"| pm043=="G"|  pm044=="G"|  pm045=="G"|  pm046=="G"| pm047=="G"| pm048=="G"| pm049=="G"| pm0410=="G"| pm0411=="G"| pm0412=="G")

keep hhid socialgroup*
tempfile pm2
save `pm2', replace

mmerge hhid using `d4'
drop if _m==1

foreach var of varlist socialgroupA socialgroupB socialgroupC socialgroupD socialgroupE socialgroupF socialgroupG {
	replace `var' = 0 if `var'==.
}
tempfile e1
save `e1', replace

use `pm2', replace
foreach var of varlist hhid socialgroupA socialgroupB socialgroupC socialgroupD socialgroupE socialgroupF socialgroupG {
	rename `var' `var'_who_rank
}
mmerge hhid_who_rank using `e1'
drop if _m==1
drop _m

gen same_socialgroup = ((socialgroupA==1 & socialgroupA_who_rank==1 )| (socialgroupB==1 & socialgroupB_who_rank==1)|(socialgroupC==1 & socialgroupC_who_rank==1)| (socialgroupD==1 & socialgroupD_who_rank==1)|(socialgroupE==1 & socialgroupE_who_rank==1)|(socialgroupF==1 & socialgroupF_who_rank==1)|(socialgroupG==1 & socialgroupG_who_rank==1)) 
drop socialgroup*
tempfile e2
save `e2', replace

// create have kids in the same school class

/* kids in the household */

use "$data\baseline\hh_ar2.dta", clear
gen age_school_children = (ar04a<=22)
** keep school kids
keep if ar14==1 & age_school_children==1
keep hhid ar12 ar13 ar04a
drop if ar12==95
recode ar12 (7=6)

** Create the grade of kids: Primary: grade 1- 6, Junior: grade 7-9, high: grade 10-12, university: grade 13-16
gen grade  = 0 if ar12==0|ar12==1
replace grade = ar13 if ar12==2 
replace grade = 6 if grade>=6
replace grade = 6 + ar13 if ar12==3 
replace grade = 9 if grade>=9
replace grade = 9 + ar13 if ar12==4 
replace grade = 12 if grade>=12
replace grade = 12 + ar13 if ar12==5 
replace grade = 15 if grade>=15
replace grade = 12 + ar13 if ar12==6 
replace grade = 16 if grade>=16
label var grade "school grade"

keep hhid grade
bys hhid grade: keep if _n==1 
gen x= 1

reshape wide x, i(hhid) j(grade)

forvalues i = 0/16 {
	replace x`i' = 0 if x`i'==.
	rename x`i' grade`i'
}

keep hhid grade*
sum

tempfile grade
save `grade', replace

mmerge hhid using `e2'
drop if _m==1

foreach var of varlist grade0- grade16 {
	replace `var' = 0 if `var'==.
}
tempfile f1
save `f1', replace

use `grade', replace
foreach var of varlist hhid grade0- grade16 {
	rename `var' `var'_who_rank
}
mmerge hhid_who_rank using `f1'
drop if _m==1
drop _m

gen same_kids = ((grade0==1 & grade0_who_rank==1 )|(grade1==1 & grade1_who_rank==1 )|(grade2==1 & grade2_who_rank==1 )|(grade3==1 & grade3_who_rank==1 )|(grade4==1 & grade4_who_rank==1 )|(grade5==1 & grade5_who_rank==1 )|(grade6==1 & grade6_who_rank==1 )|(grade7==1 & grade7_who_rank==1 )|(grade8==1 & grade8_who_rank==1 )|(grade9==1 & grade9_who_rank==1 )|(grade10==1 & grade10_who_rank==1 )|(grade11==1 & grade11_who_rank==1 )|(grade12==1 & grade12_who_rank==1 )|(grade13==1 & grade13_who_rank==1 )|(grade14==1 & grade14_who_rank==1 )|(grade15==1 & grade15_who_rank==1 )|(grade16==1 & grade16_who_rank==1 )) 
drop grade*

compress
sort hhid
save "$codeddata\analysis01.dta", replace



/*

// 1. Basic regression

** No fixed effect

regress RANK LOGCONSUMPTION, cluster(hhea)
outreg using "$output\analysis01_1_nofe.xls", se 3aster replace
regress RANK RANKCONSUMPTION, cluster(hhea)
outreg using "$output\analysis01_1_nofe.xls", se 3aster append
regress RANK RANK_sw02, cluster(hhea)
outreg using "$output\analysis01_1_nofe.xls", se 3aster append
regress RANK RANK_sw03, cluster(hhea)
outreg using "$output\analysis01_1_nofe.xls", se 3aster append

** fixed effect

areg RANK LOGCONSUMPTION, absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_1_fe.xls", se 3aster replace
areg RANK RANKCONSUMPTION, absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_1_fe.xls", se 3aster append
areg RANK RANK_sw02, absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_1_fe.xls", se 3aster append
areg RANK RANK_sw03, absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_1_fe.xls", se 3aster append

***** RT head/non RT head

forvalues RT = 0/1 {

	** No fixed effect

	regress RANK LOGCONSUMPTION if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_1_nofe_RT`RT'.xls", se 3aster replace
	regress RANK RANKCONSUMPTION if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_1_nofe_RT`RT'.xls", se 3aster append
	regress RANK RANK_sw02 if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_1_nofe_RT`RT'.xls", se 3aster append
	regress RANK RANK_sw03  if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_1_nofe_RT`RT'.xls", se 3aster append

	** fixed effect

	areg RANK LOGCONSUMPTION if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_1_fe_RT`RT'.xls", se 3aster replace
	areg RANK RANKCONSUMPTION if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_1_fe_RT`RT'.xls", se 3aster append
	areg RANK RANK_sw02 if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_1_fe_RT`RT'.xls", se 3aster append
	areg RANK RANK_sw03 if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_1_fe_RT`RT'.xls", se 3aster append

}





// 2. Do they have residual information beyond PMT?

** No fixed effect

local assets "pcfloor tfloor twall toilet water lighting troof fcook house credit hhsize hhsize2 hhage hhage2 hhmale hhmarried hhmalemarr hhsector1 hhsector2 hhsector3 formal informal hheduc2 hheduc3 hheduc4 age04 eschild jschild sschild higheduc2 higheduc3 higheduc4 depratio se2_115 se2_117 se2_13_15 se2_11_12 se2_14 se2_114 se2_18 se2_17 se2_124 se2_125 se2_126_127 se2_119 se2_122_123 se5_110 se5_11_12"

regress RANK LOGCONSUMPTION PMTSCORE, cluster(hhea)
outreg using "$output\analysis01_2_nofe.xls", se 3aster replace
regress RANK LOGCONSUMPTION `assets', cluster(hhea)
outreg using "$output\analysis01_2_nofe.xls", se 3aster append
regress RANK RANKCONSUMPTION PMTRANK, cluster(hhea)
outreg using "$output\analysis01_2_nofe.xls", se 3aster append
regress RANK RANKCONSUMPTION `assets', cluster(hhea)
outreg using "$output\analysis01_2_nofe.xls", se 3aster append

** fixed effect

areg RANK LOGCONSUMPTION PMTSCORE, absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_2_fe.xls", se 3aster replace
areg RANK LOGCONSUMPTION `assets', absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_2_fe.xls", se 3aster append
areg RANK RANKCONSUMPTION PMTRANK, absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_2_fe.xls", se 3aster append
areg RANK RANKCONSUMPTION `assets', absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_2_fe.xls", se 3aster append


***** RT head/non RT head

forvalues RT = 0/1 {

	** No fixed effect

	regress RANK LOGCONSUMPTION PMTSCORE if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_2_nofe_RT`RT'.xls", se 3aster replace
	regress RANK LOGCONSUMPTION `assets' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_2_nofe_RT`RT'.xls", se 3aster append
	regress RANK RANKCONSUMPTION PMTRANK if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_2_nofe_RT`RT'.xls", se 3aster append
	regress RANK RANKCONSUMPTION `assets' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_2_nofe_RT`RT'.xls", se 3aster append

	** fixed effect

	areg RANK LOGCONSUMPTION PMTSCORE if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_2_fe_RT`RT'.xls", se 3aster replace
	areg RANK LOGCONSUMPTION `assets' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_2_fe_RT`RT'.xls", se 3aster append
	areg RANK RANKCONSUMPTION PMTRANK if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_2_fe_RT`RT'.xls", se 3aster append
	areg RANK RANKCONSUMPTION `assets' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_2_fe_RT`RT'.xls", se 3aster append

}





// 3. How does the community assess poverty?

** No fixed effect

local X1 "shock conspicuousness connectedness elite_connectedness verypoor"
local X2 "shock conspicuousness connectedness elite_connectedness verypoor ETHICMINORITY RELIGIOUSMINORITY isolated"
local X3 "shock conspicuousness_2 elite_connectedness verypoor ETHICMINORITY RELIGIOUSMINORITY isolated"

forvalues i = 1/3 {

	regress LOGCONSUMPTION `X`i'', cluster(hhea)
	predict y1LOGCONSUMPTION_X`i'

	regress RANKCONSUMPTION `X`i'', cluster(hhea)
	predict y1RANKCONSUMPTION_X`i'

	regress RANK LOGCONSUMPTION `X`i'', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster replace
	regress RANK RANKCONSUMPTION `X`i'', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster append

	regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster append
	regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster append

	recode GENDERTARGET (3=2)
	forvalues j = 1/2 {
		regress RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster replace
		regress RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster append

		regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster append
		regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster append
	}

	** Fixed effect

	areg LOGCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	predict y2LOGCONSUMPTION_X`i'

	areg RANKCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	predict y2RANKCONSUMPTION_X`i'

	areg RANK LOGCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster replace
	areg RANK RANKCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster append

	areg RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster append
	areg RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster append


	forvalues j = 1/2 {
		areg RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster replace
		areg RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster append

		areg RANK LOGCONSUMPTION `X`i'' y2LOGCONSUMPTION_X`i' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster append
		areg RANK RANKCONSUMPTION `X`i'' y2RANKCONSUMPTION_X`i' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster append
	}

}



***** RT head/non RT head

forvalues RT = 0/1 {

	forvalues i = 1/3 {

		** No Fixed effect

		regress LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		predict y1LOGCONSUMPTION_X`i'_RT`RT'

		regress RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		predict y1RANKCONSUMPTION_X`i'_RT`RT'

		regress RANK LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster replace
		regress RANK RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster append

		regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster append
		regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster append

		recode GENDERTARGET (3=2)
		forvalues j = 1/2 {
			regress RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster replace
			regress RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster append

			regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
			regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
		}

		** Fixed effect

		areg LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		predict y2LOGCONSUMPTION_X`i'_RT`RT'

		areg RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		predict y2RANKCONSUMPTION_X`i'_RT`RT'

		areg RANK LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster replace
		areg RANK RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster append

		areg RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster append
		areg RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster append


		forvalues j = 1/2 {
			areg RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster replace
			areg RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster append

			areg RANK LOGCONSUMPTION `X`i'' y2LOGCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
			areg RANK RANKCONSUMPTION `X`i'' y2RANKCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
		}
	}
}





// 4. Who gets ranked more accurately?

local V "urban inequality avg_connectedness"

foreach var in `X1' `V'  {
	gen `var'LC = `var'* LOGCONSUMPTION
	gen `var'RC = `var'* RANKCONSUMPTION
}

local XLC "shockLC conspicuousnessLC connectednessLC elite_connectednessLC verypoorLC"
local VLC "urbanLC inequalityLC avg_connectednessLC"
local XRC "shockRC conspicuousnessRC connectednessRC elite_connectednessRC verypoorRC"
local VRC "urbanRC inequalityRC avg_connectednessRC"


** No fixed Effect

regress RANK LOGCONSUMPTION `XLC' `X1', cluster(hhea)
outreg using "$output\analysis01_4_nofe.xls", se 3aster replace
regress RANK LOGCONSUMPTION `VLC' `V', cluster(hhea)
outreg using "$output\analysis01_4_nofe.xls", se 3aster append
regress RANK LOGCONSUMPTION *LC `X1' `V', cluster(hhea)
outreg using "$output\analysis01_4_nofe.xls", se 3aster append

regress RANK RANKCONSUMPTION `XRC' `X1', cluster(hhea)
outreg using "$output\analysis01_4_nofe.xls", se 3aster append
regress RANK RANKCONSUMPTION `VRC' `V', cluster(hhea)
outreg using "$output\analysis01_4_nofe.xls", se 3aster append
regress RANK RANKCONSUMPTION *RC `X1' `V', cluster(hhea)
outreg using "$output\analysis01_4_nofe.xls", se 3aster append

** fixed Effect

areg RANK LOGCONSUMPTION `XLC' `X1',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_4_fe.xls", se 3aster replace
areg RANK LOGCONSUMPTION `VLC' `V',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_4_fe.xls", se 3aster append
areg RANK LOGCONSUMPTION *LC `X1' `V',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_4_fe.xls", se 3aster append

areg RANK RANKCONSUMPTION `XRC' `X1',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_4_fe.xls", se 3aster append
areg RANK RANKCONSUMPTION `VRC' `V',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_4_fe.xls", se 3aster append
areg RANK RANKCONSUMPTION *RC `X1' `V',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_4_fe.xls", se 3aster append


***** RT head/non RT head

forvalues RT = 0/1 {

	** No fixed Effect

	regress RANK LOGCONSUMPTION `XLC' `X1' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_4_nofe_RT`RT'.xls", se 3aster replace
	regress RANK LOGCONSUMPTION `VLC' `V' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_4_nofe_RT`RT'.xls", se 3aster append
	regress RANK LOGCONSUMPTION *LC `X1' `V' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_4_nofe_RT`RT'.xls", se 3aster append

	regress RANK RANKCONSUMPTION `XRC' `X1' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_4_nofe_RT`RT'.xls", se 3aster append
	regress RANK RANKCONSUMPTION `VRC' `V' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_4_nofe_RT`RT'.xls", se 3aster append
	regress RANK RANKCONSUMPTION *RC `X1' `V' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_4_nofe_RT`RT'.xls", se 3aster append

	** fixed Effect

	areg RANK LOGCONSUMPTION `XLC' `X1' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_4_fe_RT`RT'.xls", se 3aster replace
	areg RANK LOGCONSUMPTION `VLC' `V' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_4_fe_RT`RT'.xls", se 3aster append
	areg RANK LOGCONSUMPTION *LC `X1' `V' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)	
	outreg using "$output\analysis01_4_fe_RT`RT'.xls", se 3aster append

	areg RANK RANKCONSUMPTION `XRC' `X1' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_4_fe_RT`RT'.xls", se 3aster append
	areg RANK RANKCONSUMPTION `VRC' `V' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_4_fe_RT`RT'.xls", se 3aster append
	areg RANK RANKCONSUMPTION *RC `X1' `V' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_4_fe_RT`RT'.xls", se 3aster append

}




//5. Who ranks better?

local X_who_rank "YREDUCRESPONDENT_who_rank MALERESPONDENT_who_rank CONSUMPTION_who_rank connectedness_who_rank RTHEAD_who_rank otherELITE_who_rank"

foreach var in `X_who_rank'  {
	gen `var'LC = `var'* LOGCONSUMPTION
	gen `var'RC = `var'* RANKCONSUMPTION
}

local X_who_rankLC "YREDUCRESPONDENT_who_rankLC MALERESPONDENT_who_rankLC CONSUMPTION_who_rankLC connectedness_who_rankLC RTHEAD_who_rankLC otherELITE_who_rankLC"
local X_who_rankRC "YREDUCRESPONDENT_who_rankRC MALERESPONDENT_who_rankRC CONSUMPTION_who_rankRC connectedness_who_rankRC RTHEAD_who_rankRC otherELITE_who_rankRC"

** No fixed effect

regress RANK LOGCONSUMPTION `X_who_rankLC', cluster(hhea)
outreg using "$output\analysis01_5_nofe.xls", se 3aster replace
regress RANK RANKCONSUMPTION `X_who_rankRC', cluster(hhea)
outreg using "$output\analysis01_5_nofe.xls", se 3aster append

** fixed effect

areg RANK LOGCONSUMPTION `X_who_rankLC',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_5_fe.xls", se 3aster replace
areg RANK RANKCONSUMPTION `X_who_rankRC',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_5_fe.xls", se 3aster append


***** RT head/non RT head

forvalues RT = 0/1 {

	** No fixed effect

	regress RANK LOGCONSUMPTION `X_who_rankLC' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_5_nofe_RT`RT'.xls", se 3aster replace
	regress RANK RANKCONSUMPTION `X_who_rankRC' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_5_nofe_RT`RT'.xls", se 3aster append

	** fixed effect

	areg RANK LOGCONSUMPTION `X_who_rankLC' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_5_fe_RT`RT'.xls", se 3aster replace
	areg RANK RANKCONSUMPTION `X_who_rankRC' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_5_fe_RT`RT'.xls", se 3aster append

}




// 6. Interactions about ranker-rankee relationship

local Z "family same_socialgroup same_kids"

foreach var in `Z'  {
	gen `var'LC = `var'* LOGCONSUMPTION
	gen `var'RC = `var'* RANKCONSUMPTION
}

local ZLC "familyLC same_socialgroupLC same_kidsLC"
local ZRC "familyRC same_socialgroupRC same_kidsRC"

** No fixed effect

regress RANK LOGCONSUMPTION `ZLC' `Z', cluster(hhea)
outreg using "$output\analysis01_6_nofe.xls", se 3aster replace
regress RANK RANKCONSUMPTION `ZRC' `Z', cluster(hhea)
outreg using "$output\analysis01_6_nofe.xls", se 3aster append

** fixed effect

areg RANK LOGCONSUMPTION `ZLC' `Z',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_6_fe.xls", se 3aster replace
areg RANK RANKCONSUMPTION `ZRC' `Z',absorb(hhid_who_rank) cluster(hhea)
outreg using "$output\analysis01_6_fe.xls", se 3aster append


***** RT head/non RT head

forvalues RT = 0/1 {

	** No fixed effect

	regress RANK LOGCONSUMPTION `ZLC' `Z' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_6_nofe_RT`RT'.xls", se 3aster replace
	regress RANK RANKCONSUMPTION `ZRC' `Z' if RTHEAD_who_rank==`RT', cluster(hhea)
	outreg using "$output\analysis01_6_nofe_RT`RT'.xls", se 3aster append

	** fixed effect

	areg RANK LOGCONSUMPTION `ZLC' `Z' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_6_fe_RT`RT'.xls", se 3aster replace
	areg RANK RANKCONSUMPTION `ZRC' `Z' if RTHEAD_who_rank==`RT',absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_6_fe_RT`RT'.xls", se 3aster append

}




// 3. How does the community assess poverty?

regress LOGCONSUMPTION LOGHHSIZE schildren0_4 schildren5_9 schildren10_15
predict equivalence_scale

** No fixed effect

local X4 "equivalence_scale ge01a ge01c ge01e ge01g WIDOW conspicuousness_2  HHRELATED FORMALLEADER FAMILYFORMALLEADER INFORMALLEADER FAMILYINFORMALLEADER NGROUPWITHINRT NGROUPOUTSIDERT CLOSEABOVEKETUART CLOSEWITHKETUART ETHICMINORITY RELIGIOUSMINORITY isolated verypoor"

local i = 4 

	regress LOGCONSUMPTION `X`i'', cluster(hhea)
	predict y1LOGCONSUMPTION_X`i'

	regress RANKCONSUMPTION `X`i'', cluster(hhea)
	predict y1RANKCONSUMPTION_X`i'

	regress RANK LOGCONSUMPTION `X`i'', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster replace
	regress RANK RANKCONSUMPTION `X`i'', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster append

	regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster append
	regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i', cluster(hhea)
	outreg using "$output\analysis01_3_nofe_X`i'.xls", se 3aster append

	recode GENDERTARGET (3=2)
	forvalues j = 1/2 {
		regress RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster replace
		regress RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster append

		regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster append
		regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i' if GENDERTARGET == `j', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_sex`j'_X`i'.xls", se 3aster append
	}

	** Fixed effect

	areg LOGCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	predict y2LOGCONSUMPTION_X`i'

	areg RANKCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	predict y2RANKCONSUMPTION_X`i'

	areg RANK LOGCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster replace
	areg RANK RANKCONSUMPTION `X`i'', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster append

	areg RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster append
	areg RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i', absorb(hhid_who_rank) cluster(hhea)
	outreg using "$output\analysis01_3_fe_X`i'.xls", se 3aster append


	forvalues j = 1/2 {
		areg RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster replace
		areg RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster append

		areg RANK LOGCONSUMPTION `X`i'' y2LOGCONSUMPTION_X`i' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster append
		areg RANK RANKCONSUMPTION `X`i'' y2RANKCONSUMPTION_X`i' if GENDERTARGET == `j', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_sex`j'_X`i'.xls", se 3aster append
	}





***** RT head/non RT head

forvalues RT = 0/1 {


		** No Fixed effect

		regress LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		predict y1LOGCONSUMPTION_X`i'_RT`RT'

		regress RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		predict y1RANKCONSUMPTION_X`i'_RT`RT'

		regress RANK LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster replace
		regress RANK RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster append

		regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster append
		regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', cluster(hhea)
		outreg using "$output\analysis01_3_nofe_X`i'_RT`RT'.xls", se 3aster append

		recode GENDERTARGET (3=2)
		forvalues j = 1/2 {
			regress RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster replace
			regress RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster append

			regress RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
			regress RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', cluster(hhea)
			outreg using "$output\analysis01_3_nofe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
		}

		** Fixed effect

		areg LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		predict y2LOGCONSUMPTION_X`i'_RT`RT'

		areg RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		predict y2RANKCONSUMPTION_X`i'_RT`RT'

		areg RANK LOGCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster replace
		areg RANK RANKCONSUMPTION `X`i'' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster append

		areg RANK LOGCONSUMPTION `X`i'' y1LOGCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster append
		areg RANK RANKCONSUMPTION `X`i'' y1RANKCONSUMPTION_X`i'_RT`RT' if RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
		outreg using "$output\analysis01_3_fe_X`i'_RT`RT'.xls", se 3aster append


		forvalues j = 1/2 {
			areg RANK LOGCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster replace
			areg RANK RANKCONSUMPTION `X`i'' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster append

			areg RANK LOGCONSUMPTION `X`i'' y2LOGCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
			areg RANK RANKCONSUMPTION `X`i'' y2RANKCONSUMPTION_X`i'_RT`RT' if GENDERTARGET == `j' & RTHEAD_who_rank==`RT', absorb(hhid_who_rank) cluster(hhea)
			outreg using "$output\analysis01_3_fe_sex`j'_X`i'_RT`RT'.xls", se 3aster append
		}

}

*/
log close
