/* Analysis 1: Mistargeting */
/* Create hhrts.dta, analysis1_hh.dta, analysis1_vill.dta */

/* Last Modified 16 April 2009 */

clear
set more off
set mem 256m

version 10

set sortseed 10000

capture log close
log using "$output\Coding_files_output\analysis1.log",replace


********************

/* create rts data */

/* match suseti data with list of households who get BLT */

use "$data\baseline\hh_ksr2.dta", clear

use "$codeddata/intermediate_data/match_suseti_experiment.dta", clear
keep hhid_exp hhid_suseti maintreatment 
sort hhid_exp

* keep if hhid_exp is equal to missing
preserve
keep if hhid_exp==""
tempfile b1
save `b1', replace
restore

drop if hhid_exp==""
tempfile a
save `a', replace


* PMT Area *

use "$codeddata\intermediate_data\pmt_p2k08.dta", clear
keep hhea lnpcexpe epcexpe RTS ranking hhid nhhrank TREATRANK ranking_PMT
rename hhid hhid_exp
mmerge hhid_exp using `a'

keep if _m==3
drop _m
tempfile b2
save `b2'

* Community area *

use "$codeddata\intermediate_data\RTS_community.dta", clear
rename hhid hhid_exp
mmerge hhid_exp using `a'

keep if _m==3
drop _m
sort hhid_exp
tempfile b3
save `b3'

* Hybrid area *

use "$codeddata\intermediate_data\rts_hybrid.dta", clear
rename hhid hhid_exp
mmerge hhid_exp using `a'

keep if _m==3

replace RTS = 0 if RTS==.
drop _m
sort hhid_exp
tempfile b4
save `b4'

use `b1', clear
append using `b2'
append using `b3'
append using `b4'

replace RTS_meeting=RTS if main==1

compress
sort hhid_suseti
save "$codeddata\intermediate_data\hhrts.dta", replace

/* Merge with consumption */

use "$codeddata\intermediate_data\consumption.dta", clear
keep hhid CONSUMPTION LOGCONSUMPTION
rename hhid hhid_suseti

mmerge hhid_suseti using "$codeddata\intermediate_data\hhrts.dta" 

drop _m
tempfile d
save `d', replace

/* Merge with RT head HHID */

use "$codeddata/intermediate_data/rthead.dta", clear
keep hhid RTHEAD
rename hhid hhid_suseti
mmerge hhid_suseti using `d'
drop _m
replace RTHEAD = 0 if RTHEAD==.

drop hhea
gen hhea = substr(hhid_suseti,1,3)
destring hhea, replace
sort hhea
tempfile e
save `e', replace

/* Create weight */

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea prop  kab kec klas_desa desa kecagroup numhhsls_dec  maintreatment tokohsubtreatment poor10subtreatment daynightsubtreatment

/* We use number of households in RT before the experiment */
rename numhhsls_dec N

gen COMMUNITY = (maintreatment==2)
gen HYBRID = (maintreatment==3)

rename tokohsubtreatment ELITE 
rename poor10subtreatment POOREST10 
gen DAYMEETING = 1 if daynightsubtreatment==0
replace DAYMEETING = 0 if daynightsubtreatment==1

sort prop  kab kec desa
tempfile f
save `f', replace

use "$codeddata\intermediate_data\coding_podes08.dta", clear
keep prop kab kec desa R
mmerge prop kab kec desa using `f'
keep if _m==3
drop _m

/* merge with poverty headcount data */
mmerge prop klas_desa using "$other\headcount.dta"

mmerge hhea using `e'

drop _m

gen weight = (N*R)/8 if RTHEAD==0
replace weight = R if RTHEAD==1

/* Create poor/ near poor variable */

headcount CONSUMPTION [w=weight],hc(poorhc) gen(verypoor) by(prop klas) id(hhid_suseti)
drop newwgt 
rename pce pce_verypoor
rename povline povline_verypoor

headcount CONSUMPTION [w=weight],hc(nearpoorhc) gen(poor) by(prop klas) id(hhid_suseti)
rename pce pce_poor
rename povline povline_poor

** this ado files create dupplicate observation so that it could cut the povline
bys hhid_suseti: keep if _n==1

/* Create inclusion/exclusion dummies */

forvalue j = 1/2 {
	gen rts = RTS if `j'==1
	replace rts = RTS_meeting if `j'==2

	gen MISTARGETDUMMY_`j' = 1 if poor==1 & rts==0
	replace MISTARGETDUMMY_`j' = 1 if poor==0 & rts==1
	replace MISTARGETDUMMY_`j' = 0 if MISTARGETDUMMY_`j'==.

	gen MISTARGETRICHDUMMY_`j' = 1 if poor==0 & rts==1
	replace MISTARGETRICHDUMMY_`j' = 0 if poor==0 & rts==0

	gen MISTARGETPOORDUMMY_`j' = 1 if poor==1 & rts==0
	replace MISTARGETPOORDUMMY_`j' = 0 if poor==1 & rts==1

	gen MISTARGETVERYPOORDUMMY_`j' = 1 if verypoor==1 & rts==0
	replace MISTARGETVERYPOORDUMMY_`j' = 0 if verypoor==1 & rts==1

	gen MISTARGETRICHDUMMY_pol_`j' = 1 if poor==0 & rts==1
	replace MISTARGETRICHDUMMY_pol_`j' = 0 if poor==1 & rts==1

	gen povertygap_`j' = abs(CONSUMPTION - povline_poor)/povline_poor if MISTARGETDUMMY_`j' == 1
	replace povertygap_`j' = 0 if MISTARGETDUMMY_`j' == 0

	drop rts
}

gen ELITEHYBRID = ELITE * HYBRID
gen ELITEPOOREST10 = ELITE * POOREST10
gen ELITEDAYMEETING = ELITE * DAYMEETING

tempfile g
save `g', replace


// merge with variables in analysis 0

use "$codeddata\intermediate_data\analysis0.dta", clear
rename CONSUMPTION avg_CONSUMPTION 
rename EDUCATIONHHHEAD avg_EDUCATIONHHHEAD 
rename PMTSCORE avg_PMTSCORE
mmerge hhea using `g'

sort hhid_suseti
compress
save "$codeddata/intermediate_data/analysis1_hh.dta", replace


*******************************

/* Average marginal utility gain from the transfer */

use "$codeddata/intermediate_data/analysis1_hh.dta", clear

bys hhea: gen Nsample=_N
label var Nsample "number of samples in RT"

forvalue j = 1/2 {
	gen rts = RTS if `j'==1
	replace rts = RTS_meeting if `j'==2

	gen u_`j' = -1 * CONSUMPTION
	gen uB_`j' = u_`j' if rts==1

	replace uB_`j' = 0 if uB_`j'==.
	egen sum_uB_`j' = sum(uB_`j'), by(hhea)

	gen uN_`j' = u_`j'
	egen sum_uN_`j' = sum(uN_`j'), by(hhea)

	forvalue i = 1/5 {
		gen CRRA`i'_`j' = CONSUMPTION^(-1*`i')
	
		gen CRRA`i'B_`j' = CRRA`i'_`j' if rts==1
		replace CRRA`i'B_`j' = 0 if uB_`j'==.
		egen sum_CRRA`i'B_`j' = sum(CRRA`i'B_`j'), by(hhea)
	
		gen CRRA`i'N_`j' = CRRA`i'_`j'
		egen sum_CRRA`i'N_`j' = sum(CRRA`i'N_`j'), by(hhea)
	}

	replace rts = 0 if rts==.
	egen B_`j' = sum(rts), by(hhea)
	label var B_`j' "number of benefeciaries in RT"

	gen Mu_`j' = (sum_uB_`j'/B_`j') - (sum_uN_`j'/N)

	forvalue i = 1/5 {
		gen MCRRA`i'_`j' = (sum_CRRA`i'B_`j'/B_`j') - (sum_CRRA`i'N_`j'/N)
	}

	drop rts
}

keep kecagroup hhea maintreatment klas ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING sum* Mu* MC* B* Nsample avg_* SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH
bys hhea: keep if _n==1

sort hhea
compress
save "$codeddata/intermediate_data/analysis1_village.dta", replace


*********************************

* Also Individual level regression

use "$codeddata/intermediate_data/analysis1_hh.dta", clear

forvalue j = 1/2 {
	gen rts = RTS if `j'==1
	replace rts = RTS_meeting if `j'==2

	gen Mu_`j' = CONSUMPTION if rts==1
	replace Mu_`j' = -1* CONSUMPTION if rts==0

	forvalue i = 1/5 {
		gen CRRA`i'_`j' = CONSUMPTION^(-1*`i') if rts==1
		replace CRRA`i'_`j' =-1 * CONSUMPTION^(-1*`i') if rts==0
	}
	drop rts
}

sort hhid_suseti
compress
save "$codeddata/intermediate_data/analysis1_hha.dta", replace




/*
***********************************

/* Regression mistarget */

use "codeddata/intermediate_data/analysis1_hh.dta", clear


***** Version 1 : Hybrid is from experiment
***** Version 2 : Hybrid is from the meeting

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

forvalue j = 1/2 {

	/* No fixed effect */

	*** BASIC

	regress MISTARGETDUMMY_`j' COMMUNITY HYBRID, cluster(hhea)
	outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster replace

	regress MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID, cluster(hhea)
	outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append

	regress MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, cluster(hhea)
	outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append

	foreach var of varlist MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j'  {
		regress `var' COMMUNITY HYBRID, cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID, cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append
	}

	*** EXTENDED VARIABEL

	foreach var of varlist MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
		regress `var' COMMUNITY HYBRID `extvar', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'.xls", se 3aster append
	}


	/* fixed effect */

	areg MISTARGETDUMMY_`j' COMMUNITY HYBRID, absorb(kecagroup) cluster(hhea)
	outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster replace

	areg MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID, absorb(kecagroup) cluster(hhea)
	outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append

	areg MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, absorb(kecagroup) cluster(hhea)
	outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append

	foreach var of varlist MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
		areg `var' COMMUNITY HYBRID, absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID, absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append
	}

	*** EXTENDED VARIABEL

	foreach var of varlist MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j'  {
		areg `var' COMMUNITY HYBRID `extvar', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'.xls", se bdec(3,3,3) 3aster append
	}


}

***** Urban/ Rural

forvalues k = 1/2 {
	
	forvalue j = 1/2 {

		/* No fixed effect */

		regress MISTARGETDUMMY_`j' COMMUNITY HYBRID if klas==`k', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster replace

		regress MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append

		regress MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append


		foreach var of varlist MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			regress `var' COMMUNITY HYBRID if klas==`k', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append
		}

		foreach var of varlist MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			regress `var' COMMUNITY HYBRID `extvar' if klas==`k', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar' if klas==`k', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar' if klas==`k', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_kladesa`k'.xls", se 3aster append
		}

		/* fixed effect */

		areg MISTARGETDUMMY_`j' COMMUNITY HYBRID if klas==`k', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster replace

		areg MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append

		areg MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append

		foreach var of varlist MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			areg `var' COMMUNITY HYBRID if klas==`k', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append
		}

		foreach var of varlist MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			areg `var' COMMUNITY HYBRID `extvar' if klas==`k', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar' if klas==`k', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar' if klas==`k', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_kladesa`k'.xls", se bdec(3,3,3) 3aster append
		}

	}

}

***** RT head/non RT head

forvalues RT = 0/1 {
	
	forvalue j = 1/2 {

		/* No fixed effect */

		regress MISTARGETDUMMY_`j' COMMUNITY HYBRID if RTHEAD==`RT', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster replace

		regress MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append

		regress MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', cluster(hhea)
		outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append


		foreach var of varlist MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			regress `var' COMMUNITY HYBRID if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append
		}

		foreach var of varlist MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			regress `var' COMMUNITY HYBRID `extvar' if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar' if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar' if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hh_nofe_ver`j'_RT`RT'.xls", se 3aster append
		}

		/* fixed effect */

		areg MISTARGETDUMMY_`j' COMMUNITY HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster replace

		areg MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append

		areg MISTARGETDUMMY_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append

		foreach var of varlist MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			areg `var' COMMUNITY HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append
		}

		foreach var of varlist MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' povertygap_`j' {
			areg `var' COMMUNITY HYBRID `extvar' if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar' if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar' if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hh_fe_ver`j'_RT`RT'.xls", se bdec(3,3,3) 3aster append
		}

	}

}





********************************

/* Regression village */

use "codeddata/analysis1_village.dta", clear

local extvar_vill "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"


forvalue j = 1/2 {

	/* No fixed effect */

	regress Mu_`j' COMMUNITY HYBRID [aw=B_`j']
	outreg using "$output\analysis1_vill_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster replace

	regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID [aw=B_`j']
	outreg using "$output\analysis1_vill_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

	regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING [aw=B_`j']
	outreg using "$output\analysis1_vill_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append


	foreach var of varlist MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
		regress `var' COMMUNITY HYBRID [aw=B_`j']
		outreg using "$output\analysis1_vill_nofe_ver`j'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID [aw=B_`j']
		outreg using "$output\analysis1_vill_nofe_ver`j'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING [aw=B_`j']
		outreg using "$output\analysis1_vill_nofe_ver`j'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
	}

	foreach var of varlist Mu_`j' MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
		regress `var' COMMUNITY HYBRID `extvar_vill' [aw=B_`j']
		outreg using "$output\analysis1_vill_nofe_ver`j'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill' [aw=B_`j']
		outreg using "$output\analysis1_vill_nofe_ver`j'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' [aw=B_`j']
		outreg using "$output\analysis1_vill_nofe_ver`j'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
	}

}


******** URBAN/RURAL

forvalue k = 1/2 {

	forvalue j = 1/2 {

		/* No fixed effect */

		regress Mu_`j' COMMUNITY HYBRID [aw=B_`j'] if klas==`k'
		outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster replace

		regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID [aw=B_`j'] if klas==`k'
		outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

		regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING [aw=B_`j'] if klas==`k'
		outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append


		foreach var of varlist MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
			regress `var' COMMUNITY HYBRID [aw=B_`j'] if klas==`k'
			outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID [aw=B_`j'] if klas==`k'
			outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING [aw=B_`j'] if klas==`k'
			outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
		}

		foreach var of varlist Mu_`j' MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
			regress `var' COMMUNITY HYBRID `extvar_vill' [aw=B_`j'] if klas==`k'
			outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill' [aw=B_`j'] if klas==`k'
			outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' [aw=B_`j'] if klas==`k'
			outreg using "$output\analysis1_vill_nofe_ver`j'_kladesa`k'.xls", bdec(5,5,5) bfmt(e,e,e) se 3aster append
		}

	}

}


/* Random effect */

xtset kecagroup

forvalue j = 1/2 {

	xtreg Mu_`j' COMMUNITY HYBRID, re
	outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster replace

	xtreg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID , re
	outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

	xtreg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, re
	outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

	foreach var of varlist MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
		xtreg `var' COMMUNITY HYBRID, re
		outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		xtreg `var' ELITE POOREST10 DAYMEETING HYBRID, re
		outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		xtreg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, re
		outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

	foreach var of varlist Mu_`j' MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
		xtreg `var' COMMUNITY HYBRID `extvar_vill', re
		outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		xtreg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill', re
		outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		xtreg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill', re
		outreg using "$output\analysis1_vill_re_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

}


*********** URBAN/RURAL

forvalue k = 1/2 {

	forvalue j = 1/2 {

		xtreg Mu_`j' COMMUNITY HYBRID if klas==`k', re
		outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster replace

		xtreg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID if klas==`k' , re
		outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

		xtreg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', re
		outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

		foreach var of varlist MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
			xtreg `var' COMMUNITY HYBRID if klas==`k', re
			outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			xtreg `var' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', re
			outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			xtreg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', re
			outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}	


		foreach var of varlist Mu_`j' MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
			xtreg `var' COMMUNITY HYBRID `extvar_vill' if klas==`k', re
			outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			xtreg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill'  if klas==`k', re
			outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			xtreg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' if klas==`k', re
			outreg using "$output\analysis1_vill_re_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}	
	}	
}


/* fixed effect */


forvalue j = 1/2 {

	areg Mu_`j' COMMUNITY HYBRID [aw=B_`j'], absorb(kecagroup)
	outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster replace

	areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID [aw=B_`j'], absorb(kecagroup)
	outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

	areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING [aw=B_`j'], absorb(kecagroup)
	outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

	foreach var of varlist MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
		areg `var' COMMUNITY HYBRID [aw=B_`j'], absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID [aw=B_`j'], absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING [aw=B_`j'], absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

	foreach var of varlist Mu_`j' MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
		areg `var' COMMUNITY HYBRID `extvar_vill' [aw=B_`j'], absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill' [aw=B_`j'], absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' [aw=B_`j'], absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

}

*********** URBAN/RURAL

forvalue k = 1/2 {

	forvalue j = 1/2  {

		areg Mu_`j' COMMUNITY HYBRID if klas==`k', absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster replace

		areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID if klas==`k' , absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

		areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', absorb(kecagroup)
		outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append

		foreach var of varlist MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
			areg `var' COMMUNITY HYBRID if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}	


		foreach var of varlist Mu_`j' MCRRA1_`j' MCRRA2_`j' MCRRA3_`j' MCRRA4_`j' MCRRA5_`j'  {
			areg `var' COMMUNITY HYBRID `extvar_vill' if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill'  if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis1_vill_fe_ver`j'_kladesa`k'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}	
	}	
}






*******************

**Individual level regression

use "$codeddata/analysis1_hha.dta", clear


local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

forvalue j = 1/2 {

	/* No fixed effect */

	*** BASIC

	regress Mu_`j' COMMUNITY HYBRID, cluster(hhea)
	outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) 3aster replace

	regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID, cluster(hhea)
	outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) 3aster append

	regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, cluster(hhea)
	outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) 3aster append

	foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
		regress `var' COMMUNITY HYBRID, cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID, cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

	*** EXTENDED VARIABEL

	foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
		regress `var' COMMUNITY HYBRID `extvar', cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar', cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar', cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}


	/* fixed effect */

	areg Mu_`j' COMMUNITY HYBRID, absorb(kecagroup) cluster(hhea)
	outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) 3aster replace

	areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID, absorb(kecagroup) cluster(hhea)
	outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) 3aster append

	areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, absorb(kecagroup) cluster(hhea)
	outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) 3aster append

	foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
		areg `var' COMMUNITY HYBRID, absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID, absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

	*** EXTENDED VARIABEL

	foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
		areg `var' COMMUNITY HYBRID `extvar', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
	}

}


/* With RT HEAD/ Without RT head */

forvalue RT = 0/1 {
	
	forvalue j = 1/2 {

		/* No fixed effect */

		*** BASIC

		regress Mu_`j' COMMUNITY HYBRID if RTHEAD==`RT', cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) 3aster replace

		regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) 3aster append

		regress Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', cluster(hhea)
		outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) 3aster append

		foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
			regress `var' COMMUNITY HYBRID if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}

		*** EXTENDED VARIABEL

		foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
			regress `var' COMMUNITY HYBRID `extvar' if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID `extvar' if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			regress `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar' if RTHEAD==`RT', cluster(hhea)
			outreg using "$output\analysis1_hha_nofe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}


		/* fixed effect */

		areg Mu_`j' COMMUNITY HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) 3aster replace

		areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) 3aster append

		areg Mu_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
		outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) 3aster append

		foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
			areg `var' COMMUNITY HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}

		*** EXTENDED VARIABEL

		foreach var of varlist CRRA1_`j' CRRA2_`j' CRRA3_`j' CRRA4_`j' CRRA5_`j'  {
			areg `var' COMMUNITY HYBRID `extvar' if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID `extvar' if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
			areg `var' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar' if RTHEAD==`RT', absorb(kecagroup) cluster(hhea)
			outreg using "$output\analysis1_hha_fe_ver`j'_RT`RT'.xls", se bdec(5,5,5) bfmt(e,e,e) 3aster append
		}
	}
}

*/

log close
