/* Analysis 2: Rank correlations */

/* Create hhtreatrank.dta, analysis2.dta */
/* Last Modified 31 Dec 2009 */

clear
set more off
set mem 256m

version 10

set sortseed 10000


capture log close
log using "$output\Coding_files_output\analysis2.log",replace


********************

/* Create CONSRANK = consumtion rank */

use "$codeddata\intermediate_data\consumption.dta", clear
keep hhid rank_pcexp RANKCONSUMPTION
rename RANKCONSUMPTION CONSRANK
tempfile c
save `c', replace

/* Create COMMRANK  */

use "$codeddata\intermediate_data\RANK.dta", clear
mmerge hhid using "$codeddata/intermediate_data/rthead"
drop ar00 EDUCATIONRTHEAD hhcov5
drop if _m==2
replace RTHEAD = 0 if RTHEAD==.
tempfile c1
save `c1', replace

use "$codeddata/intermediate_data/rthead", clear
keep hhid RTHEAD
rename hhid hhid_who_rank
rename RTHEAD RTHEAD_who_rank
mmerge hhid_who_rank using `c1'
drop _m
replace RTHEAD_who_rank = 0 if RTHEAD_who_rank==.
tempfile c2
save `c2', replace

** INCLUDING RTHEAD
use `c2', clear

collapse (mean) mean_rank_RTA = rank, by(hhid)
label var mean_rank_RTA "mean rank from all community (including RT HEAD)"

gen hhea = substr(hhid,1,3)
sort hhea mean_rank_RTA

egen nhhrank_RTA=max(mean_rank_RTA)
label var nhhrank_RTA "number of household in village (including RT HEAD)"

gen COMMRANK_RTA= mean_rank_RTA/nhhrank_RTA
label var COMMRANK_RTA "percentile community rank in suseti data"
tempfile c3
save `c3', replace

** EXCLUDING RTHEAD

use `c2', replace

drop if RTHEAD_who_rank==1
drop if RTHEAD==1
sort hhid_who_rank rank

bys hhid_who_rank: gen x=_n
gen rank_RT0 = x
drop x

collapse (mean) mean_rank_RT0 = rank_RT0, by(hhid)
label var mean_rank_RT0 "mean rank from community (excluding RT HEAD)"

gen hhea = substr(hhid,1,3)
sort hhea mean_rank_RT0

egen nhhrank_RT0=max(mean_rank_RT0)
label var nhhrank_RT0 "number of household in village (excluding RT HEAD)"

gen COMMRANK_RT0= mean_rank/nhhrank
label var COMMRANK_RT0 "percentile community rank in suseti data"

mmerge hhid using `c3', type(1:1)

drop _m
tempfile c4
save `c4', replace

** RT HEAD ONLY

use `c2', replace
keep if RTHEAD_who_rank==1

gen COMMRANK_RT1= RANK
label var COMMRANK_RT1 "percentile community rank in suseti data (only RT HEAD)"

mmerge hhid using `c4', type(1:1)
drop _m
tempfile c5
save `c5', replace

** MAIN

use `c2', replace

drop if RTHEAD_who_rank==1
sort hhid_who_rank rank

bys hhid_who_rank: gen x=_n
gen rank_main = x
drop x

collapse (mean) mean_rank_main = rank_main, by(hhid)
label var mean_rank_main "mean rank from community (excluding RT HEAD)"

gen hhea = substr(hhid,1,3)
sort hhea mean_rank_main

egen nhhrank_main=max(mean_rank_main)
label var nhhrank_main "number of household in village (excluding RT HEAD)"

gen COMMRANK_main= mean_rank_main/nhhrank_main
label var COMMRANK_main "percentile community rank in suseti data"

mmerge hhid using `c5', type(1:1)

compress
sort hhid
save "$codeddata/intermediate_data/COMMRANK.dta", replace

mmerge hhid using `c', type(1:1) /* It is not perfectly merge because interviewer only interviewed households from fisrt samples. In other words, substitute households were not ranked */
drop if _m==1
drop _m

/* Merge with subjective rank */

mmerge hhid using "$codeddata/intermediate_data/hh_sw.dta", type(1:1)

rename hhid hhid_suseti

/* Merge with treatment rank */

mmerge hhid_suseti using "$codeddata/intermediate_data/hhrts.dta", type(1:1)

replace TREATRANK_2 = TREATRANK if main ==1

drop hhea
gen hhea = substr(hhid_suseti,1,3)
destring hhea, replace
sort hhea
drop _m
tempfile d
save `d', replace

/* Merge with method */

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea prop  kab kec desa klas kecagroup numhhsls_dec  maintreatment tokohsubtreatment poor10subtreatment daynightsubtreatment

gen COMMUNITY = (maintreatment==2)
gen HYBRID = (maintreatment==3)

rename tokohsubtreatment ELITE 
rename poor10subtreatment POOREST10 
gen DAYMEETING = (daynightsubtreatment==0)

gen ELITEHYBRID = ELITE * HYBRID
gen ELITEPOOREST10 = ELITE * POOREST10
gen ELITEDAYMEETING = ELITE * DAYMEETING

mmerge hhea using `d'

drop _m
tempfile e
save `e', replace

/* Create rank correlation treatment, consumption and community All */

use `e', clear
drop COMMRANK_RT1 mean_rank_RT0 nhhrank_RT0 COMMRANK_RT0 mean_rank_main nhhrank_main COMMRANK_main

rename TREATRANK TREATRANK_1
gen RANKCORRTREATCONSUMPTION_1=.
gen RANKCORRTREATCOMMUNITY_1=.
gen RANKCORRTREATSW02_1=.
gen RANKCORRTREATSW03_1=.

gen RANKCORRTREATCONSUMPTION_2=.
gen RANKCORRTREATCOMMUNITY_2=.
gen RANKCORRTREATSW02_2=.
gen RANKCORRTREATSW03_2=.

forvalue j = 1/2 {
	forvalue i = 1/640 {
		qui spearman TREATRANK_`j' CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_`j'=r(rho) if hhea==`i'
	
		qui spearman TREATRANK_`j' COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_`j'=r(rho) if hhea==`i'
	}
}

save "$codeddata/intermediate_data/hhtreatrank_RTA.dta", replace

keep kecagroup hhea klas maintreatment ranking_meeting ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING RANK* 

bys hhea: keep if _n==1

// merge with variables in analysis 0

mmerge hhea using "$codeddata\intermediate_data\analysis0.dta"

compress

save "$codeddata/intermediate_data/analysis2_RTA.dta", replace


******************************************
// sample without RT Head

use `e', clear

drop COMMRANK_RT1 mean_rank_RTA nhhrank_RTA COMMRANK_RTA mean_rank_main nhhrank_main COMMRANK_main

rename TREATRANK TREATRANK_1
gen RANKCORRTREATCONSUMPTION_1=.
gen RANKCORRTREATCOMMUNITY_1=.
gen RANKCORRTREATSW02_1=.
gen RANKCORRTREATSW03_1=.

gen RANKCORRTREATCONSUMPTION_2=.
gen RANKCORRTREATCOMMUNITY_2=.
gen RANKCORRTREATSW02_2=.
gen RANKCORRTREATSW03_2=.

forvalue j = 1/2 {
	forvalue i = 1/640 {
		qui spearman TREATRANK_`j' CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_`j'=r(rho) if hhea==`i'
	
		qui spearman TREATRANK_`j' COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_`j'=r(rho) if hhea==`i'
	}
}

save "$codeddata/intermediate_data/hhtreatrank_RT0.dta", replace

keep kecagroup hhea klas maintreatment ranking_meeting ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING RANK* 

bys hhea: keep if _n==1

// merge with variables in analysis 0


mmerge hhea using "$codeddata\intermediate_data\analysis0.dta"

compress

save "$codeddata/intermediate_data/analysis2_RT0.dta", replace

******************************************
// sample with only RT Head

use `e', clear
drop mean_rank_RTA nhhrank_RTA COMMRANK_RTA mean_rank_RT0 nhhrank_RT0 COMMRANK_RT0 mean_rank_main nhhrank_main COMMRANK_main


rename TREATRANK TREATRANK_1
gen RANKCORRTREATCONSUMPTION_1=.
gen RANKCORRTREATCOMMUNITY_1=.
gen RANKCORRTREATSW02_1=.
gen RANKCORRTREATSW03_1=.

gen RANKCORRTREATCONSUMPTION_2=.
gen RANKCORRTREATCOMMUNITY_2=.
gen RANKCORRTREATSW02_2=.
gen RANKCORRTREATSW03_2=.

forvalue j = 1/2 {
	forvalue i = 1/640 {
		qui spearman TREATRANK_`j' CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_`j'=r(rho) if hhea==`i'
	
		qui spearman TREATRANK_`j' COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_`j'=r(rho) if hhea==`i'
	}
}

save "$codeddata/intermediate_data/hhtreatrank_RT1.dta", replace

keep kecagroup hhea klas maintreatment ranking_meeting ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING RANK* 

bys hhea: keep if _n==1

// merge with variables in analysis 0

mmerge hhea using "$codeddata\intermediate_data\analysis0.dta"

compress

save "$codeddata/intermediate_data/analysis2_RT1.dta", replace

******************************************
// Main

use `e', clear
drop mean_rank_RTA nhhrank_RTA COMMRANK_RTA mean_rank_RT0 nhhrank_RT0 COMMRANK_RT0 COMMRANK_RT1


rename TREATRANK TREATRANK_1
gen RANKCORRTREATCONSUMPTION_1=.
gen RANKCORRTREATCOMMUNITY_1=.
gen RANKCORRTREATSW02_1=.
gen RANKCORRTREATSW03_1=.

gen RANKCORRTREATCONSUMPTION_2=.
gen RANKCORRTREATCOMMUNITY_2=.
gen RANKCORRTREATSW02_2=.
gen RANKCORRTREATSW03_2=.

forvalue j = 1/2 {
	forvalue i = 1/640 {
		qui spearman TREATRANK_`j' CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_`j'=r(rho) if hhea==`i'
	
		qui spearman TREATRANK_`j' COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_`j'=r(rho) if hhea==`i'

		qui spearman TREATRANK_`j' RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_`j'=r(rho) if hhea==`i'
	}
}

save "$codeddata/intermediate_data/hhtreatrank_main.dta", replace

keep kecagroup hhea klas maintreatment ranking_meeting ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING RANK* 

bys hhea: keep if _n==1

// merge with variables in analysis 0

mmerge hhea using "$codeddata\intermediate_data\analysis0.dta"

compress

save "$codeddata/intermediate_data/analysis2_main.dta", replace



/*******************************


/* Analysis of actual distribution */

use "codeddata/intermediate_data/analysis2_main.dta", clear

local extvar_vill "CONSUMPTION EDUCATIONHHHEAD PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

forvalues j = 1/2 {

	foreach var in "CONSUMPTION" "COMMUNITY" "SW02" "SW03" {

		/* No fixed effect */
		
		regress RANKCORRTREAT`var'_`j' COMMUNITY HYBRID
		outreg using "$output\analysis2_`var'_nofe_ver`j'.xls", se 3aster replace
		regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID
		outreg using "$output\analysis2_`var'_nofe_ver`j'.xls", se 3aster append
		regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING
		outreg using "$output\analysis2_`var'_nofe_ver`j'.xls", se 3aster append

		regress RANKCORRTREAT`var'_`j' COMMUNITY HYBRID `extvar_vill'
		outreg using "$output\analysis2_`var'_nofe_ver`j'.xls", se 3aster append
		regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill'
		outreg using "$output\analysis2_`var'_nofe_ver`j'.xls", se 3aster append
		regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill'
		outreg using "$output\analysis2_`var'_nofe_ver`j'.xls", se 3aster append


		/* fixed effect */

		areg RANKCORRTREAT`var'_`j' COMMUNITY HYBRID, absorb(kecagroup)
		outreg using "$output\analysis2_`var'_fe_ver`j'.xls", se 3aster replace
		areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID, absorb(kecagroup)
		outreg using "$output\analysis2_`var'_fe_ver`j'.xls", se 3aster append
		areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID  ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, absorb(kecagroup)
		outreg using "$output\analysis2_`var'_fe_ver`j'.xls", se 3aster append

		areg RANKCORRTREAT`var'_`j' COMMUNITY HYBRID `extvar_vill', absorb(kecagroup)
		outreg using "$output\analysis2_`var'_fe_ver`j'.xls", se 3aster append
		areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill', absorb(kecagroup)
		outreg using "$output\analysis2_`var'_fe_ver`j'.xls", se 3aster append
		areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID  ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill', absorb(kecagroup)
		outreg using "$output\analysis2_`var'_fe_ver`j'.xls", se 3aster append

	}
}


****** URBAN/RURAL

forvalues k = 1/2 {

	forvalues j = 1/2 {

		foreach var in "CONSUMPTION" "COMMUNITY" "SW02" "SW03" {

			/* No fixed effect */
		
			regress RANKCORRTREAT`var'_`j' COMMUNITY HYBRID if klas==`k'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_kladesa`k'.xls", se 3aster replace
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID if klas==`k'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_kladesa`k'.xls", se 3aster append

			regress RANKCORRTREAT`var'_`j' COMMUNITY HYBRID `extvar_vill' if klas==`k'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill' if klas==`k'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_kladesa`k'.xls", se 3aster append
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' if klas==`k'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_kladesa`k'.xls", se 3aster append


			/* fixed effect */

			areg RANKCORRTREAT`var'_`j' COMMUNITY HYBRID if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_kladesa`k'.xls", se 3aster replace
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_kladesa`k'.xls", se 3aster append
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID  ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_kladesa`k'.xls", se 3aster append

			areg RANKCORRTREAT`var'_`j' COMMUNITY HYBRID `extvar_vill' if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_kladesa`k'.xls", se 3aster append
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill' if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_kladesa`k'.xls", se 3aster append
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID  ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill' if klas==`k', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_kladesa`k'.xls", se 3aster append

		}
	}

}

********************************

// RT Head/No RT Head

/* Analysis of actual distribution */

local extvar_vill "CONSUMPTION EDUCATIONHHHEAD PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

forvalues k =0/1 {

	use "$codeddata/analysis2_RT`k'.dta", clear

	forvalues j = 1/2 {

		foreach var in "CONSUMPTION" "COMMUNITY" "SW02" "SW03"{

			/* No fixed effect */
		
			regress RANKCORRTREAT`var'_`j' COMMUNITY HYBRID
			outreg using "$output\analysis2_`var'_nofe_ver`j'_RT`k'.xls", se 3aster replace
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID
			outreg using "$output\analysis2_`var'_nofe_ver`j'_RT`k'.xls", se 3aster append
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING
			outreg using "$output\analysis2_`var'_nofe_ver`j'_RT`k'.xls", se 3aster append

			regress RANKCORRTREAT`var'_`j' COMMUNITY HYBRID `extvar_vill'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_RT`k'.xls", se 3aster append
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_RT`k'.xls", se 3aster append
			regress RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill'
			outreg using "$output\analysis2_`var'_nofe_ver`j'_RT`k'.xls", se 3aster append


			/* fixed effect */

			areg RANKCORRTREAT`var'_`j' COMMUNITY HYBRID, absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_RT`k'.xls", se 3aster replace
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID, absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_RT`k'.xls", se 3aster append
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID  ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING, absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_RT`k'.xls", se 3aster append

			areg RANKCORRTREAT`var'_`j' COMMUNITY HYBRID `extvar_vill', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_RT`k'.xls", se 3aster append
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID `extvar_vill', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_RT`k'.xls", se 3aster append
			areg RANKCORRTREAT`var'_`j' ELITE POOREST10 DAYMEETING HYBRID  ELITEHYBRID ELITEPOOREST10 ELITEDAYMEETING `extvar_vill', absorb(kecagroup)
			outreg using "$output\analysis2_`var'_fe_ver`j'_RT`k'.xls", se 3aster append

		}
	}

}

*/

log close
