/* Analysis 3: Interactions: Elites, geographic and other characteristic */

/* Create analysis3.dta */
/* Last Modified 31 Dec 2009 */

clear
set more off
set mem 256m

version 10

set sortseed 10000

capture log close
log using "$output\Coding_files_output\analysis3.log",replace


********************

/* Community level interation */

/* Urban/Rural */
use "$codeddata/intermediate_data/coding_treatment.dta", clear
keep desaid hhea klas
gen urban = (klas==1)
drop klas

/* Merge with Inequality */

mmerge hhea using "$codeddata/intermediate_data/inequality.dta"

tempfile d1
save `d1', replace

/* Create P2kp experience */
use "$data/other/urban village.dta", clear
keep vill
rename vill desaid
gen p2kp = 1
label var p2kp "P2KP experience"

mmerge desaid using `d1'
drop if _m==1
replace p2kp = 0 if _m==2
drop _m
tempfile d2
save `d2', replace

/* merge with number of households being ranked */
use "$codeddata\intermediate_data\f7b_ranking.dta", clear
keep hhea nhhrank
bys hhea: keep if _n==1
destring hhea, replace

mmerge hhea using `d2'
drop _m
tempfile d3
save `d3', replace

/* Oligarchy measure: Is ketua RT family with any other village official? */

use "$codeddata\intermediate_data\hh_cr01.dta", clear
mmerge hhid using "$codeddata\intermediate_data\rthead.dta"
drop if _m==1
drop _m
sort hhid_cr01
tempfile d4
save `d4', replace

use "$codeddata\intermediate_data\formalleader.dta", clear
rename hhid hhid_cr01 
mmerge hhid_cr01 using `d4'
drop if _m==1

replace  FORMALLEADER = 0 if FORMALLEADER==.
collapse (sum) obligarchy = FORMALLEADER, by(hhea)
replace obligarchy = 1 if obligarchy>=1
label var obligarchy "Is ketua RT family with any other village official?"

destring hhea, replace

mmerge hhea using `d3'
drop _m

/* merge with Household level interaction */

mmerge hhea using "$codeddata\intermediate_data\aggregatevar.dta"
gen elite_connectD = 1 if elite_connectedness>0
replace elite_connectD = 0 if elite_connectedness==0

rename hhid hhid_suseti
tempfile d
save `d', replace


/* merge with hhrts & hhtreatrank */

use "$codeddata/intermediate_data/analysis1_hh.dta", clear
keep kecagroup hhea maintreatment ELITE POOREST10 daynightsubtreatment COMMUNITY HYBRID DAYMEETING hhid_suseti hhid_exp RTS* verypoor MIS* ELITEHYBRID ELITEPOOREST10 ELITEPOOREST10 CONSUMPTION LOGCONSUMPTION
mmerge hhid_suseti using `d', type(1:1)

tempfile e
save `e', replace

use "$codeddata/intermediate_data/hhtreatrank_main.dta", clear
keep hhid* TREATRANK* COMMRANK CONSRANK
rename COMMRANK_main COMMRANK
mmerge hhid_suseti using `e', type(1:1)

drop _m
tempfile f
save `f', replace

/* merge with minority */

use "$codeddata/intermediate_data/minority.dta", clear
rename hhid hhid_suseti
mmerge hhid_suseti using `f', ty(1:1)
drop _m
tempfile g
save `g', replace

/* merge with geogra isolated */


use "$codeddata/intermediate_data/coding_gps.dta", clear
keep hhid hhea dist_RTHEAD isolated
rename hhid hhid_suseti
mmerge hhid_suseti using `g', ty(1:1)
drop _m

sort hhid_suseti
compress

save "$codeddata/analysis3.dta", replace

*******************************

/*
use "codeddata/analysis3.dta", clear

local X1 "shock conspicuousness connectedness elite_connectedness verypoor"
local V "urban inequality avg_connectedness"
local X2 "ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW conspicuousness connectedness elite_connectD verypoor"
local X3 "shock conspicuousness connectedness elite_connectedness verypoor  ETHICMINORITY RELIGIOUSMINORITY isolated"
local X4 "shock conspicuousness_2 elite_connectedness verypoor  ETHICMINORITY RELIGIOUSMINORITY isolated"
local X5 "shock conspicuousness_2 elite_connectedness ETHICMINORITY RELIGIOUSMINORITY isolated"

foreach var in shock conspicuousness connectedness elite_connectedness verypoor urban inequality avg_connectedness ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW elite_connectD  ETHICMINORITY RELIGIOUSMINORITY conspicuousness_2 isolated{
	gen C_`var' = COMMUNITY*`var'
	gen H_`var' = HYBRID*`var'
	gen E_`var' = ELITE*`var'
	gen E_H_`var' = ELITE*HYBRID*`var'
	gen LC_`var' = LOGCONSUMPTION*`var'
}

local COMMUNITY_X1 "C_shock C_conspicuousness C_connectedness C_elite_connectedness C_verypoor"
local HYBRID_X1 "H_shock H_conspicuousness H_connectedness H_elite_connectedness H_verypoor"
local ELITE_X1 "E_shock E_conspicuousness E_connectedness E_elite_connectedness E_verypoor"
local ELITEHYBRID_X1 "E_H_shock E_H_conspicuousness E_H_connectedness E_H_elite_connectedness E_H_verypoor"
local LOGCONSUMPTION_X1 "LC_shock LC_conspicuousness LC_connectedness LC_elite_connectedness LC_verypoor"

local COMMUNITY_V "C_urban C_inequality C_avg_connectedness"
local HYBRID_V "H_urban H_inequality H_avg_connectedness"
local ELITE_V "E_urban E_inequality E_avg_connectedness"
local ELITEHYBRID_V "E_H_urban E_H_inequality E_H_avg_connectedness"
local LOGCONSUMPTION_V "LC_urban LC_inequality LC_avg_connectedness"

local COMMUNITY_X2 "C_ge01a C_ge01b C_ge01c C_ge01d C_ge01e C_ge01f C_ge01g C_ge01h C_ge01v C_WIDOW C_conspicuousness C_connectedness C_elite_connectD C_verypoor"
local HYBRID_X2 "H_ge01a H_ge01b H_ge01c H_ge01d H_ge01e H_ge01f H_ge01g H_ge01h H_ge01v H_WIDOW H_conspicuousness H_connectedness H_elite_connectD H_verypoor"
local ELITE_X2 "E_ge01a E_ge01b E_ge01c E_ge01d E_ge01e E_ge01f E_ge01g E_ge01h E_ge01v E_WIDOW E_conspicuousness E_connectedness E_elite_connectD E_verypoor"
local ELITEHYBRID_X2 "E_H_ge01a E_H_ge01b E_H_ge01c E_H_ge01d E_H_ge01e E_H_ge01f E_H_ge01g E_H_ge01h E_H_ge01v E_H_WIDOW E_H_conspicuousness E_H_connectedness E_H_elite_connectD E_H_verypoor"
local LOGCONSUMPTION_X2 "LC_ge01a LC_ge01b LC_ge01c LC_ge01d LC_ge01e LC_ge01f LC_ge01g LC_ge01h LC_ge01v LC_WIDOW LC_conspicuousness LC_connectedness LC_elite_connectD LC_verypoor"

local COMMUNITY_X3 "C_shock C_conspicuousness C_connectedness C_elite_connectedness C_verypoor C_ETHICMINORITY C_RELIGIOUSMINORITY C_isolated"
local HYBRID_X3 "H_shock H_conspicuousness H_connectedness H_elite_connectedness H_verypoor H_ETHICMINORITY H_RELIGIOUSMINORITY H_isolated"
local ELITE_X3 "E_shock E_conspicuousness E_connectedness E_elite_connectedness E_verypoor E_ETHICMINORITY E_RELIGIOUSMINORITY E_isolated"
local ELITEHYBRID_X3 "E_H_shock E_H_conspicuousness E_H_connectedness E_H_elite_connectedness E_H_verypoor E_H_ETHICMINORITY E_H_RELIGIOUSMINORITY E_H_isolated"
local LOGCONSUMPTION_X3 "LC_shock LC_conspicuousness LC_connectedness LC_elite_connectedness LC_verypoor LC_ETHICMINORITY LC_RELIGIOUSMINORITY LC_isolated"

local COMMUNITY_X4 "C_shock C_conspicuousness_2 C_elite_connectedness C_verypoor C_ETHICMINORITY C_RELIGIOUSMINORITY C_isolated"
local HYBRID_X4 "H_shock H_conspicuousness_2 H_elite_connectedness H_verypoor H_ETHICMINORITY H_RELIGIOUSMINORITY H_isolated"
local ELITE_X4 "E_shock E_conspicuousness_2 E_elite_connectedness E_verypoor E_ETHICMINORITY E_RELIGIOUSMINORITY E_isolated"
local ELITEHYBRID_X4 "E_H_shock E_H_conspicuousness_2 E_H_elite_connectedness E_H_verypoor E_H_ETHICMINORITY E_H_RELIGIOUSMINORITY E_H_isolated"
local LOGCONSUMPTION_X4 "LC_shock LC_conspicuousness_2 LC_elite_connectedness LC_verypoor LC_ETHICMINORITY LC_RELIGIOUSMINORITY LC_isolated"

local COMMUNITY_X5 "C_shock C_conspicuousness_2 C_elite_connectedness C_ETHICMINORITY C_RELIGIOUSMINORITY C_isolated"
local HYBRID_X5 "H_shock H_conspicuousness_2 H_elite_connectedness H_ETHICMINORITY H_RELIGIOUSMINORITY H_isolated"
local ELITE_X5 "E_shock E_conspicuousness_2 E_elite_connectedness E_ETHICMINORITY E_RELIGIOUSMINORITY E_isolated"
local ELITEHYBRID_X5 "E_H_shock E_H_conspicuousness_2 E_H_elite_connectedness E_H_ETHICMINORITY E_H_RELIGIOUSMINORITY E_H_isolated"
local LOGCONSUMPTION_X5 "LC_shock LC_conspicuousness_2 LC_elite_connectedness LC_ETHICMINORITY LC_RELIGIOUSMINORITY LC_isolated"

forvalues i= 1/5 {
	forvalues j= 1/2 {
		gen rts = RTS if `j'==1
		replace rts = RTS_meeting if `j'==2

		foreach var of varlist rts MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' {

			// Without LOG CONSUMPTION INTERACTION

			** No Fixed effec
			regress `var' LOGCONSUMPTION `X`i'' COMMUNITY HYBRID, cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster replace
			regress `var' LOGCONSUMPTION `X`i'' COMMUNITY HYBRID `COMMUNITY_X`i'' `HYBRID_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `V' COMMUNITY HYBRID `COMMUNITY_V' `HYBRID_V', cluster(hhea)	
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' COMMUNITY HYBRID `COMMUNITY_X`i'' `COMMUNITY_V' `HYBRID_X`i'' `HYBRID_V', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append

			regress `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING, cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING `ELITE_X`i'' `HYBRID_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `V' HYBRID ELITE POOREST10 DAYMEETING `ELITE_V' `HYBRID_V', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' HYBRID ELITE POOREST10 DAYMEETING `ELITE_X`i'' `ELITE_V' `HYBRID_X`i'' `HYBRID_V', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append

			regress `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_X`i'' `HYBRID_X`i'' `ELITEHYBRID_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `v' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_V' `HYBRID_V' `ELITEHYBRID_V', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_X`i'' `ELITE_V' `HYBRID_X`i'' `HYBRID_V' `ELITEHYBRID_X`i'' `ELITEHYBRID_`ELITEHYBRID_X`i''', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append

			** Fixed effect

			areg `var' LOGCONSUMPTION `X`i'' COMMUNITY HYBRID,absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster replace

			areg `var' LOGCONSUMPTION `X`i'' COMMUNITY HYBRID `COMMUNITY_X`i'' `HYBRID_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

			areg `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING,absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

			areg `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING `ELITE_X`i'' `HYBRID_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

			areg `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_X`i'' `HYBRID_X`i'' `ELITEHYBRID_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

			// With LOG CONSUMPTION INTERACTION

			** No Fixed effec
			regress `var' LOGCONSUMPTION `X`i'' COMMUNITY HYBRID `COMMUNITY_X`i'' `HYBRID_X`i'' `LOGCONSUMPTION_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `V' COMMUNITY HYBRID `COMMUNITY_V' `HYBRID_V' `LOGCONSUMPTION_V`i'', cluster(hhea)	
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' COMMUNITY HYBRID `COMMUNITY_X`i'' `COMMUNITY_V' `HYBRID_X`i'' `HYBRID_V' `LOGCONSUMPTION_X`i'' `LOGCONSUMPTION_V`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append

			regress `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING `ELITE_X`i'' `HYBRID_X`i'' `LOGCONSUMPTION_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `V' HYBRID ELITE POOREST10 DAYMEETING `ELITE_V' `HYBRID_V' `LOGCONSUMPTION_V`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' HYBRID ELITE POOREST10 DAYMEETING `ELITE_X`i'' `ELITE_V' `HYBRID_X`i'' `HYBRID_V' `LOGCONSUMPTION_X`i'' `LOGCONSUMPTION_V`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append

			regress `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_X`i'' `HYBRID_X`i'' `ELITEHYBRID_X`i'' `LOGCONSUMPTION_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `v' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_V' `HYBRID_V' `ELITEHYBRID_V' `LOGCONSUMPTION_V`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_X`i'' `ELITE_V' `HYBRID_X`i'' `HYBRID_V' `ELITEHYBRID_X`i'' `ELITEHYBRID_`ELITEHYBRID_X`i''' `LOGCONSUMPTION_X`i'' `LOGCONSUMPTION_V`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'.xls", se 3aster append

			** Fixed effect

			areg `var' LOGCONSUMPTION `X`i'' COMMUNITY HYBRID `COMMUNITY_X`i'' `HYBRID_X`i'' `LOGCONSUMPTION_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

			areg `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING `ELITE_X`i'' `HYBRID_X`i'' `LOGCONSUMPTION_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

			areg `var' LOGCONSUMPTION `X`i'' HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID `ELITE_X`i'' `HYBRID_X`i'' `ELITEHYBRID_X`i'' `LOGCONSUMPTION_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'.xls", se 3aster append

		}
		drop rts
	}
}

***** TREATRANK

use "codeddata/analysis3.dta", clear

local X1 "shock conspicuousness connectedness elite_connectedness verypoor"
local V "urban inequality avg_connectedness"
local X2 "ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW conspicuousness connectedness elite_connectD verypoor"
local X3 "shock conspicuousness connectedness elite_connectedness verypoor  ETHICMINORITY RELIGIOUSMINORITY isolated"
local X4 "shock conspicuousness_2 elite_connectedness verypoor  ETHICMINORITY RELIGIOUSMINORITY isolated"
local X5 "shock conspicuousness_2 elite_connectedness  ETHICMINORITY RELIGIOUSMINORITY isolated"

foreach var1 in CONSRANK COMMRANK {
	
	gen `var1'_C = `var1' * COMMUNITY
	gen `var1'_H = `var1' * HYBRID
	gen `var1'_E = `var1' * ELITE
	gen `var1'_P = `var1' * POOREST10
	gen `var1'_D = `var1' * DAYMEETING

	gen `var1'_E_H = `var1' * ELITE * HYBRID

	foreach var2 in shock conspicuousness connectedness elite_connectedness verypoor urban inequality avg_connectedness ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW elite_connectD ETHICMINORITY RELIGIOUSMINORITY conspicuousness_2 isolated{
		gen `var1'_C_`var2' = `var1' * COMMUNITY * `var2'
		gen `var1'_H_`var2' = `var1' * HYBRID * `var2'
		gen `var1'_E_`var2' = `var1' * ELITE * `var2'
		gen `var1'_P_`var2' = `var1' * POOREST10 * `var2'
		gen `var1'_D_`var2' = `var1' * DAYMEETING * `var2'

		gen `var1'_E_H_`var2' = `var1' * ELITE * HYBRID * `var2'
	}

}

foreach var1 in CONSRANK COMMRANK {

	local `var1'_C_X1 "`var1'_C_shock `var1'_C_conspicuousness `var1'_C_connectedness `var1'_C_elite_connectedness `var1'_C_verypoor"
	local `var1'_C_V "`var1'_C_urban `var1'_C_inequality `var1'_C_avg_connectedness"
	local `var1'_C_X2 "`var1'_C_ge01a `var1'_C_ge01b `var1'_C_ge01c `var1'_C_ge01d `var1'_C_ge01e `var1'_C_ge01f `var1'_C_ge01g `var1'_C_ge01h `var1'_C_ge01v `var1'_C_WIDOW `var1'_C_conspicuousness `var1'_C_connectedness `var1'_C_elite_connectD `var1'_C_verypoor"
	local `var1'_C_X3 "`var1'_C_shock `var1'_C_conspicuousness `var1'_C_connectedness `var1'_C_elite_connectedness `var1'_C_verypoor `var1'_C_ETHICMINORITY `var1'_C_RELIGIOUSMINORITY `var1'_C_isolated"
	local `var1'_C_X4 "`var1'_C_shock `var1'_C_conspicuousness_2 `var1'_C_elite_connectedness `var1'_C_verypoor `var1'_C_ETHICMINORITY `var1'_C_RELIGIOUSMINORITY `var1'_C_isolated"
 	local `var1'_C_X5 "`var1'_C_shock `var1'_C_conspicuousness_2 `var1'_C_elite_connectedness `var1'_C_ETHICMINORITY `var1'_C_RELIGIOUSMINORITY `var1'_C_isolated"

	local `var1'_H_X1 "`var1'_H_shock `var1'_H_conspicuousness `var1'_H_connectedness `var1'_H_elite_connectedness `var1'_H_verypoor"
	local `var1'_H_V "`var1'_H_urban `var1'_H_inequality `var1'_H_avg_connectedness"
	local `var1'_H_X2 "`var1'_H_ge01a `var1'_H_ge01b `var1'_H_ge01c `var1'_H_ge01d `var1'_H_ge01e `var1'_H_ge01f `var1'_H_ge01g `var1'_H_ge01h `var1'_H_ge01v `var1'_H_WIDOW `var1'_H_conspicuousness `var1'_H_connectedness `var1'_H_elite_connectD `var1'_H_verypoor"
	local `var1'_H_X3 "`var1'_H_shock `var1'_H_conspicuousness `var1'_H_connectedness `var1'_H_elite_connectedness `var1'_H_verypoor `var1'_H_ETHICMINORITY `var1'_H_RELIGIOUSMINORITY `var1'_H_isolated"
	local `var1'_H_X4 "`var1'_H_shock `var1'_H_conspicuousness_2 `var1'_H_elite_connectedness `var1'_H_verypoor `var1'_H_ETHICMINORITY `var1'_H_RELIGIOUSMINORITY `var1'_H_isolated"
	local `var1'_H_X5 "`var1'_H_shock `var1'_H_conspicuousness_2 `var1'_H_elite_connectedness `var1'_H_ETHICMINORITY `var1'_H_RELIGIOUSMINORITY `var1'_H_isolated"

	local `var1'_E_X1 "`var1'_E_shock `var1'_E_conspicuousness `var1'_E_connectedness `var1'_E_elite_connectedness `var1'_E_verypoor"
	local `var1'_E_V "`var1'_E_urban `var1'_E_inequality `var1'_E_avg_connectedness"
	local `var1'_E_X2 "`var1'_E_ge01a `var1'_E_ge01b `var1'_E_ge01c `var1'_E_ge01d `var1'_E_ge01e `var1'_E_ge01f `var1'_E_ge01g `var1'_E_ge01h `var1'_E_ge01v `var1'_E_WIDOW `var1'_E_conspicuousness `var1'_E_connectedness `var1'_E_elite_connectD `var1'_E_verypoor"
	local `var1'_E_X3 "`var1'_E_shock `var1'_E_conspicuousness `var1'_E_connectedness `var1'_E_elite_connectedness `var1'_E_verypoor `var1'_E_ETHICMINORITY `var1'_E_RELIGIOUSMINORITY `var1'_E_isolated"
	local `var1'_E_X4 "`var1'_E_shock `var1'_E_conspicuousness_2 `var1'_E_elite_connectedness `var1'_E_verypoor `var1'_E_ETHICMINORITY `var1'_E_RELIGIOUSMINORITY `var1'_E_isolated"
	local `var1'_E_X5 "`var1'_E_shock `var1'_E_conspicuousness_2 `var1'_E_elite_connectedness `var1'_E_ETHICMINORITY `var1'_E_RELIGIOUSMINORITY `var1'_E_isolated"

	local `var1'_P_X1 "`var1'_P_shock `var1'_P_conspicuousness `var1'_P_connectedness `var1'_P_elite_connectedness `var1'_P_verypoor"
	local `var1'_P_V "`var1'_P_urban `var1'_P_inequality `var1'_P_avg_connectedness"
	local `var1'_P_X2 "`var1'_P_ge01a `var1'_P_ge01b `var1'_P_ge01c `var1'_P_ge01d `var1'_P_ge01e `var1'_P_ge01f `var1'_P_ge01g `var1'_P_ge01h `var1'_P_ge01v `var1'_P_WIDOW `var1'_P_conspicuousness `var1'_P_connectedness `var1'_P_elite_connectD `var1'_P_verypoor"
	local `var1'_P_X3 "`var1'_P_shock `var1'_P_conspicuousness `var1'_P_connectedness `var1'_P_elite_connectedness `var1'_P_verypoor `var1'_P_ETHICMINORITY `var1'_P_RELIGIOUSMINORITY `var1'_P_isolated"
	local `var1'_P_X4 "`var1'_P_shock `var1'_P_conspicuousness_2 `var1'_P_elite_connectedness `var1'_P_verypoor `var1'_P_ETHICMINORITY `var1'_P_RELIGIOUSMINORITY `var1'_P_isolated"
	local `var1'_P_X5 "`var1'_P_shock `var1'_P_conspicuousness_2 `var1'_P_elite_connectedness `var1'_P_ETHICMINORITY `var1'_P_RELIGIOUSMINORITY `var1'_P_isolated"

	local `var1'_D_X1 "`var1'_D_shock `var1'_D_conspicuousness `var1'_D_connectedness `var1'_D_elite_connectedness `var1'_D_verypoor"
	local `var1'_D_V "`var1'_D_urban `var1'_D_inequality `var1'_D_avg_connectedness"
	local `var1'_D_X2 "`var1'_D_ge01a `var1'_D_ge01b `var1'_D_ge01c `var1'_D_ge01d `var1'_D_ge01e `var1'_D_ge01f `var1'_D_ge01g `var1'_D_ge01h `var1'_D_ge01v `var1'_D_WIDOW `var1'_D_conspicuousness `var1'_D_connectedness `var1'_D_elite_connectD `var1'_D_verypoor"
	local `var1'_D_X3 "`var1'_D_shock `var1'_D_conspicuousness `var1'_D_connectedness `var1'_D_elite_connectedness `var1'_D_verypoor `var1'_D_ETHICMINORITY `var1'_D_RELIGIOUSMINORITY `var1'_D_isolated"
	local `var1'_D_X4 "`var1'_D_shock `var1'_D_conspicuousness_2 `var1'_D_elite_connectedness `var1'_D_verypoor `var1'_D_ETHICMINORITY `var1'_D_RELIGIOUSMINORITY `var1'_D_isolated"
	local `var1'_D_X5 "`var1'_D_shock `var1'_D_conspicuousness_2 `var1'_D_elite_connectedness `var1'_D_ETHICMINORITY `var1'_D_RELIGIOUSMINORITY `var1'_D_isolated"

	local `var1'_E_H_X1 "`var1'_E_H_shock `var1'_E_H_conspicuousness `var1'_E_H_connectedness `var1'_E_H_elite_connectedness `var1'_E_H_verypoor"
	local `var1'_E_H_V "`var1'_E_H_urban `var1'_E_H_inequality `var1'_E_H_avg_connectedness"
	local `var1'_E_H_X2 "`var1'_E_H_ge01a `var1'_E_H_ge01b `var1'_E_H_ge01c `var1'_E_H_ge01d `var1'_E_H_ge01e `var1'_E_H_ge01f `var1'_E_H_ge01g `var1'_E_H_ge01h `var1'_E_H_ge01v `var1'_E_H_WIDOW `var1'_E_H_conspicuousness `var1'_E_H_connectedness `var1'_E_H_elite_connectD `var1'_E_H_verypoor"
	local `var1'_E_H_X3 "`var1'_E_H_shock `var1'_E_H_conspicuousness `var1'_E_H_connectedness `var1'_E_H_elite_connectedness `var1'_E_H_verypoor `var1'_E_H_ETHICMINORITY `var1'_E_H_RELIGIOUSMINORITY `var1'_E_H_isolated"
	local `var1'_E_H_X4 "`var1'_E_H_shock `var1'_E_H_conspicuousness_2 `var1'_E_H_elite_connectedness `var1'_E_H_verypoor `var1'_E_H_ETHICMINORITY `var1'_E_H_RELIGIOUSMINORITY `var1'_E_H_isolated"
	local `var1'_E_H_X5 "`var1'_E_H_shock `var1'_E_H_conspicuousness_2 `var1'_E_H_elite_connectedness `var1'_E_H_ETHICMINORITY `var1'_E_H_RELIGIOUSMINORITY `var1'_E_H_isolated"

}

forvalues i= 1/5 {
	forvalues j= 1/2 {
		foreach var1 of varlist CONSRANK COMMRANK {

		** No fixed effect

		regress TREATRANK_`j' `var1' `var1'_C `var1'_H ``var1'_C_X`i'' ``var1'_H_X`i'' COMMUNITY HYBRID, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster replace
		regress TREATRANK_`j' `var1' `var1'_C `var1'_H ``var1'_C_V' ``var1'_H_V' COMMUNITY HYBRID, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append
		regress TREATRANK_`j' `var1' `var1'_C `var1'_H ``var1'_C_X`i'' ``var1'_C_V' ``var1'_H_X`i'' ``var1'_H_V' COMMUNITY HYBRID, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append

		regress TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_P `var1'_D ``var1'_E_X`i'' ``var1'_H_X`i'' ``var1'_P_X`i'' ``var1'_D_X`i'' ELITE HYBRID POOREST10 DAYMEETING, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append
		regress TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_P `var1'_D ``var1'_E_V' ``var1'_H_V' ``var1'_P_V' ``var1'_D_V' ELITE HYBRID POOREST10 DAYMEETING, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append
		regress TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_P `var1'_D ``var1'_E_X`i'' ``var1'_E_V' ``var1'_H_X`i'' ``var1'_H_V' ``var1'_P_X`i'' ``var1'_P_V' ``var1'_D_X`i'' ``var1'_D_V' ELITE HYBRID POOREST10 DAYMEETING, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append

		regress TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_E_H  ``var1'_E_X`i'' ``var1'_H_X`i'' ``var1'_E_H_X`i'' ELITE HYBRID ELITEHYBRID, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append
		regress TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_E_H  ``var1'_E_V' ``var1'_H_V' ``var1'_E_H_V' ELITE HYBRID ELITEHYBRID, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append
		regress TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_E_H  ``var1'_E_X`i'' ``var1'_E_V' ``var1'_H_X`i'' ``var1'_H_V' ``var1'_E_H_X`i'' ``var1'_E_H_V' ELITE HYBRID ELITEHYBRID, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe.xls", se 3aster append

		** fixed effect

		areg TREATRANK_`j' `var1' `var1'_C `var1'_H ``var1'_C_X`i'' ``var1'_H_X`i'' COMMUNITY HYBRID,absorb(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_fe.xls", se 3aster replace

		areg TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_P `var1'_D ``var1'_E_X`i'' ``var1'_H_X`i'' ``var1'_P_X`i'' ``var1'_D_X`i'' ELITE HYBRID POOREST10 DAYMEETING,absorb(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_fe.xls", se 3aster append

		areg TREATRANK_`j' `var1' `var1'_E `var1'_H `var1'_E_H  ``var1'_E_X`i'' ``var1'_H_X`i'' ``var1'_E_H_X`i'' ELITE HYBRID ELITEHYBRID,absorb(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_fe.xls", se 3aster append

		}
	}
}



*************************************

// COMBINE COMMUNITY AND HYBRID BECOME ONE

use "codeddata/analysis3.dta", clear

gen COMMUNITY_A = (COMMUNITY==1|HYBRID==1)
drop COMMUNITY HYBRID

local X1 "shock conspicuousness connectedness elite_connectedness verypoor"
local V "urban inequality avg_connectedness"
local X2 "ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW conspicuousness connectedness elite_connectD verypoor"
local X3 "shock conspicuousness connectedness elite_connectedness verypoor  ETHICMINORITY RELIGIOUSMINORITY isolated"
local X4 "shock conspicuousness_2 elite_connectedness verypoor  ETHICMINORITY RELIGIOUSMINORITY isolated"
local X5 "shock conspicuousness_2 elite_connectedness  ETHICMINORITY RELIGIOUSMINORITY isolated"

foreach var in shock conspicuousness connectedness elite_connectedness verypoor urban inequality avg_connectedness ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW elite_connectD  ETHICMINORITY RELIGIOUSMINORITY conspicuousness_2 isolated{
	gen C_`var' = COMMUNITY_A*`var'
}

local C_X1 "C_shock C_conspicuousness C_connectedness C_elite_connectedness C_verypoor"
local C_V "C_urban C_inequality C_avg_connectedness"
local C_X2 "C_ge01a C_ge01b C_ge01c C_ge01d C_ge01e C_ge01f C_ge01g C_ge01h C_ge01v C_WIDOW C_conspicuousness C_connectedness C_elite_connectD C_verypoor"
local C_X3 "C_shock C_conspicuousness C_connectedness C_elite_connectedness C_verypoor C_ETHICMINORITY C_RELIGIOUSMINORITY C_isolated"
local C_X4 "C_shock C_conspicuousness_2 C_elite_connectedness C_verypoor C_ETHICMINORITY C_RELIGIOUSMINORITY C_isolated"
local C_X4 "C_shock C_conspicuousness_2 C_elite_connectedness C_ETHICMINORITY C_RELIGIOUSMINORITY C_isolated"

forvalues i= 1/5 {
	forvalues j= 1/2 {
		gen rts = RTS if `j'==1
		replace rts = RTS_meeting if `j'==2

		foreach var of varlist rts MISTARGETDUMMY_`j' MISTARGETRICHDUMMY_`j' MISTARGETPOORDUMMY_`j' MISTARGETVERYPOORDUMMY_`j' MISTARGETRICHDUMMY_pol_`j' {

			** No Fixed effec
			regress `var' LOGCONSUMPTION `X`i'' COMMUNITY_A `C_X`i'', cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'_CA.xls", se 3aster replace
			regress `var' LOGCONSUMPTION `V' COMMUNITY_A `C_V', cluster(hhea)	
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'_CA.xls", se 3aster append
			regress `var' LOGCONSUMPTION `X`i'' `V' COMMUNITY_A `C_X`i'' `C_V' , cluster(hhea)
			outreg using "$output\analysis3_`var'_nofe_ver`j'_X`i'_CA.xls", se 3aster append

			** Fixed effect

			areg `var' LOGCONSUMPTION `X`i'' COMMUNITY_A `C_X`i'',absorb(hhea)
			outreg using "$output\analysis3_`var'_fe_ver`j'_X`i'_CA.xls", se 3aster replace

		}
		drop rts
	}
}

***** TREATRANK


foreach var1 in CONSRANK COMMRANK {
	
	gen `var1'_C = `var1' * COMMUNITY_A

	foreach var2 in shock conspicuousness connectedness elite_connectedness verypoor urban inequality avg_connectedness ge01a ge01b ge01c ge01d ge01e ge01f ge01g ge01h ge01v WIDOW elite_connectD  ETHICMINORITY RELIGIOUSMINORITY conspicuousness_2 isolated{
		gen `var1'_C_`var2' = `var1' * COMMUNITY * `var2'
	}

}

foreach var1 in CONSRANK COMMRANK {
	local `var1'_C_X1 "`var1'_C_shock `var1'_C_conspicuousness `var1'_C_connectedness `var1'_C_elite_connectedness `var1'_C_verypoor"
	local `var1'_C_V "`var1'_C_urban `var1'_C_inequality `var1'_C_avg_connectedness"
	local `var1'_C_X2 "`var1'_C_ge01a `var1'_C_ge01b `var1'_C_ge01c `var1'_C_ge01d `var1'_C_ge01e `var1'_C_ge01f `var1'_C_ge01g `var1'_C_ge01h `var1'_C_ge01v `var1'_C_WIDOW `var1'_C_conspicuousness `var1'_C_connectedness `var1'_C_elite_connectD `var1'_C_verypoor"
	local `var1'_C_X3 "`var1'_C_shock `var1'_C_conspicuousness `var1'_C_connectedness `var1'_C_elite_connectedness `var1'_C_verypoor  `var1'_C_ETHICMINORITY `var1'_C_RELIGIOUSMINORITY `var1'_C_isolated"
 	local `var1'_C_X4 "`var1'_C_shock `var1'_C_conspicuousness_2 `var1'_C_elite_connectedness `var1'_C_verypoor  `var1'_C_ETHICMINORITY `var1'_C_RELIGIOUSMINORITY `var1'_C_isolated"
 	local `var1'_C_X5 "`var1'_C_shock `var1'_C_conspicuousness_2 `var1'_C_elite_connectedness `var1'_C_ETHICMINORITY `var1'_C_RELIGIOUSMINORITY `var1'_C_isolated"
}

forvalues i= 1/5 {
	forvalues j= 1/2 {
		foreach var1 of varlist CONSRANK COMMRANK {

		** No fixed effect

		regress TREATRANK_`j' `var1' `var1'_C ``var1'_C_X`i'' COMMUNITY_A, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe_CA.xls", se 3aster replace
		regress TREATRANK_`j' `var1' `var1'_C ``var1'_C_V'  COMMUNITY_A, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe_CA.xls", se 3aster append
		regress TREATRANK_`j' `var1' `var1'_C ``var1'_C_X`i'' ``var1'_C_V' COMMUNITY_A, cluster(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_nofe_CA.xls", se 3aster append

		** fixed effect

		areg TREATRANK_`j' `var1' `var1'_C ``var1'_C_X`i'' COMMUNITY_A,absorb(hhea)
		outreg using "$output\analysis3_treat`j'_`var1'_fe_CA.xls", se 3aster replace

		}
	}
}

*/

log close
