/* CODING baseline data : SUSETI */
/* Last Modified 24 August 2009 */

clear

set more off
set mem 256m

version 10

set sortseed 10000

capture log close
log using "$output\Coding_files_output\coding_baseline.log",replace


*****
/* CREATE LOG PER CAPITA CONSUMPTION AND RANK CONSUMPTION */
*****


use "$data\baseline\hh_ks1.dta", clear
mmerge hhid using "$data\baseline\hh_ks2.dta", type(1:1)

drop _m

sum

/* recode missing values, don't know and not applicable to missing */
foreach var of varlist ks01_1a - ks01_14b{
	gen missing_`var' = (`var'>=999990)
	replace `var'=. if `var'>=999990
}

foreach var of varlist  ks03_15a - ks04_20{
	gen missing_`var' = (`var'>=99999990)
	replace `var'=. if `var'>=99999990
}

sum

egen missing = rsum( missing_ks01_1a- missing_ks04_20 )

egen wfood = rsum(ks01_1a - ks01_14b)
label var wfood "The value of food consumed last week"
gen mfood = wfood * 30/7
label var mfood "Monthly food consumtion"

egen x = rsum(ks03_15a ks03_15c ks03_15d ks03_16a ks03_16d ks03_16e)
egen y = rsum(ks04_15b ks04_16b ks04_16c ks04_17 ks04_18 ks04_19a ks04_19b ks04_19c ks04_19d ks04_20)
gen mnonfood = x + (y/12)
drop x y
label var mnonfood "Monthly non food consumtion"

gen hhconsumption = mfood + mnonfood
replace hhconsumption=. if missing>=4
label var hhconsumption "Monthly household consumtion"
drop missing*

keep  hhid wfood mfood mnonfood hhconsumption
mmerge hhid using "$data\baseline\hh_ar1.dta", type(1:1)
drop _m

label var hhsize "Household size"
gen hhsize2 = hhsize^2
label var hhsize2 "Household Size Squared"

gen LOGHHSIZE = log(hhsize)
label var LOGHHSIZE "Log household size"

gen CONSUMPTION = (hhconsumption/hhsize)/1000
label var CONSUMPTION "Per capita consumption (in thousand Rp)"

gen LOGCONSUMPTION = log(CONSUMPTION)
label var LOGCONSUMPTION "Log per capita consumption"

gen hhea = substr(hhid,1,3)
bys hhea: egen rank_pcexp = rank(CONSUMPTION)
label var rank_pcexp "Rank per capita consumption within village"
bys hhea: gen nhhrank_pcexp=_N
label var nhhrank_pcexp "number of household in village"

gen RANKCONSUMPTION= rank_pcexp/nhhrank_pcexp
label var RANKCONSUMPTION "Rank per capita consumption within village in percentiles"

compress
sort hhid

save "$codeddata\intermediate_data\consumption.dta", replace


*****
/* CREATE HH HEAD CHARACTERISTIC */
*****


use "$data\baseline\hh_ar2.dta", clear

keep if ar02==1 /* keep household head */

rename ar03 hhmale
recode hhmale (3=0)
label var hhmale "Head of Household is Male"

rename ar04a hhage
recode hhage (998=.)
label var hhage "Age of head of household"

rename ar07 hhmarried
recode hhmarried (1 3 4 5=0) (2=1)
label var hhmarried "Head of household is married"

gen hhage2 = hhage^2
label var hhage2 "Age of head of household squared"

gen hhmalemarr = hhmale * hhmarried
label var hhmalemarr "Head of household is male and married"

gen hheduc1 = (ar12 ==0 | ar12 ==1 | (ar12 ==2 & ~(ar13 ==6 | ar13 ==7)))
label var hheduc1 "Not School/Not Finish Elementary School"
gen hheduc2 = ((ar12 ==2 & (ar13 ==6 | ar13 ==7)) | (ar12 ==3 & ~(inrange(ar13,3,7))))
label var hheduc2 "Education Attaintment of HH Head is Elementary School"
gen hheduc3 = ((ar12 ==3 & inrange(ar13,3,7)) | (ar12 ==4 & ~(inrange(ar13,3,7))))
label var hheduc3 "Education Attaintment of HH Head is Junior School"
gen hheduc4 = ((ar12 ==4 & inrange(ar13,3,7)) | inrange(ar12,5,7))
label var hheduc4 "Education Attaintment of HH Head is Senior +"

gen hhsector1 = (inrange(ar11,1,5))
label var hhsector1 "Head of household works in agriculture sector"
gen hhsector2 = (inrange(ar11,6,9))
label var hhsector2 "Head of household works in industry sector"
gen hhsector3 = (inrange(ar11,10,13))
label var hhsector3 "Head of household works in service sector"

gen formal = (inrange(ar10,3,5))
label var formal "Head of household works in formal sector"
gen informal = (inrange(ar10,1,2)|inrange(ar10,6,8))
label var informal "Head of household works in informal sector"

rename ar12 EDUCATIONHHHEAD
label var EDUCATIONHHHEAD "Education level of household head"
label define education 0 "0. Never attended school" 1 "1. Playgroup" 2 "2. Primary" 3 "3. Junior High" 4 "4. Senior High" 5 "5. D1/D2/D3" 6 "6. University (D4/S1)" 7 "7. S2/S3" 98 "98. Don't know" 95 "95. Others"
label val EDUCATIONHHHEAD education

gen YREDUCATIONHHHEAD = 0 if EDUCATIONHHHEAD == 0 | EDUCATIONHHHEAD==1
replace YREDUCATIONHHHEAD = ar13 if EDUCATIONHHHEAD == 2
replace YREDUCATIONHHHEAD = 6 if YREDUCATIONHHHEAD>6
replace YREDUCATIONHHHEAD = 6 + ar13 if EDUCATIONHHHEAD == 3
replace YREDUCATIONHHHEAD = 9 if YREDUCATIONHHHEAD>9
replace YREDUCATIONHHHEAD = 9 + ar13 if EDUCATIONHHHEAD == 4
replace YREDUCATIONHHHEAD = 12 if YREDUCATIONHHHEAD>12
replace YREDUCATIONHHHEAD = 12 + ar13 if EDUCATIONHHHEAD == 5
replace YREDUCATIONHHHEAD = 15 if YREDUCATIONHHHEAD>15
replace YREDUCATIONHHHEAD = 12 + ar13 if EDUCATIONHHHEAD == 6
replace YREDUCATIONHHHEAD = 16 if YREDUCATIONHHHEAD>16
replace YREDUCATIONHHHEAD = 16 + ar13 if EDUCATIONHHHEAD == 7
replace YREDUCATIONHHHEAD = 21 if YREDUCATIONHHHEAD>21
replace YREDUCATIONHHHEAD = . if EDUCATIONHHHEAD>=95

label var YREDUCATIONHHHEAD "Years of education of HH Head "

gen AGRICULTURALHH = 1 if ar11>=1 & ar11<=5
replace AGRICULTURALHH = 0 if ar11>=6 & ar11<=95
label var AGRICULTURALHH "Agricultural household"

rename ar11 SECTORHHHEAD
label define sector 1 "1. Agriculture and crops" 2 "2. Plantation and forestry" 3 "3. Livestock" 4 "4. Fisheries" 5 "5. Hunting" 6 "6. Mining and quarrying" 7 "7. Manufacturing" 8 "8. Electricity, Gas and Water" 9 "9. Construction" 10 "10. Wholesale, retail, restaurant and hotel" 11 "11. Transportation, storage and communication" 12 "12. Finance, insurance, real estate, services" 13 "13. Social services" 95 "95. Other" 96 "96. Not applicable" 98 "98. Don't know" 
label val SECTORHHHEAD sector

gen hhea = substr(hhid,1,3)
bys hhea: gen sumHH =_N
label var sumHH "Total number households per RT"

bys hhea: egen NAGRICULTURALHH = sum(AGRICULTURALHH)
gen SHAREAGRICULTURALHH = NAGRICULTURALHH/sumHH *100 
label var SHAREAGRICULTURALHH "Share Agricultural household in village"

drop ar*

compress
sort hhid

save "$codeddata\intermediate_data\hhhead.dta", replace


*****
/* EDUCATION LEVEL OF RT HEAD */
*****


use "$data\baseline\hh_ar2_fix.dta", clear

rename ar12 EDUCATIONRTHEAD
label var EDUCATIONRTHEAD "Education level of RT head"
label define education 0 "0. Never attended school" 1 "1. Playgroup" 2 "2. Primary" 3 "3. Junior High" 4 "4. Senior High" 5 "5. D1/D2/D3" 6 "6. University (D4/S1)" 7 "7. S2/S3" 98 "98. Don't know" 95 "95. Others"
label val EDUCATIONRTHEAD education

gen YREDUCATIONRTHEAD = 0 if EDUCATIONRTHEAD == 0 | EDUCATIONRTHEAD==1
replace YREDUCATIONRTHEAD = ar13 if EDUCATIONRTHEAD == 2
replace YREDUCATIONRTHEAD = 6 if YREDUCATIONRTHEAD>6
replace YREDUCATIONRTHEAD = 6 + ar13 if EDUCATIONRTHEAD == 3
replace YREDUCATIONRTHEAD = 9 if YREDUCATIONRTHEAD>9
replace YREDUCATIONRTHEAD = 9 + ar13 if EDUCATIONRTHEAD == 4
replace YREDUCATIONRTHEAD = 12 if YREDUCATIONRTHEAD>12
replace YREDUCATIONRTHEAD = 12 + ar13 if EDUCATIONRTHEAD == 5
replace YREDUCATIONRTHEAD = 15 if YREDUCATIONRTHEAD>15
replace YREDUCATIONRTHEAD = 12 + ar13 if EDUCATIONRTHEAD == 6
replace YREDUCATIONRTHEAD = 16 if YREDUCATIONRTHEAD>16
replace YREDUCATIONRTHEAD = 16 + ar13 if EDUCATIONRTHEAD == 7
replace YREDUCATIONRTHEAD = 21 if YREDUCATIONRTHEAD>21
replace YREDUCATIONRTHEAD = . if EDUCATIONRTHEAD>=95

label var YREDUCATIONRTHEAD "Years of education of RT Head "

drop ar13

save "$codeddata\intermediate_data\rthead.dta", replace


*****
/* CREATE ALL HOUSEHOLD CHARACTERISTICS FOR PMT */
*****


use "$data\baseline\hh_kr", clear

rename kr01 floor
rename kr21 healthcare
rename kr32 credit

gen tfloor = (kr04 !=6)
gen twall = (kr08 ==1)
gen troof = (inrange(kr06,1,2))
gen toilet = (kr15 ==2)
replace toilet = . if kr15==8 | kr15==9
gen water = (inrange(kr12,1,4) | kr12 ==6)
replace water = . if kr12==99

gen lighting = (kr17a ==3)
gen house = (kr09a ==1)
gen fcook = (kr23a !=1)

label var floor "Floor area"
label var healthcare "Can afford healthcare"
label var tfloor "Not earth floor"
label var troof "Concrete or corrugated roof"
label var twall "Brick or cement wall"
label var toilet "Private toilet"
label var water "Clean drinking water"
label var lighting "PLN electricity"
label var house "Own house privately"
label var fcook "Cooks with firewood"

recode healthcare credit (3 8 9=0)

gen FLOORTOPQUALITY = (kr04==1|kr04==2)
drop kr04
label var FLOORTOPQUALITY "Floor material top quality"

keep hhid healthcare credit floor tfloor troof twall toilet water lighting house fcook FLOORTOPQUALITY
compress
sort hhid
save "$codeddata\intermediate_data\hhcharacteristic.dta", replace


*****
/* OTHER HH CHARACTERISTIC FOR PMT */
*****


use "$data\baseline\hh_ar2", clear

recode ar04a (998=.)
gen age04 = (inrange(ar04a,0,4))
gen age14 = (inrange(ar04a,0,14))
gen age65 = (ar04a >64)
gen age1564 = (inrange(ar04a,15,64))

gen eschild = (ar12 ==2 & ar14 ==1 & ar04a<=12)
gen jschild = (ar12 ==3 & ar14 ==1 & ar04a>=13 & ar04a<=15)
gen sschild = (ar12 ==4 & ar14 ==1 & ar04a>=16 & ar04a<=18)

gen educ1 = (ar12 ==0 | ar12 ==1 | (ar12 ==2 & ~(ar13 ==6 | ar13 ==7)))
gen educ2 = ((ar12 ==2 & (ar13 ==6 | ar13 ==7)) | (ar12 ==3 & ~(inrange(ar13,3,7))))
gen educ3 = ((ar12 ==3 & inrange(ar13,3,7)) | (ar12 ==4 & ~(inrange(ar13,3,7))))
gen educ4 = ((ar12 ==4 & inrange(ar13,3,7)) | inrange(ar12,5,7))

forval x =1/4 {
	egen cteduc`x' = total(educ`x'), by(hhid)
	gen higheduc`x' =0
}

replace higheduc4 = 1 if cteduc4 >0 & cteduc4 !=.
replace higheduc3 = 1 if higheduc4 !=1 & cteduc3 >0 & cteduc3 !=.
replace higheduc2 = 1 if higheduc4 !=1 & higheduc3 !=1 & cteduc2 >0 & cteduc2 !=.
replace higheduc1 = 1 if higheduc4 !=1 & higheduc3 !=1 & higheduc2 !=1


collapse (sum) age04 age14 age65 age1564 eschild jschild sschild (mean) higheduc1 higheduc2 higheduc3 higheduc4, by(hhid)

gen depratio = (age14 + age65) / age1564
gen depratio_c = age14 / age1564
gen depratio_a = age65 / age1564

label var age04	"Number of children 0-4"
label var age14 "Number of children 0-14"
label var age65	"Number of adults over 64"
label var age1564 "Number of adults 15-64"
label var higheduc1 "Highest Education Attaintment within HH is Not School/Not Finish Elementary School"
label var higheduc2 "Highest Education Attaintment within HH is Elementary School"
label var higheduc3 "Highest Education Attaintment within HH is Junior School"
label var higheduc4 "Highest Education Attaintment within HH is Senior +"

label var eschild "Number of Children in Elementary School"
label var jschild "Number of Children in Junior H.School"
label var sschild "Number of Children in Senior H.School"
label var depratio "Total Dependency Ratio"
label var depratio_c "Child Dependency Ratio"
label var depratio_a "Aged Dependency Ratio"

compress
sort hhid
save "$codeddata\hh_ar2", replace


*****
/* CREATE ALL ASSET VARIABLES FOR PMT */
*****


use "$data\baseline\hh_hr1", clear
keep hhid hr1type hr01

replace hr01=. if hr01==8|hr01==9

reshape wide hr01, i(hhid) j(hr1type) string

rename hr01d house

rename hr01e se2_139

gen se2_138 = (hr01a ==1 | hr01b ==1 | hr01c ==1)

recode house (3 8=0)

label var se2_138 "Agricultural land"
label var se2_139 "Non-agricultural land"
label var house "Owns own house"

keep hhid house se2_138 se2_139
compress
sort hhid
tempfile a
save `a', replace

use "$data\baseline\hh_hr2", clear
keep hhid hr2type hr05 hr06
keep if   hr2type == "07" | hr2type == "08" | hr2type == "09" | hr2type == "10" | hr2type == "11" | hr2type == "12" | hr2type == "13" | hr2type == "14" | hr2type == "15" | hr2type == "16" | hr2type == "17" | hr2type == "18" | hr2type == "19" | hr2type == "20" | hr2type == "21" | hr2type == "22" | hr2type == "23" | hr2type == "25" | hr2type == "26" | hr2type == "27" | hr2type == "28" | hr2type == "29" | hr2type == "30" | hr2type == "31" | hr2type == "32" | hr2type == "33" | hr2type == "34" | hr2type == "35"

recode hr05 (3 8=0) (7 9=.) /* Recode 3.No and 8. Don't know to 0; recode 7. don't want to answer and 9. missing to . */
recode hr06 (997 =.) /* Recode 997. don't want to answer to . (missing) */
reshape wide hr05 hr06, i(hhid) j(hr2type) string

* Recode 7. don't want to answer and 
rename hr0509 se2_17
rename hr0510 se2_16
rename hr0511 se2_111
rename hr0512 se2_110
rename hr0513 se2_115
rename hr0514 se2_13_15
rename hr0515 se2_11_12
rename hr0516 se2_14
rename hr0517 se2_114
rename hr0518 se2_117
rename hr0519 se2_119
rename hr0520 se2_118
rename hr0521 se2_124
rename hr0522 se2_128
rename hr0523 se2_125
rename hr0525 se2_126_127
rename hr0526 se2_129
rename hr0527 se2_122_123
rename hr0528 se5_110
rename hr0529 se5_17
rename hr0530 se5_15_16
rename hr0531 se5_11_12
rename hr0532 se5_13
rename hr0533 se2_132_133
rename hr0534 se2_112
rename hr0535 se2_121

gen se2_18 = (hr0507 ==1 | hr0508 ==1)
drop hr0507 hr0508

label var se2_14 "DVD/VCD player"
label var se2_16 "Rice Cooker / Magic Jar"
label var se2_17 "Refrigerator"
label var se2_18 "Gas burner"
label var se2_111 "Mixer / Blender"
label var se2_115 "AC"
label var se2_114 "Satelite dish"
label var se2_117 "Computer"
label var se2_13_15 "Radio / Cassette Player"
label var se2_11_12 "TV"
label var se2_119 "HP"
label var se2_124 "Bicycle"
label var se2_125 "Motorcycle"
label var se2_126_127 "Car / Mini-bus / Truck"
label var se2_122_123 "Jewelry"
label var se2_132_133 "Rice husker / mill"
label var se2_112 "Sewing Machine"
label var se5_17 "Pig"
label var se5_15_16 "Goat / Sheep"
label var se5_11_12 "Caribou / Cow"
label var se5_110 "chicken"

label var hr0609 "number of Refrigerator"
label var hr0610 "number of Rice Cooker / Magic Jar"
label var hr0611 "number of Mixer / Blender"
label var hr0612 "number of Fan"
label var hr0613 "number of AC"
label var hr0614 "number of Radio / Cassette Player"
label var hr0615 "number of TV"
label var hr0616 "number of DVD/VCD player"
label var hr0617 "number of Satelite dish"
label var hr0618 "number of Computer"
label var hr0619 "number of HP"
label var hr0620 "number of Telephone"
label var hr0621 "number of Bicycle"
label var hr0622 "number of row/kayak"
label var hr0623 "number of Motorcycle"
label var hr0625 "number of Car / Mini-bus / Truck"
label var hr0626 "number of Motorboat"
label var hr0627 "number of Jewelry"
label var hr0628 "number of chicken"
label var hr0629 "number of pig"
label var hr0630 "number of goat"
label var hr0631 "number of cow"
label var hr0632 "number of horse"
label var hr0633 "number of Rice husker / mill"
label var hr0634 "number of Sewing Machine"
label var hr0635 "number of electric water pump"

compress
sort hhid
mmerge hhid using `a'
drop _m
compress
sort hhid

save "$codeddata\intermediate_data\hhasset.dta", replace


*****
/* LOCATION */
*****

use "$data\baseline\hh_lk", clear

rename lk01 prop
rename lk02 kab
*rename lk03 kec
*rename lk04 desa
rename lk04a urban

label var prop "Province"
label var kab "Kabupaten"
label var kec "Kecamatan"
label var desa "Desa or Kelurahan"
label var urban "Urban"

recode urban (2=0)

keep  hhid prop kab kec desa urban
compress
sort hhid

save "$codeddata\intermediate_data\hh_lk.dta", replace


*****
/* HOUSEHOLD RANK */
*****


use "$data/baseline/hh_cr04a.dta", clear

	/* some coding removed for containing identifiers; 
	ask corresponding author for explanation */

gen rank =  cr04a_line
label var rank "Rank from household sample"

rename hhid hhid_who_rank
rename hhid_cr04 hhid

keep hhid hhea hhid_who_rank rank 
order hhid hhea hhid_who_rank rank
tempfile x
save `x', replace

use "$data\baseline\hh_cov.dta", clear
keep hhid hhea  hhcov5
keep if hhcov5==2 /* Replacement households*/
** the enumerators should just rank the original households; not the replacement households
mmerge hhid using `x'
keep if _m==2
drop _m

compress
sort hhid
save "$codeddata\intermediate_data\hh_rank.dta", replace


*****
/* GENDER TARGET */
*****


use "$data/baseline/hh_cov.dta", clear
keep hhid hhcov1

rename hhcov1 GENDERTARGET
label var GENDERTARGET "Gender target"
label define sex 1 "1. Male" 3 "3. Female"
label val GENDERTARGET sex

mmerge hhid using "$data\baseline\hh_ar1.dta."
keep if _m==3
drop _m hhsize
compress
sort hhid
save "$codeddata\intermediate_data\gendertarget.dta", replace


*****
/* PERCENT KIDS OF AGEGROUP 0-4, 4-9, 10-15 */
*****


use "$data/baseline/hh_ar2.dta", clear
keep hhid ar02 ar04a
gen children = (ar02==3)
gen children0_4 = (children==1 & ar04>=0 & ar04<=4)
label var children0_4 "Children aged 0-4)
gen children5_9 = (children==1 & ar04>=5 & ar04<=9)
label var children5_9 "Children aged 5-9)
gen children10_15 = (children==1 & ar04>=10 & ar04<=15)
label var children10_15 "Children aged 10-15)

bys hhid: egen nchildren = sum(children)
bys hhid: egen nchildren0_4 = sum(children0_4)
label var nchildren0_4 "Number Children aged 0-4)
bys hhid: egen nchildren5_9 = sum(children5_9)
label var nchildren5_9 "Number Children aged 5-9)
bys hhid: egen nchildren10_15 = sum(children10_15)
label var nchildren10_15 "Number Children aged 10-15)

gen schildren0_4 = nchildren0_4/nchildren *100
replace schildren0_4 = 0 if schildren0_4==. 
label var schildren0_4 "Share children aged 0-4"
gen schildren5_9 = nchildren5_9/nchildren *100
replace schildren5_9 = 0 if schildren5_9==.
label var schildren5_9 "Share children aged 5-9"
gen schildren10_15 = nchildren10_15/nchildren *100
replace schildren10_15 = 0 if schildren10_15==.
label var schildren10_15 "Share children aged 10-15"

bys hhid: keep if _n==1
drop ar* children

compress
sort hhid
save "$codeddata\intermediate_data\children.dta", replace


*****
/* SHOCK: SECTION GE + WIDOW*/
*****


use "$data/baseline/hh_ge.dta", clear
keep hhid getype ge01
reshape wide ge01, i(hhid) str j(getype)

foreach var of varlist ge01a-ge01v{
	replace `var' = 0 if `var'==3
	replace `var' = . if `var'==8|`var'==9 /* 8. Dont know; 9. Missing */
}

label var ge01a "GE01a. Death of head of household/main income earner"
label var ge01b "GE01b. Death of other household member"
label var ge01c "GE01c. Grave illness of head of household or main income earner who required hospitalisation or continuous medical treatment?"
label var ge01d "GE01d. Grave illness of other household member  who required hospitalisation or continuous medical treatment?  "
label var ge01e "GE01e. Lost of employment of business failure among household members?"
label var ge01f "GE01f. Losses due to fire, earthquake other disasters"
label var ge01g "GE01g. Harvest failure"
label var ge01h "GE01h. Reduction in household income due to very low harvest/production"
label var ge01v "GE01v. Other"

tempfile h1
save `h1', replace

* WIDOW *

use "$data/baseline/hh_ar2.dta", clear
keep hhid ar02 ar07
keep if ar02==1 /*Head of household */
gen WIDOW = (ar07==4)
drop ar02 ar07
mmerge hhid using `h1'
drop _m

compress
sort hhid
save "$codeddata\intermediate_data\hhshock.dta", replace


*****
/* INDEBTEDNESS: DUMMY FOR HAVING MORE THAN THE 75th PERCENTILE IN OUR DATA OF OUTSTANDING LOANS */
*****


use "$data\baseline\hh_bh1.dta", clear
gen loan = (bh04num>=1 & bh04num<=4)
label var loan "Do you have loans?"
label define loan 1 "1.yes" 0 "0. No"
label val loan loan 

keep hhid loan
tempfile i1
save `i1', replace

use "$data\baseline\hh_bh2.dta", clear
keep hhid bh04col bh05

reshape wide bh05, i(hhid) j(bh04col)

egen outstandingloan = rsum(  bh051 bh052 bh053 bh054)
label var outstandingloan "Total number outstanding loan"
keep hhid outstandingloan

mmerge hhid using `i1'
replace outstandingloan = 0 if _m==2
drop _m

xtile quartloan = outstandingloan, nq(4)
gen INDEBTEDNESS = (quartloan==4)

compress
sort hhid
save "$codeddata\intermediate_data\indebtdness.dta", replace


	/* Coding for HAJI removed for containing identifiers;
	ask corresponding author for more information */

*****
/* SOCIAL CONNECTION */
*****


/* L1. NUMBER OF HH IN RT YOU ARE RELATED TO */

use "$data\baseline\hh_cr01.dta", clear

/* check whether there is double counting of the households */
gen hhea = substr(hhid,1,3)
gen hhid_cr01 =hhea +cr01_hhid
bys hhid hhid_cr01: gen x=_n
tab x /* there is no double counting */
drop x

gen family=1

save "$codeddata\intermediate_data\hh_cr01.dta", replace

bys hhid:gen HHRELATED =_N
label var HHRELATED "Number of households in RT you are related to"
keep hhid HHRELATED
bys hhid: keep if _n==1

mmerge hhid using "$data\baseline\hh_ar1.dta"
replace HHRELATED = 0 if _m==2

drop _m hhsize
tempfile l1
save `l1', replace


/* L2. FORMAL LEADER */

use "$data\baseline\hh_cr00.dta", clear
keep hhid cr05a*

gen hhea = substr(hhid,1,3)

forvalues i = 1/5{
	preserve
	gen formalleader`i'=1 if  cr05a`i'_hhid!=""

	gen hhid_formalleader`i' = hhea + cr05a`i'_hhid
	replace hhid_formalleader`i' ="" if cr05a`i'_hhid==""

	bys hhid_formalleader`i': egen vote_formalleader`i' = sum(formalleader`i') 
	replace vote_formalleader`i'=. if vote_formalleader`i'==0

	bys hhid_formalleader`i': keep if _n==1

	keep hhid_formalleader`i' vote_formalleader`i'

	rename hhid_formalleader`i' hhid

	drop if hhid==""
	tempfile l2`i'
	save `l2`i'', replace
	restore
}

use `l21', clear
mmerge hhid using `l22'
mmerge hhid using `l23'
mmerge hhid using `l24'
mmerge hhid using `l25'
drop _m

egen vote_formalleader = rsum(vote_formalleader1 vote_formalleader2 vote_formalleader3 vote_formalleader4 vote_formalleader5)

/* some households have vote more than 9. It is possible because one household could have more than one formal leader */

gen FORMALLEADER = (vote_formalleader>=2)
label var FORMALLEADER "Formal leader in the RT"

sort hhid
save "$codeddata/intermediate_data/formalleader.dta", replace

mmerge hhid using `l1'
drop if _m==1

replace FORMALLEADER = 0 if _m==2

drop _m
tempfile l2
save `l2', replace

/* L3. INFORMAL LEADER */

use "$data\baseline\hh_cr00.dta", clear

keep hhid cr05b*
gen hhea = substr(hhid,1,3)

forvalues i = 1/5{
	preserve
	gen informalleader`i'=1 if  cr05b`i'_hhid!=""

	gen hhid_informalleader`i' = hhea + cr05b`i'_hhid
	replace hhid_informalleader`i' ="" if cr05b`i'_hhid==""

	bys hhid_informalleader`i': egen vote_informalleader`i' = sum(informalleader`i') 
	replace vote_informalleader`i'=. if vote_informalleader`i'==0

	bys hhid_informalleader`i': keep if _n==1

	keep hhid_informalleader`i' vote_informalleader`i'

	rename hhid_informalleader`i' hhid

	drop if hhid==""
	tempfile l3`i'
	save `l3`i'', replace
	restore
}

use `l31', clear
mmerge hhid using `l32'
mmerge hhid using `l33'
mmerge hhid using `l34'
mmerge hhid using `l35'
drop _m

egen vote_informalleader = rsum(vote_informalleader1 vote_informalleader2 vote_informalleader3 vote_informalleader4 vote_informalleader5)

gen INFORMALLEADER = (vote_informalleader>=2)
label var INFORMALLEADER "Informal leader in the RT"

sort hhid
save "$codeddata/intermediate_data/informalleader.dta", replace

mmerge hhid using `l2'

drop if _m==1

replace INFORMALLEADER = 0 if _m==2
drop _m
tempfile l3
save `l3', replace

/* L4. FAMILY MEMBER OF FORMAL LEADER */

foreach var in "a" "b" "c" "d" "e" {
	use "$data\baseline\hh_cr05`var'a.dta", clear

	gen hhea = substr(hhid,1,3)

	gen familyformalleader=1

	gen hhid_familyformalleader = hhea+cr05`var'a_hhid

	bys hhid_familyformalleader: egen vote_familyformalleader = sum(familyformalleader)

	keep hhid_familyformalleader vote_familyformalleader

	bys hhid_familyformalleader: keep if _n==1

	rename hhid_familyformalleader hhid
	rename vote_familyformalleader vote_familyformalleader`var'

	tempfile l4`var'
	save `l4`var'', replace
}

use `l4a', clear
mmerge hhid using `l4b'
mmerge hhid using `l4c'
mmerge hhid using `l4d'
mmerge hhid using `l4e'
drop _m

foreach var in "a" "b" "c" "d" "e" {
	replace vote_familyformalleader`var'=0 if vote_familyformalleader`var'==.
}

gen FAMILYFORMALLEADER = (vote_familyformalleadera>=2 |vote_familyformalleaderb>=2 | vote_familyformalleaderc>=2 | vote_familyformalleaderd>=2 | vote_familyformalleadere>=2)
label var FAMILYFORMALLEADER "Family member of formal leader"

mmerge hhid using `l3'
drop if _m==1

replace FAMILYFORMALLEADER = 0 if _m==2
drop _m
tempfile l4
save `l4', replace

/* L5. FAMILY MEMBER OF INFORMAL LEADER */

foreach var in "a" "b" "c" "d" "e" {
	use "$data\baseline\hh_cr05`var'b.dta", clear

	gen hhea = substr(hhid,1,3)

	gen familyinformalleader=1

	gen hhid_familyinformalleader = hhea+cr05`var'b_hhid

	bys hhid_familyinformalleader: egen vote_familyinformalleader = sum(familyinformalleader)

	keep hhid_familyinformalleader vote_familyinformalleader

	bys hhid_familyinformalleader: keep if _n==1

	rename hhid_familyinformalleader hhid
	rename vote_familyinformalleader vote_familyinformalleader`var'

	tempfile l5`var'
	save `l5`var'', replace
}

use `l5a', clear
mmerge hhid using `l5b'
mmerge hhid using `l5c'
mmerge hhid using `l5d'
mmerge hhid using `l5e'
drop _m

foreach var in "a" "b" "c" "d" "e" {
	replace vote_familyinformalleader`var'=0 if vote_familyinformalleader`var'==.
}

gen FAMILYINFORMALLEADER = (vote_familyinformalleadera>=2 |vote_familyinformalleaderb>=2 | vote_familyinformalleaderc>=2 | vote_familyinformalleaderd>=2 | vote_familyinformalleadere>=2)
label var FAMILYINFORMALLEADER "Family member of Informal leader"

mmerge hhid using `l4'
drop if _m==1

replace FAMILYINFORMALLEADER = 0 if _m==2

drop _m
tempfile l5
save `l5', replace


/* L6. NUMBER OF GROUPS HH PARTICIPATES IN WITHIN THE RT OR OUTSIDE THE RT
AND RT LEVEL GROUP MEETINGS HAVE YOU BEEN TO IN LAST MONTH*/

use "$data\baseline\hh_pm2.dta", clear
label var pm03 "Name of organization"
label var pm04 "Organization code"
label var pm04v  "Organization code, others"
label var pm05 "NUMBER OF HOUSEHOLD MEMBERS THAT JOIN THE GROUP[...]?"
label var pm06 "How many times have you participated in group activities [...] in the last  3 months?"
label var pm07 "How many were present usually in the group activities [...]  in the last  3 monthsr?"
label var pm08 "Do all  members  of  group [...] live in the same region?"

save "$codeddata/intermediate_data/hh_pm2.dta", replace

bys hhid: gen NGROUP = _N
label var NGROUP "Number of groups HH participates"

gen groupwithinRT = (pm08==1)

gen groupoutsideRT = (pm08!=1)

bys hhid: egen NGROUPWITHINRT = sum(groupwithinRT)
label var NGROUPWITHINRT "Number of groups HH participates within the RT"

bys hhid: egen NGROUPOUTSIDERT = sum(groupoutsideRT)
label var NGROUPOUTSIDERT "Number of groups HH participates outside the RT"

gen pm06_withinRT = pm06 if groupwithinRT==1
replace pm06_withinRT = 0 if pm06_withinRT==.

bys hhid: egen NMEETING_3MONTHS = sum(pm06_withinRT)
label var NMEETING_3MONTHS "RT level group meetings have you been to in the last 3 months"

keep hhid NGROUP groupwithinRT groupoutsideRT NGROUPWITHINRT NGROUPOUTSIDERT NMEETING*
bys hhid: keep if _n==1

mmerge hhid using `l5'
tempfile l6
save `l6', replace

/* L7. CLOSE TO THE POWER ABOVE KETUA RT AND CLOSE TO KETUA RT */

use "$data\baseline\hh_pm3.dta", clear
keep hhid pm2type pm16

reshape wide pm16, i(hhid) str j(pm2type)

foreach var of varlist pm16a- pm16e{
	replace `var' = (`var'==1)
}

label var pm16a "PM16a. Do you close with Village/ward head  or spouse"
label var pm16b "PM16b. Do you close with Village/ward  secretary or spouse"
label var pm16c "PM16c. Do you close with Chairman/members of regional parliament/ ward committee/community consultative forum"
label var pm16d "PM16d. Do you close with Hamlet/sub-ward/RT head or spouse"
label var pm16e "PM16e. Do you close with Household cluster head (RW) or   spouse"

gen CLOSEABOVEKETUART = (pm16a==1|pm16b==1|pm16c==1|pm16e==1)
label var CLOSEABOVEKETUART "Close to the power above ketua RT"

gen CLOSEWITHKETUART = (pm16d==1)
label var CLOSEWITHKETUART "Close to ketua RT"

mmerge hhid using `l6'
drop _m
tempfile l7
save `l7', replace


/* L8. NUMBER OF ELITE HH IN RT YOU ARE RELATED TO */

use "$codeddata\intermediate_data\formalleader.dta", clear
mmerge hhid using "$codeddata\intermediate_data\informalleader.dta"

keep hhid FORMALLEADER INFORMALLEADER

gen ELITE = FORMALLEADER==1| INFORMALLEADER==1

gen hhea = substr(hhid,1,3)

bys hhea: egen nFORMALLEADER = sum(FORMALLEADER)
label var nFORMALLEADER "Number of formal leader household in the RT"

bys hhea: egen nINFORMALLEADER = sum(INFORMALLEADER)
label var nINFORMALLEADER "Number of informal leader household in the RT"

bys hhea: egen nELITE = sum(ELITE)
label var nELITE "Number of elite household in the RT"

preserve
keep hhea n*
bys hhea: keep if  _n==1
sort hhea
save "$codeddata/intermediate_data/nELITE.dta", replace
restore

rename hhid hhid_cr01
tempfile l8
save `l8'

use "$data\baseline\hh_cr01.dta", clear

gen hhea = substr(hhid,1,3)
gen hhid_cr01 =hhea +cr01_hhid

mmerge hhid_cr01 using `l8'

drop if _m==2
replace ELITE = 0 if _m==1
drop _m


bys hhid:egen HHRELATED_ELITE =sum(ELITE)
label var HHRELATED_ELITE "Number of Elite households in RT you are related to"
keep hhid HHRELATED_ELITE
bys hhid: keep if _n==1

mmerge hhid using "$data\baseline\hh_ar1.dta"
replace HHRELATED_ELITE = 0 if _m==2

drop _m hhsize

mmerge hhid using `l7'
drop _m

compress
sort hhid
save "$codeddata\intermediate_data\socialconnection.dta", replace


*****
/* ETHNIC OR RELIGIOUS MINORITY */
*****


use "$data\baseline\k_id.dta", clear

keep kid id01 id03
gen hhea = substr(kid,1,3)

label var id01 "ID01. What is the largest ethnic"
label var id03 "ID03. What is the largest religious"
recode id03 (3=2) (2=3) (6=4) (4=5) (5=95)
label define id03 1 "1. Moslem" 2 "2. Catholicism" 3 "3. Protestantism" 4 "4. Buddhism" 5 "5. Hindu" 95 " 95. Other"
label val id03 id03

bys hhea: keep if _n==1
tempfile k1
save `k1', replace

use "$data\baseline\hh_krt.dta", clear

keep hhid krt02 krt03

label var krt02 "KRT02. What is the ethnic origin of  Household Head"
label var krt03 "KRT03. What is the religious of  Household Head"

gen hhea = substr(hhid,1,3)

label define id03 1 "1. Moslem" 2 "2. Catholicism" 3 "3. Protestantism" 4 "4. Buddhism" 5 "5. Hindu" 95 " 95. Other"
label val krt03 id03

mmerge hhea using `k1'
drop _m

gen ETHICMINORITY = (krt02!=id01)
gen RELIGIOUSMINORITY = (krt03!=id03)

compress
sort hhid
save "$codeddata\intermediate_data\minority.dta", replace


*****
/* M. CHARACTERISTIC OF RESPONDENT */
*****


use "$data/baseline/hh_cov.dta",clear
 
* keep only HH that were successfully interviewed
keep if hhcov6 == 1 

g ar00 = hhcov2no
keep hhid ar00

mmerge hhid ar00 using "$data/baseline/hh_ar2.dta"
label var ar00 "Serial code of respondent"
keep if _m==3 
drop _m

gen GENDERRESPONDENT = ar03
label define ar03 1 "1. Male" 3 "3. Female"
label val GENDERRESPONDENT ar03

replace ar12=. if ar12==95 | ar12==98 /* recode don't know and other to missing value for ar12. highest level */
replace ar13=. if ar13==98 /* recode don't know to missing value for ar13. highest grade */

gen YREDUCRESPONDENT = 0 if ar12==0|ar12==1
replace YREDUCRESPONDENT = ar13 if ar12==2 
replace YREDUCRESPONDENT = 6 if YREDUCRESPONDENT>=6
replace YREDUCRESPONDENT = 6 + ar13 if ar12==3 
replace YREDUCRESPONDENT = 9 if YREDUCRESPONDENT>=9
replace YREDUCRESPONDENT = 9 + ar13 if ar12==4 
replace YREDUCRESPONDENT = 12 if YREDUCRESPONDENT>=12
replace YREDUCRESPONDENT = 12 + ar13 if ar12==5 
replace YREDUCRESPONDENT = 15 if YREDUCRESPONDENT>=15
replace YREDUCRESPONDENT = 12 + ar13 if ar12==6 
replace YREDUCRESPONDENT = 16 if YREDUCRESPONDENT>=16
replace YREDUCRESPONDENT = 16 + ar13 if ar12==7 
replace YREDUCRESPONDENT = 20 if YREDUCRESPONDENT>=20
label var YREDUCRESPONDENT "Year of education of respondent"

keep hhid ar00 GENDERRESPONDENT YREDUCRESPONDENT

compress
sort hhid
save "$codeddata\intermediate_data\characteristic_respondent.dta", replace

// Households that get BLT 2008

use "$data\baseline\hh_ksr2.dta", clear
keep hhid ksr2type ksr04

keep if ksr2type=="b" /* keep only 2008 */
gen maintreatment = 4
gen BLT = 1
label var BLT "HH get BLT treatment in 2008"
gen RTS_BLT = (ksr04==1|ksr04==2)

keep hhid maintreatment BLT RTS_BLT
compress
sort hhid
save "$codeddata\intermediate_data\hhblt.dta", replace

// Subjective Rank questions

use "$data\baseline\hh_sw.dta", clear
keep hhid sw02 sw03

recode sw02 (8=.)
recode sw03 (7=.)

gen RANK_sw02= sw02/6
gen RANK_sw03= sw03/5

compress
sort hhid
save "$codeddata\intermediate_data\hh_sw.dta", replace

log close
