/* CODING BPS data */
/* Last Modified 14 April 2009 */

clear
set more off
set mem 256m

version 10

capture log close
log using "$output\Coding_files_output\coding_bps.log",replace


***********
* PMT AREA
***********

/* Form Updating for PMT area */
 
	/* coding for ud.dta removed for containing identifiers */

/* Form Cover for PMT area */

use "$data\bps\data_p_rmt.dta", clear
keep wilcah hhid /* namakrt */ kunjungan jumlahkel jumlahart blt 

rename wilcah hhea
tostring hhea, replace
replace hhea = "00" + hhea if length(hhea)==1
replace hhea = "0" + hhea if length(hhea)==2

rename hhid idrt
tostring idrt, replace
replace idrt = "00" + idrt if length(idrt)==1
replace idrt = "0" + idrt if length(idrt)==2

gen hhid = hhea + idrt

/* There are double observations. I have checked them. They are the same */
*bys hhid: keep if _n==1

rename kunjungan resultofvisit
label define resultofvisit 1 "1. Completed" 2 "2. Partly completed" 3 "3. Refused" 4 "4. HH is not around during Enumeration period" 5 "5. Not found"
label val resultofvisit resultofvisit

label var jumlahkel "number of family"
label var jumlahart "number of HH size"
label define blt 1 "1. Received BLT in 2005" 2 "2. Received BLT in 2008" 3 "3. Received BLT in 2005 & 2008" 4 "4. Not received"
label val blt blt
*label var kip "No identification of BLT"
 
sort hhid
compress
save "$codeddata\intermediate_data\data_p_rtm.dta", replace

/* Form PMT for PMT area */

use "$data\bps\pmt_p2k08.dta", clear
keep wilcah no hhid /* namakrt */ luaslantai - kategori ranking
rename wilcah hhea
tostring hhea, replace
replace hhea = "00" + hhea if length(hhea)==1
replace hhea = "0" + hhea if length(hhea)==2

rename hhid idrt
tostring idrt, replace
replace idrt = "00" + idrt if length(idrt)==1
replace idrt = "0" + idrt if length(idrt)==2

gen hhid = hhea + idrt

label var lnpcexp "log per capita expenditure from PMT"
label var epcexpe "per capita expenditure from PMT"

rename kategori RTS
label var RTS "poor household who got Rp 30,000"

label var ranking "ranking from the experiment"

bys hhea: gen nhhrank=_N
label var nhhrank "number of household being ranked"

gen TREATRANK= ranking/nhhrank
label var TREATRANK "percentile rank from experiment"

gen ranking_PMT = ranking

sort hhid
compress
save "$codeddata\intermediate_data\pmt_p2k08.dta", replace



*****
/* Hybrid */


/* Form Updating for Hybrid area */
 
	/* Coding for "$data\bps\f7b.dta" removed for containing identifiers */


/* Form Cover for Hybrid area */

use "$data\bps\data_h_rmt.dta", clear
keep wilcah hhid /* namakrt */ kunjungan jumlahkel jumlahart blt 

rename wilcah hhea
tostring hhea, replace
replace hhea = "00" + hhea if length(hhea)==1
replace hhea = "0" + hhea if length(hhea)==2

rename hhid idrt
tostring idrt, replace
replace idrt = "00" + idrt if length(idrt)==1
replace idrt = "0" + idrt if length(idrt)==2

gen hhid = hhea + idrt

/* There are double observations. I have checked them. They are the same */
bys hhid: keep if _n==1

rename kunjungan resultofvisit
label define resultofvisit 1 "1. Completed" 2 "2. Partly completed" 3 "3. Refused" 4 "4. HH is not around during Enumeration period" 5 "5. Not found" 6 "6. Traveling" 7 "7. Merged with other HH"
label val resultofvisit resultofvisit

label var jumlahkel "number of family"
label var jumlahart "number of HH size"
label define blt 1 "1. Received BLT in 2005" 2 "2. Received BLT in 2008" 3 "3. Received BLT in 2005 & 2008" 4 "4. Not received"
label val blt blt
*label var kip "No identification of BLT"
 
sort hhid
compress
save "$codeddata\intermediate_data\data_h_rtm.dta", replace


/* Form PMT for Hybrid area */

use "$data\bps\pmt_hybrid.dta", clear
keep wilcah no hhid /* namakrt */ luaslantai - kategori ranking
rename wilcah hhea
tostring hhea, replace
replace hhea = "00" + hhea if length(hhea)==1
replace hhea = "0" + hhea if length(hhea)==2

rename hhid idrt
tostring idrt, replace
replace idrt = "00" + idrt if length(idrt)==1
replace idrt = "0" + idrt if length(idrt)==2

gen hhid = hhea + idrt

label var lnpcexp "log per capita expenditure from PMT"
label var epcexpe "per capita expenditure from PMT"

rename kategori RTS
label var RTS "poor household who got Rp 30,000"

rename ranking ranking_PMT
label var ranking_PMT "ranking from PMT"

sort hhid
compress
save "$codeddata\intermediate_data\pmt_hybrid.dta", replace

/* Create TREATRANK for Hybrid */

use "$codeddata\intermediate_data\pmt_hybrid.dta", clear
keep hhea RTS ranking hhid  lnpcexpe epcexpe
mmerge hhid using "$codeddata\intermediate_data\f7b_bps.dta", type(1:1)
drop _m
destring hhea, replace
sort hhea
tempfile a
save `a', replace

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea maintreatment quota_final
keep if maintreatment==3

mmerge hhea using `a', type(1:n)

gen ranking = ranking_PMT 
replace ranking = ranking_meeting if ranking==.
label var ranking "ranking from the experiment" 

/* BPS should enumerate 1.5*quota HH. But sometimes these households could not be interviewed because they were not avalaible or refused */
bys hhea ranking: gen x=_N
replace ranking = . if x==2 & ranking_PMT==.
drop x

bys hhea: egen nhhrank_1= max(ranking)
label var nhhrank_1 "number of household being ranked from experiment"

gen TREATRANK= ranking/nhhrank_1
label var TREATRANK "percentile rank from experiment"

bys hhea: egen nhhrank_2= max(ranking_meeting)
label var nhhrank_2 "number of household being ranked from meeting"

gen TREATRANK_2= ranking_meeting/nhhrank_2
label var TREATRANK_2 "percentile rank from meeting"

gen RTS_meeting = (ranking_meeting <= quota)
label var RTS_meeting "beneficiaries households based on meeting results"

sort hhid
compress
save "$codeddata\intermediate_data\rts_hybrid.dta", replace


log close
