/* CODING Community data */
/* Last Modified 21 April 2009 */

clear
set more off
set mem 256m

version 10

set sortseed 10000


capture log close
log using "$output\Coding_files_output\coding_mitra.log",replace

/* Form 1 attendance */

* Form 1a : all community

use "$data\mitra\f1a_dh.dta", clear
rename wilker hhea

/* Keep for first meeting only */
drop if pw==2
drop pw

replace  dh_q1="" if  dh_q1=="Z99" /* idrt=Z99 means missing */

replace  dh_q1="876" if hhea=="611" & dh_q0==45
drop if dh_q1==""

generate hhid= hhea+dh_q1

gen hh_attend = ( dh_q3 ==1| dh_q5 ==1| dh_q7 ==1)
label var hh_attend "Household attend the meeting)

keep hhea hhid hh_attend
tempfile f1a
save `f1a', replace

* Form 1b : all tokoh

use "$data\mitra\f1b_dh.dta", clear

rename wilker hhea
/* Keep for first meeting only */
drop if pw==2
drop pw

generate hhid= hhea+bdh_q1

gen hh_attend = 1
label var hh_attend "Household attend the meeting"

gen form1b=1

keep hhea hhid hh_attend form1b
bys hhid: keep if _n==1

mmerge hhid using `f1a'
gen tokoh_attend = 1 if _m==3
label var tokoh_attend "Elite attend the meeting from Form 1b"
drop _m

sort hhid
compress
save "$codeddata/intermediate_data/f1_hhattend.dta", replace


/* Form 2 General information */

use "$data\mitra\f2_data.dta", clear
keep wilker pw c_q1a c_q2a c_q3a d_q1l d_q1p
rename wilker hhea

/* Keep for first meeting only */
drop if pw==2
drop pw

* Raining at the start of the meeting
label var c_q1a "c1a. Raining at the start of the meeting"
label var c_q2a "c1b. Raining at the middle of the meeting"
label var c_q3a "c1a. Raining at the end  of the meeting"

gen raining_start = (c_q1a==1 | c_q1a==2)

gen small_rain =(c_q2a==1|c_q3a==1)
gen heavy_rain =(c_q2a==2|c_q3a==2)

* Total attendance
label var d_q1l "number of men attended the meeting"
label var d_q1p "number of women attended the meeting"

gen total_attend2 = (d_q1l +d_q1p)

replace total_attend2 = . if d_q1l==999| d_q1p==999 
replace d_q1l = . if d_q1l==999
replace d_q1p = . if d_q1p==999

gen swomen_attend = d_q1p/total_attend2

sort hhea
compress

save "$codeddata\intermediate_data\f2_data.dta", replace


/* Form 3 Community data */
 
use "$data\mitra\f3_kla.dta", clear

label var kla_q1 "Q1. serial number"
*label var kla_q3 "Q3. name of household head"
*label var kla_q4 "Q4. name of spouse"
label var kla_q5 "Q5. number of family"
label var kla_q6 "Q6. updating"
label define kla_q6 1 "1. found" 2 "2. Found, but the name of HH head is wrong/changing" 3 "3. HH head passed away without other HH member" 4 "4. Moved" 5 "5. HH not listed yet" 6 "6. Split from other HH which lives in this RT" 7 "7.	Merged with other HH in this RT (2 HH or more become 1)" 8 "8. Other" 9 "9. Missing"
label val kla_q6 kla_q6
label var kla_q6_8 "Q6. code 8. Other"
*label var kla_q7 "Q7. name of household head if Q6==2"
label var kla_q8 "Q8. household id if Q6==7 or 8"

replace kla_q6=7 if wilker=="402" & kla_q2=="229"

replace kla_q8="450" if wilker=="402" & kla_q2=="229"

generate hhid= wilker+kla_q2
generate hhidinduk= wilker+kla_q8 if kla_q8!=""
label var hhidinduk "HHID because of split or merge"

rename kla_q2 idrt
rename wilker hhea

sort hhid
compress
save "$codeddata\intermediate_data\f3_kla.dta", replace



/* Form 4: Agenda */

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea maintreatment poor10subtreatment numhhsls_dec
drop if maintreatment==1
tempfile f41
save `f41', replace

* Form 4a. agenda meeting without 10 poorest HH

use "$data\mitra\f4a_ap.dta", clear
keep wilker pw ap_q6*_hr ap_q6*_mnt ap_q7_hr ap_q7_mnt  
rename wilker hhea
destring hhea, replace
mmerge hhea using `f41'
keep if poor10subtreatment==0 /* Form 4a. agenda meeting without 10 poorest HH */
tempfile f42
save `f42', replace

* Form 4b. agenda meeting with 10 poorest HH

use "$data\mitra\f4b_ap.dta", clear
keep  wilker pw ap_q7*_hr ap_q7*_mnt ap_q8_hr ap_q8_mnt
rename wilker hhea

renpfix ap_q7 ap_q6
renpfix ap_q8 ap_q7

destring hhea, replace
mmerge hhea using `f41'
keep if poor10subtreatment==1 /* Form 4a. agenda meeting with 10 poorest HH */

append using `f42'

drop if hhea==19 & pw==9 /* double observation */

* first meeting *
preserve
drop if pw==2  

*keep  hhea pw ap_q6a_hr ap_q6a_mnt ap_q7_hr ap_q7_mnt maintreatment 

label var ap_q6a_hr "Start rank hh no 1 (hour)"
label var ap_q6a_mnt "Start rank hh no 1 (minute)"

label var ap_q7_hr "Start reading HH ranking (hour)"
label var ap_q7_mnt "Start reading HH ranking (minute)"

replace ap_q7_hr = . if ap_q7_hr ==99
replace ap_q7_mnt = . if ap_q7_hr ==99

** editing the data entry

gen ranking_time1 = (ap_q7_hr + (ap_q7_mnt/60)) - (ap_q6a_hr + (ap_q6a_mnt/60))
/* We use var ap_q7_hr because ap_q6dd_hr has many missing variables */
replace ranking_time1 = . if ranking_time < = 0 

label var ranking_time1 "ranking time for the first meeting (hour)"


keep hhea ranking_time1
tempfile f43
save `f43', replace

restore

* Second meeting *

keep if pw==2

**** DO IT MANUALLY ************************************ *********************************************************
gen ranking_start2_hr = ap_q6l_hr if hhea==6
gen ranking_start2_min = ap_q6l_mnt if hhea==6

replace ranking_start2_hr = ap_q6g_hr if hhea==96
replace ranking_start2_min = ap_q6g_mnt if hhea==96

replace ranking_start2_hr = ap_q6f_hr if hhea==124
replace ranking_start2_min = ap_q6f_mnt if hhea==124

replace ranking_start2_hr = ap_q6g_hr if hhea==162
replace ranking_start2_min = ap_q6g_mnt if hhea==162

replace ranking_start2_hr = ap_q6j_hr if hhea==3
replace ranking_start2_min = ap_q6j_mnt if hhea==3

replace ranking_start2_hr = ap_q6j_hr if hhea==70
replace ranking_start2_min = ap_q6j_mnt if hhea==70

replace ranking_start2_hr = ap_q6f_hr if hhea==84
replace ranking_start2_min = ap_q6f_mnt if hhea==84

replace ranking_start2_hr = ap_q6j_hr if hhea==122
replace ranking_start2_min = ap_q6j_mnt if hhea==122

replace ranking_start2_hr = ap_q6g_hr if hhea==123
replace ranking_start2_min = ap_q6g_mnt if hhea==123


label var ap_q7_hr "Start reading HH ranking (hour)"
label var ap_q7_mnt "Start reading HH ranking (minute)"

replace ap_q7_hr = . if ap_q7_hr ==99
replace ap_q7_mnt = . if ap_q7_hr ==99


gen ranking_time2 = (ap_q7_hr + (ap_q7_mnt/60)) - (ranking_start2_hr + (ranking_start2_min/60)) 
label var ranking_time2 "ranking time for the second meeting (hour)"

drop if ranking_time2==.

keep hhea ranking_time2

mmerge hhea using `f43'

drop _m
egen ranking_time = rsum(ranking_time1 ranking_time2)
replace ranking_time = . if ranking_time==0
label var ranking_time "ranking time (hour)"

sort hhea
compress
save "$codeddata/intermediate_data/ranking_time.dta", replace

/* Form 7b Ranking */

use "$data\mitra\f7b_ranking.dta", clear

generate hhid= wilker+r2_q2
rename r2_q0 ranking
rename r2_q2 idrt
rename wilker hhea

label var ranking "ranking from the experiment"
gen ranking_meeting = ranking

bys hhea: gen nhhrank=_N
label var nhhrank "number of household being ranked"

gen TREATRANK= ranking/nhhrank
label var TREATRANK "percentile rank from the experiment"

gen TREATRANK_2= ranking_meeting/nhhrank
label var TREATRANK_2 "percentile rank from meeting"

** Check for duplicate ranking 
bys hhid: gen y = _N
tab y 
** There are 7 HH with duplicate ranking and we have check with the hardcopy

replace ranking = . if y==2 
replace TREATRANK = . if y==2
replace TREATRANK_2 = . if y==2

drop y
bys hhid: keep if _n==1

sort hhid
compress
save "$codeddata\intermediate_data\f7b_ranking.dta", replace

/* Create RTS dataset for community because RTS form has not been enter */

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea maintreatment quota_final
keep if maintreatment==2
tempfile a
save `a', replace

use "$codeddata\intermediate_data\f7b_ranking.dta", clear
destring hhea, replace
mmerge hhea using `a'
drop if _m==1
drop _merge
gen RTS = (ranking<=quota)

gen RTS_meeting = RTS
replace RTS=. if ranking==.
label var RTS_meeting "beneficiaries households based on meeting results"

sort hhid
compress
save "$codeddata\intermediate_data\RTS_community.dta", replace


/* Form 9a: most talkative people */

* Tokoh
use "$data\mitra\f9a_ub1a.dta", clear
keep wilker pw ub1_a0 /* ub1_a1 */ ub1_a2 ub1_a3 ub1_a4 

rename wilker hhea
*rename ub1_a1 name
rename ub1_a2 idrt

rename ub1_a3 sex
label define sex 1 "1. Male" 3 "3. Female" 9 "9. Missing"
label val sex sex

rename ub1_a4 position
label define  position 1 "01. Village Head" 2 "02. Village Secretary" 3 "03. Head of Development/Governance department,etc" 4 "04. Head/member of LKMD, LMD,BAPERDES.BPD, etc" 5 "05. RW Head" 6 "06. RT/Hamlet Head" 7 "07. Religious leader" 8 "08. Tribe leader" 9 "09. Headmaster/teacher" 10 "10. Civil servant" 95 "95. Others" 99 "99. Missing"
label val position position

tempfile f9a1
save `f9a1', replace

* Common people
use "$data\mitra\f9a_ub1b.dta", clear
keep wilker pw ub1_b0 /* ub1_b1 */ ub1_b2 ub1_b3 

rename wilker hhea
*rename ub1_b1 name
rename ub1_b2 idrt

rename ub1_b3 sex
label define sex 1 "1. Male" 3 "3. Female" 9 "9. Missing"
label val sex sex

append using `f9a1'

sort hhea ub1_a0 ub1_b0
gen tokoh = (ub1_a0!=.)
gen commonpeople = (ub1_b0!=.)

gen female = (sex==3)

collapse (sum) nTOKOH=tokoh ncommonpeople=commonpeople nfemale=female, by(hhea)

label var nTOKOH "Number of tokoh who most talkative"
label var ncommonpeople "Number of commonpeople who most talkative"
label var nfemale "number of female who most talkative"

gen ntalkative = nTOKOH + ncommonpeople
label var ntalkative "Number of people who most talkative"

gen sfemale = nfemale/ntalkative
label var sfemale "share of female who most talkative"

sort hhea
compress
save "$codeddata/intermediate_data/f9a.dta", replace



/* Form 9b: Facilitator feedback */

* Community meeting

use "$data\mitra\f9b_ub2c.dta", clear
keep ub2_c1i ub2_c6 wilker pw
rename wilker hhea

keep if pw==1 /* Keep for first meeting only */
drop pw

label var ub2_c1i "C1. Did poor people attend?"
recode ub2_c1i (3=0) (9=.)

label var ub2_c6 "C6. community participation in the meeting"
label define ub2_c6 1 "1. all community active" 2 "2. several people dominated the meeting" 9 "9. missing"

replace ub2_c6 = . if ub2_c6==9
gen dominated = (ub2_c6==2)
label var dominated "meeting is dominated by several people"

sort hhea
compress
save "$codeddata\intermediate_data\f9b_ub2c.dta", replace

/* Fund Distribution */

use "$data\mitra\fd_a.dta", clear

rename wilker hhea

recode a_q2 (99=.)
label var a_q2 "How was the fund distributed?"

gen method_meeting = (a_q2==2)
replace method_meeting = . if a_q2 == .
label var method_meeting "The fund is distributed in the meeting"

recode a_q7 (3=0) (9=.)
label var a_q7 "Did facilitator encounter any difficulty in distributing the fund?"

keep hhea a_q2 a_q7 method_meeting
sort hhea
compress
save "$codeddata\intermediate_data\fd_a.dta", replace


use "$data\mitra\fd_b.dta", clear

rename wilker hhea
gen get_money = ( b_q5 ==1| b_q5 ==2| b_q5 ==3)
replace get_money = . if  b_q5==97 | b_q5==99 

bys hhea: gen sum_rts = _N
egen sum_get_money = sum(get_money), by(hhea)
label var sum_get_money "Total households that get the money"
gen sget_money = sum_get_money/sum_rts
label var sget_money "share household that get the money"

keep hhea sum_rts sum_get_money sget_money
bys hhea: keep if _n==1

sort hhea
compress
save "$codeddata\intermediate_data\fd_b.dta", replace

/* Pak RT interview */

use "$data\mitra\c_data.dta", clear
keep wilker c_q1a_hhid c_q11a c_q3 c_q5 c_q9 c_q12
rename wilker hhea
rename c_q1a_hhid hhid
gen RTHEAD_int = 1

** Number of complain
gen ncomplain_receivedbyRT = c_q12
replace ncomplain_receivedbyRT = 0 if ncomplain_receivedbyRT==.

** Satisfaction

label var c_q11a "Q11a. In your opinion, are the people satisfied with P2K08 activities in this RT in general?"
label define c_q11a  1 "1. Very satisfied" 2 "2. Satisfied" 3 "3. A little bit disatisfied" 4 "4. Very disatisfied" 9 "9. Missing"
label val c_q11a c_q11a
recode c_q11a (9=.)

** Appropriateness 

label var c_q3 "Q3. In your opinion, is the method (survey/community/hybrid) applied to find targeted HH correct?"
label define c_q3 1 "1. yes" 3 "3. No" 9 "9. Missing"
label val c_q3 c_q3
recode c_q3 (3=0) (9=.)

** Better than BLT question 

label var c_q5 "Q5. In your opinion, how is this method if compared with other method (like BLT) in determining targeted HH?"
label define c_q5 1 "1. More correct" 2 "2. The same" 3 "3. Not correct" 9 "9. Missing"
label val c_q5 c_q5
recode c_q5 (9=.)

** Number of HH that should be added to list (dummy for not saying "it s ok") 

label var c_q9 "Q9.In your opinion, is the numper of people included in the List of targeted HH too few, already correct, or too many?"
recode c_q9 (9=.)
gen D_add = (c_q9==1)

** Number of HH that should be subtracted to list (dummy)

gen D_subtract = (c_q9==3)

compress
sort hhid
save "$codeddata\intermediate_data\c_data.dta", replace


log close
