/* CODING PODES 2008 */
/* Last Modified 17 April 2009 */

clear

set more off
set mem 256m

version 10
set sortseed 10000


capture log close
log using "$output\Coding_Files_output\coding_podes08.log", text replace

/* PODES 2008 */

use "$data\other\pds2008.dta", clear


rename r3031_4 R
label var R "Number of smallest neighborhood (RT) in the village"

label var r401c "401c. Number of families"
label define missing 99998 "99998. Missing"
label var r601b_2 "601b.2. Number of public primary school"
label var r601b_3 "601b.3. Number of public private school"

egen primary_school_total = rsum(r601b_2 r601b_3)
gen PRIMARYSCHOOLPERHH = primary_school_total/r401c

gen villsd = ((r601b_2 >0 & r601b_2 !=.) | (r601b_3 >0 & r601b_3 !=.))
gen villsmp = ((r601c_2 >0 & r601c_2 !=.) | (r601c_3 >0 & r601c_3 !=.))
label var villsd "Existing of SD"
label var villsmp "Existing of SLTP"


label var r703a "703a. Mosque"
label var r703c "703c. Protestan Church"
label var r703d "703d. Chatolic church"
label var r703e "703e. Temple"
label var r703f "703f. Vihara"

egen r1001 = rsum(r1002a r1002b r1002c)
replace r1001= r1001/10
label var r1001 "Size of village in hectares"
gen LOGVILLAGESIZE = log(r1001)

drop r1002a r1002b r1002c

foreach x in d e h i j {
	destring r604`x'_2, replace
}

foreach x in r901b1 r1104a r1113a r1113b r1113c r1113d {
	destring `x', replace
}

recode r606a1 r606a2 r606c (97 98 99=.)

gen villpusk = (r604d_2 ==1 | r604e_2 ==1)
gen villposk = (r604h_2 ==1)
gen villpolin = (r604i_2 ==1)
gen villposy = (r604j_2 ==1)
gen villdokt = ((r606a1 >0 & r606a1 !=.) | (r606a2 >0 & r606a2 !=.))
gen villbidan = (r606c >0 & r606c !=.)
gen villrtype = (r901b1 ==1)
gen villpmplace = (r1104a ==1)
gen villcred = (r1113a ==1 | r1113b ==3 | r1113c ==5 | r1113d ==7)


label var villpusk "Existing of Puskesmas/Pustu"
label var villposk "Existing of Poskesdes"
label var villpolin "Existing of Polindes"
label var villposy "Existing of Posyandu"
label var villdokt "Avaibility of Doctor"
label var villbidan "Avaibility of Bidan"
label var villrtype "Road type is Asphalt"
label var villpmplace "Existing of Semi/permanent market place"
label var villcred "Existing of Credit Facility"

egen religious_building_total = rsum(r703a r703c r703d r703e r703f)
gen RELIGIOUSBUILDINGPERHH = religious_building_total/r401c

keep prop kab RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH kec desa R r401c r601b_2 r601b_3 r601c_2 r601c_3 r703a r703b r703c r703d r703e r703f r1001 LOGVILLAGESIZE vill*
tempfile b
save `b', replace

/* BPS do not give the data distance to kecamatan to public for Podes 2008 because they said the data is not reliable. But we have this data from pak Kadar */
use "$data\other\jml3pro.dta", clear
append using "$data\other\nsumatera.dta"
keep prop kab kec desa klas r9021_2 r9022_2
rename klas klas_desa

label var r9021_2 "Distance to kecamatan (km)"
recode  r9021_2 (0=.)
gen DISTANCEKEC = r9021_2/10

recode r9022_2 (980 980.9 997 998 998.8 999 999.8=.)
recode  r9022_2 (0=.)
rename r9022_2 vill2dist
label var vill2dist "Distance to district capital"

bys prop kab kec desa: keep if _n==1

mmerge prop kab kec desa using `b'
drop if _m==1
drop _m

destring prop kab kec desa, replace
sum
save "$codeddata\intermediate_data\coding_podes08.dta", replace

log close


