/* Create PMT score */
/* Last Modified 31 March 2009 */

clear

set more off
set mem 256m

version 10

set sortseed 10000

capture log close
log using "$output\Coding_Files_output\coding_suseti_pmt.log",replace

** Set variables to use in regressions

local regressors "urban pcfloor tfloor twall toilet water lighting troof fcook house credit hhsize hhsize2 hhage hhage2 hhmale hhmarried hhmalemarr hhsector1 hhsector2 hhsector3 formal informal hheduc2 hheduc3 hheduc4 age04 eschild jschild sschild higheduc2 higheduc3 higheduc4 depratio vill2dist villsd villsmp villpusk villpolin villposy villdokt villbidan villrtype villpmplace villcred"

local assets "se2_115 se2_117 se2_13_15 se2_11_12 se2_14 se2_114 se2_18 se2_17 se2_124 se2_125 se2_126_127 se2_119 se2_122_123 se5_110 se5_11_12"

**********************************
** Predict consumption		**
**********************************;

/* Merge all variables PMT variables from PMT */

use "$codeddata\intermediate_data\hhhead.dta", clear
keep hh*
mmerge hhid using "$codeddata\intermediate_data\consumption.dta"
mmerge hhid using "$codeddata\intermediate_data\hhhead.dta"
mmerge hhid using "$codeddata\intermediate_data\hhcharacteristic.dta"
mmerge hhid using "$codeddata\hh_ar2.dta"
mmerge hhid using "$codeddata\intermediate_data\hhasset.dta"
destring hhea, replace
mmerge hhea using "$codeddata/intermediate_data/coding_treatment.dta", 
drop prop_nm kab_nm kecagroup _merge
mmerge prop kab kec desa using "$codeddata\intermediate_data\coding_podes08.dta"
keep if _m==3

gen urban = (klas_desa==1)

** Gen per capita floor area

gen pcfloor  = floor / hhsize
label var pcfloor "Household floor area Per capita"

gen kabu = prop*100 + kab

mmerge kabu using "$data\other\sc100.dta"
keep if _m==3
mmerge kabu using "$data\other\uc100.dta"

foreach z in `regressors' {
	gen comp_`z' = `z' * c_`z'
}

foreach z in `assets' {
	egen `z'_avg = mean(`z'), by(kabu)
	gen `z'_dm = `z' - `z'_avg
	gen comp2_`z' = `z'_dm * c_`z'
}

capture drop temp*
egen temp1 =rsum(comp_*)
egen temp2 =rsum(comp2_*)
gen temp4 = temp1 + c__cons
gen temp_s = exp(temp4)
gen pcexppred = temp_s + temp2
label var pcexppred "Per capita consumption from PMT"

gen PMTSCORE = log(pcexppred)
label var PMTSCORE "Log Per capita consumption from PMT" 

bys hhea: egen rank_pmt = rank(pcexppred)
label var rank_pmt "Rank based on Per capita consumption from PMT within village"
bys hhea: gen nhhrank_pmt=_N
label var nhhrank_pmt "number of household in village from PMT"

gen PMTRANK= rank_pmt/nhhrank_pmt
label var PMTRANK "Rank per capita consumption from PMT within village in percentiles"

compress
sort hhid

save "$codeddata/coding_suseti_pmt.dta", replace

log close
