/* Create Mistargeting data */

/* Last Modified 7 June 2009 */

clear

set more off
set mem 256m

version 10

set sortseed 10000

capture log close
log using "$output\mistargeting.log",replace


********************

/* create onlist data = beneficiaries households that get Rp 30,000 */

	use "$codeddata/intermediate_data/match_suseti_experiment.dta", clear
	keep hhid_exp hhid_suseti maintreatment 
	label var hhid_suseti "Household id in baseline survey"
	label var hhid_exp "Household id in experiment"
	sort hhid_exp

	* keep if hhid_exp is equal to missing
	preserve
	keep if hhid_exp==""
	tempfile b1
	save `b1', replace
	restore

	drop if hhid_exp==""
	tempfile a
	save `a', replace

	* PMT Area *

	use "$codeddata\intermediate_data\pmt_p2k08.dta", clear
	keep hhea lnpcexpe epcexpe RTS ranking hhid nhhrank TREATRANK ranking_PMT
	rename hhid hhid_exp
	mmerge hhid_exp using `a'

	keep if _m==3
	drop _m
	tempfile b2
	save `b2'

	* Community area *

	use "$codeddata\intermediate_data\RTS_community.dta", clear	
	rename hhid hhid_exp
	mmerge hhid_exp using `a'

	keep if _m==3
	drop _m
	sort hhid_exp
	tempfile b3
	save `b3'

	* Hybrid area *

	use "$codeddata\intermediate_data\rts_hybrid.dta", clear
	rename hhid hhid_exp
	mmerge hhid_exp using `a'

	keep if _m==3

	replace RTS = 0 if RTS==.
	drop _m
	sort hhid_exp
	tempfile b4	
	save `b4'

	* Combine all *
	
	use `b1', clear
	append using `b2'
	append using `b3'
	append using `b4'

	replace RTS_meeting=RTS if main==1

	tempfile b5
	save `b5', replace
	
	compress
	sort hhid_suseti
	save "$codeddata\intermediate_data\hhrts.dta", replace

/* Merge with consumption */

	use "$codeddata\intermediate_data\consumption.dta", clear
	keep hhid CONSUMPTION LOGCONSUMPTION
	
/* Merge with minority */
	
	mmerge hhid using "$codeddata\intermediate_data\minority.dta", type(1:1)
	drop  krt02 krt03 hhea kid id01 id03
	label var ETHICMINORITY "Dummy variable for ethnic minority"
	label var RELIGIOUSMINORITY "Dummy variable for religious minority"
	 
/* Merge with shock */

	mmerge hhid using "$codeddata\intermediate_data\aggregatevar.dta", type(1:1)
	
	drop hhea-connectedness avg_connectedness- ge01v		
	
	rename hhid hhid_suseti

	mmerge hhid_suseti using `b5', type(1:1)
	
	drop _m
	tempfile d
	save `d', replace

/* Merge with RT head HHID */

	use "$codeddata/intermediate_data/rthead.dta", clear
	keep hhid RTHEAD
	rename hhid hhid_suseti
	mmerge hhid_suseti using `d', type(1:1)
	
	drop _m
	replace RTHEAD = 0 if RTHEAD==.

	drop hhea
	gen hhea = substr(hhid_suseti,1,3)
	destring hhea, replace
	sort hhea
	tempfile e
	save `e', replace

/* Merge with treatment data */

	use "$codeddata\intermediate_data\coding_treatment.dta", clear
	keep hhea prop  kab kec klas_desa desa kecagroup numhhsls_dec  maintreatment tokohsubtreatment poor10subtreatment daynightsubtreatment

	* We use number of households in RT before the experiment *
	rename numhhsls_dec N
	
	gen PMT = (maintreatment==1)
	gen COMMUNITY = (maintreatment==2)
	gen HYBRID = (maintreatment==3)

	rename tokohsubtreatment ELITE 
	replace ELITE = 0 if ELITE==.
	label var ELITE "ELITE treatment"
	
	rename poor10subtreatment POOREST10 
	replace POOREST10 = 0 if POOREST10==.
	label var POOREST10 "10 POOREST treatment"
	
	gen DAYMEETING = 1 if daynightsubtreatment==0
	replace DAYMEETING = 0 if daynightsubtreatment==1
	replace DAYMEETING = 0 if DAYMEETING==.
	drop daynightsubtreatment
	label var DAYMEETING " Day meeting treatment"

	gen ELITEHYBRID = ELITE * HYBRID
	label var ELITEHYBRID "ELITE * HYBDRID"
	tempfile f1
	save `f1', replace

	use "$codeddata\intermediate_data\coding_podes08.dta", clear
	keep prop kab kec desa R
	
	mmerge prop kab kec desa using `f1'
	keep if _m==3
	drop _m

/* merge with poverty headcount data */

	mmerge prop klas_desa using "$other\headcount.dta"
	mmerge hhea using `e'

	drop _m

	gen weight = (N*R)/8 if RTHEAD==0
	replace weight = R if RTHEAD==1

/* Create poor */

	headcount CONSUMPTION [w=weight],hc(poorhc) gen(verypoor) by(prop klas) id(hhid_suseti)
	drop newwgt pce
	rename povline povline_verypoor
	label var povline_verypoor "Poverty line for very poor"
	rename poorhc verypoorhc
	label var verypoorhc "Headcount for very poor"
	label var verypoor
	label var verypoor "Dummy variable for very poor"

	headcount CONSUMPTION [w=weight],hc(nearpoorhc) gen(poor) by(prop klas) id(hhid_suseti)
	drop newwgt pce
	rename povline povline_poor
	label var povline_poor "Poverty line for poor"
	rename nearpoorhc poorhc
	label var poorhc "Headcount for poor"
	label var poor "Dummy variable for poor"

	gen nearpoor = poor==1 & verypoor==0
	label var nearpoor "Dummy variable for near poor"

	gen middlehc = ((100- poorhc)/2) +  poorhc
	label var middlehc "Headcount for middle household"

	headcount CONSUMPTION [w=weight],hc(middlehc) gen(middle) by(prop klas) id(hhid_suseti)
	drop newwgt pce povline
	
	replace middle = 0 if poor==1
	label var middle "Dummy variable for middle"

	gen rich = middle == 0 & poor==0
	label var rich "Dummy variable for rich"

	** this ado files create dupplicate observation so that it could cut the povline
	bys hhid_suseti: keep if _n==1

/* Create inclusion/exclusion dummies */

	gen MISTARGETDUMMY  = 1 if poor==1 & RTS==0
	replace MISTARGETDUMMY  = 1 if poor==0 & RTS==1
	replace MISTARGETDUMMY  = 0 if MISTARGETDUMMY ==.

	gen MISTARGETNONPOORDUMMY  = 1 if poor==0 & RTS==1
	replace MISTARGETNONPOORDUMMY  = 0 if poor==0 & RTS==0

	gen MISTARGETRICHDUMMY  = 1 if rich==1 & RTS==1
	replace MISTARGETRICHDUMMY  = 0 if rich==1 & RTS==0

	gen MISTARGETMIDDLEDUMMY  = 1 if middle==1 & RTS==1
	replace MISTARGETMIDDLEDUMMY  = 0 if middle==1 & RTS==0

	gen MISTARGETPOORDUMMY  = 1 if poor==1 & RTS==0
	replace MISTARGETPOORDUMMY  = 0 if poor==1 & RTS==1

	gen MISTARGETNEARPOORDUMMY  = 1 if nearpoor==1 & RTS==0
	replace MISTARGETNEARPOORDUMMY  = 0 if nearpoor==1 & RTS==1

	gen MISTARGETVERYPOORDUMMY  = 1 if verypoor==1 & RTS==0
	replace MISTARGETVERYPOORDUMMY  = 0 if verypoor==1 & RTS==1

	gen MISTARGETRICHDUMMY_pol  = 1 if poor==0 & RTS==1
	replace MISTARGETRICHDUMMY_pol  = 0 if poor==1 & RTS==1

	gen povertygap = abs(CONSUMPTION - povline_poor)/povline_poor if MISTARGETDUMMY == 1
	replace povertygap = 0 if MISTARGETDUMMY == 0

	tempfile g
	save `g', replace


/* merge with variables in randomization data */

	use "$codeddata\randomizationdata.dta", clear
	mmerge hhea using `g'
	drop _m

foreach var of varlist elite_connectedness ETHICMINORITY RELIGIOUSMINORITY shock {
	gen C_`var' = COMMUNITY * `var'
	label var C_`var' "COMMUNITY * `var'"
 
	gen H_`var' = HYBRID * `var'
	label var H_`var' "HYBRID * `var'"
	
	gen E_`var' = ELITE * `var'
	label var E_`var' "ELITE * `var'"
	
	gen E_H_`var' = ELITEHYBRID * `var'
	label var E_H_`var' "ELITEHYBRID * `var'"
}

label var prop "Povince code"
label var kab "District code"
label var kec "Subdistrict code"
label var desa "Village code"

label var RTHEAD "Dummy variable for RT head"
label var ranking_PMT "Household ranking based on PMT"
label var ranking_meeting "Household ranking based on Community meeting"

label var quota_final "Village quota"

drop idrt TREATRANK_2 

sort hhid_suseti
compress
save "$codeddata/mistargeting.dta", replace

log close
