/* Create Rank correlations data */

/* Last Modified 26 April 2009 */

clear
set more off
set mem 256m

version 10

capture log close
log using "$output\Coding_Files_output\rankcorrelation.log",replace


********************

/* Create CONSRANK = consumtion rank */

	use "$codeddata\intermediate_data\consumption.dta", clear
	keep hhid rank_pcexp RANKCONSUMPTION
	rename RANKCONSUMPTION CONSRANK
	tempfile c
	save `c', replace

/* Create COMMRANK  */

	use "$codeddata/intermediate_data/RANK.dta", clear
	mmerge hhid using "$codeddata/intermediate_data/rthead"
	drop ar00 EDUCATIONRTHEAD hhcov5
	drop if _m==2
	replace RTHEAD = 0 if RTHEAD==.
	label var RTHEAD "Dummy variable for RT Head"
	tempfile c1
	save `c1', replace

	use "$codeddata/intermediate_data/rthead", clear
	keep hhid RTHEAD
	rename hhid hhid_who_rank
	rename RTHEAD RTHEAD_who_rank
	mmerge hhid_who_rank using `c1'
	drop _m
	replace RTHEAD_who_rank = 0 if RTHEAD_who_rank==.
	label var RTHEAD_who_rank "Dummy variable for RT Head who do the rank"
	tempfile c2
	save `c2', replace

	// INCLUDING RTHEAD
	
	use `c2', clear

	collapse (mean) mean_rank_RTA = rank, by(hhid)
	label var mean_rank_RTA "mean rank from all community (including RT HEAD)"

	gen hhea = substr(hhid,1,3)
	sort hhea mean_rank_RTA

	egen nhhrank_RTA=max(mean_rank_RTA)
	label var nhhrank_RTA "number of household in village (including RT HEAD)"

	gen COMMRANK_RTA= mean_rank_RTA/nhhrank_RTA
	label var COMMRANK_RTA "percentile community rank in suseti data"
	tempfile c3
	save `c3', replace

	// EXCLUDING RTHEAD

	use `c2', replace

	drop if RTHEAD_who_rank==1
	drop if RTHEAD==1
	sort hhid_who_rank rank

	bys hhid_who_rank: gen x=_n
	gen rank_RT0 = x
	drop x

	collapse (mean) mean_rank_RT0 = rank_RT0, by(hhid)
	label var mean_rank_RT0 "mean rank from community (excluding RT HEAD)"

	gen hhea = substr(hhid,1,3)
	sort hhea mean_rank_RT0

	egen nhhrank_RT0=max(mean_rank_RT0)
	label var nhhrank_RT0 "number of household in village (excluding RT HEAD)"

	gen COMMRANK_RT0= mean_rank/nhhrank
	label var COMMRANK_RT0 "percentile community rank in suseti data"

	mmerge hhid using `c3', type(1:1)

	drop _m
	tempfile c4
	save `c4', replace

	// RT HEAD ONLY

	use `c2', replace
	keep if RTHEAD_who_rank==1

	gen COMMRANK_RT1= RANK
	label var COMMRANK_RT1 "percentile community rank in suseti data (only RT HEAD)"

	mmerge hhid using `c4', type(1:1)
	drop _m
	tempfile c5
	save `c5', replace

	// MAIN

	use `c2', replace

	drop if RTHEAD_who_rank==1
	sort hhid_who_rank rank

	bys hhid_who_rank: gen x=_n
	gen rank_main = x
	drop x

	collapse (mean) mean_rank_main = rank_main, by(hhid)
	label var mean_rank_main "mean rank from community (excluding RT HEAD)"

	gen hhea = substr(hhid,1,3)
	sort hhea mean_rank_main

	egen nhhrank_main=max(mean_rank_main)
	label var nhhrank_main "number of household in village (excluding RT HEAD who do the ranking)"

	gen COMMRANK_main= mean_rank_main/nhhrank_main
	label var COMMRANK_main "percentile community rank in suseti data"

	mmerge hhid using `c5', type(1:1)

	mmerge hhid using `c', type(1:1) /* It is not perfectly merge because interviewer only interviewed households from fisrt samples. In other words, substitute households were not ranked */
	drop if _m==1
	drop _m

/* Merge with subjective rank */

	mmerge hhid using "$codeddata/intermediate_data/hh_sw.dta", type(1:1)
	drop sw02 sw03
	label var RANK_sw02 "Subjective welfare in 6 level (0=poorest, 1= richest)
	label var RANK_sw03 "Subjective welfare in 5 level (0=poorest, 1= richest)

	rename hhid hhid_suseti

/* Merge with treatment rank */

	mmerge hhid_suseti using "$codeddata/intermediate_data/hhrts.dta", type(1:1)

	replace TREATRANK_2 = TREATRANK if main ==1

	drop hhea
	gen hhea = substr(hhid_suseti,1,3)
	destring hhea, replace
	sort hhea
	drop _m
	tempfile d
	save `d', replace

/* Merge with method */

	use "$codeddata\intermediate_data\coding_treatment.dta", clear
	keep hhea prop  kab kec desa klas kecagroup  maintreatment tokohsubtreatment poor10subtreatment daynightsubtreatment

	gen PMT = (maintreatment==1)
	gen COMMUNITY = (maintreatment==2)
	gen HYBRID = (maintreatment==3)

	rename tokohsubtreatment ELITE 
	replace ELITE = 0 if ELITE==.
	label var ELITE "ELITE treatment"
	
	rename poor10subtreatment POOREST10 
	replace POOREST10 = 0 if POOREST10==.
	label var POOREST10 "10 POOREST treatment"
	
	gen DAYMEETING = 1 if daynightsubtreatment==0
	replace DAYMEETING = 0 if daynightsubtreatment==1
	replace DAYMEETING = 0 if DAYMEETING==.
	drop daynightsubtreatment
	label var DAYMEETING " Day meeting treatment"

	gen ELITEHYBRID = ELITE * HYBRID
	label var ELITEHYBRID "ELITE * HYBDRID"
	mmerge hhea using `d'

	label var ranking_PMT "Household ranking based on PMT"
	label var ranking_meeting "Household ranking based on Community meeting"

	label var quota_final "Village quota"

	drop idrt TREATRANK_2 

	drop _m
	tempfile e
	save `e', replace


/* Create rank correlation treatment, consumption and community All */

	use `e', clear
	drop COMMRANK_RT1 mean_rank_RT0 nhhrank_RT0 COMMRANK_RT0 mean_rank_main nhhrank_main COMMRANK_main

	gen RANKCORRTREATCONSUMPTION_all=.
	gen RANKCORRTREATCOMMUNITY_all=.
	gen RANKCORRTREATSW02_all=.
	gen RANKCORRTREATSW03_all=.

	forvalue i = 1/640 {
		qui spearman TREATRANK CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_all=r(rho) if hhea==`i'
	
		qui spearman TREATRANK COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_all=r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_all=r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_all=r(rho) if hhea==`i'
	}

	keep kecagroup hhea klas maintreatment ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYB RANKCORR*

	bys hhea: keep if _n==1

	tempfile f1
	save `f1', replace
	

/* Create rank correlation treatment, consumption and community for sample without RT head */

	use `e', clear

	drop COMMRANK_RT1 mean_rank_RTA nhhrank_RTA COMMRANK_RTA mean_rank_main nhhrank_main COMMRANK_main

	gen RANKCORRTREATCONSUMPTION_RT0 =.
	gen RANKCORRTREATCOMMUNITY_RT0 =.
	gen RANKCORRTREATSW02_RT0 =.
	gen RANKCORRTREATSW03_RT0 =.

	forvalue i = 1/640 {
		qui spearman TREATRANK CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_RT0 =r(rho) if hhea==`i'
			
		qui spearman TREATRANK COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_RT0 =r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_RT0 =r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_RT0 =r(rho) if hhea==`i'
	}

	keep kecagroup hhea klas maintreatment ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYB RANKCORR* 

	bys hhea: keep if _n==1

	tempfile f2
	save `f2', replace

/* Create rank correlation treatment, consumption and community for sample only RT head */

	use `e', clear
	drop mean_rank_RTA nhhrank_RTA COMMRANK_RTA mean_rank_RT0 nhhrank_RT0 COMMRANK_RT0 mean_rank_main nhhrank_main COMMRANK_main


	gen RANKCORRTREATCONSUMPTION_RT1 =.
	gen RANKCORRTREATCOMMUNITY_RT1 =.
	gen RANKCORRTREATSW02_RT1 =.
	gen RANKCORRTREATSW03_RT1 =.

	forvalue i = 1/640 {
		qui spearman TREATRANK CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_RT1 =r(rho) if hhea==`i'
	
		qui spearman TREATRANK COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_RT1 =r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_RT1 =r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_RT1 =r(rho) if hhea==`i'
	}

	keep kecagroup hhea klas maintreatment ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYB RANKCORR*

	bys hhea: keep if _n==1

	tempfile f3
	save `f3', replace

/* Create rank correlation treatment, consumption and community for main sample */

	use `e', clear
	drop mean_rank_RTA nhhrank_RTA COMMRANK_RTA mean_rank_RT0 nhhrank_RT0 COMMRANK_RT0 COMMRANK_RT1


	gen RANKCORRTREATCONSUMPTION_main =.
	gen RANKCORRTREATCOMMUNITY_main =.
	gen RANKCORRTREATSW02_main =.
	gen RANKCORRTREATSW03_main =.

	forvalue i = 1/640 {
		qui spearman TREATRANK CONSRANK if hhea==`i'
		qui replace RANKCORRTREATCONSUMPTION_main =r(rho) if hhea==`i'
	
		qui spearman TREATRANK COMMRANK if hhea==`i'
		qui replace RANKCORRTREATCOMMUNITY_main =r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw02 if hhea==`i'
		qui replace RANKCORRTREATSW02_main =r(rho) if hhea==`i'

		qui spearman TREATRANK RANK_sw03 if hhea==`i'
		qui replace RANKCORRTREATSW03_main =r(rho) if hhea==`i'
	}

	keep kecagroup hhea klas maintreatment ELITE POOREST10 COMMUNITY HYBRID DAYMEETING ELITEHYB RANKCORR*

	bys hhea: keep if _n==1
	
	mmerge hhea using `f1', type(1:1)
	mmerge hhea using `f2', type(1:1)
	mmerge hhea using `f3', type(1:1)
	
/* merge with variables in randomization data */

	mmerge hhea using "$codeddata\randomizationdata.dta", type(1:1)
	
	label var PMT 				"PMT treatment"
	label var COMMUNITY			"Community treatment"
	label var HYBRID			"Hybrid treatment"


	compress
	sort hhea

	save "$codeddata/rankcorrelation.dta", replace

log close
