/* Create satisfaction variable from Mitra samya data and RT head data  */
/* Last Modified 20 April 2009 */

clear
set more off
set mem 256m

version 10

capture log close
log using "$output\Coding_Files_output\satisfaction_rthead.log",replace

// Fund disbursement data

	use "$codeddata\intermediate_data\fd_a.dta", clear
	mmerge hhea using "$codeddata\intermediate_data\fd_b.dta", type(1:1)
	mmerge hhea using "$codeddata\intermediate_data\c_data.dta", type(1:1)

	recode a_q2 (95=.)

// Complain data

	mmerge hhea using "$codeddata\intermediate_data\complain.dta", type(1:1)
	replace ncomplain = 0 if ncomplain==.
	drop _m

// Merge with prob HH attend from Meeting data
	mmerge hhea using "$codeddata\intermediate_data\f2_data.dta", type(1:1)
	tempfile a
	save `a', replace

	use "$codeddata/intermediate_data/f1_hhattend.dta", clear
	gen x =1
	collapse (sum) total_hhattend = hh_attend total = x, by(hhea)
	label var total_hhattend "number of HH attend the meeting"
	
	gen prob_total_HHattend = total_hhattend/total
	label var prob_total_HHattend "Probability household attend community meeting (Meeting data)"
	
	mmerge hhea using `a', type(1:1)
	tempfile b
	save `b', replace

// Merge with prob HH attend from HH data

	use "$codeddata\intermediate_data\coding_endline.dta", clear
	keep hhea hhid e_q5a
	gen x= 1
	collapse (sum) total=x nattend=e_q5a, by(hhea)
	gen probattend = nattend/total
	label var probattend "probability households attend the meeting (HH data)"
	mmerge hhea using `b', type(1:1)
	destring hhea, replace
	
// Treatment data

	mmerge hhea using "$codeddata/intermediate_data/coding_treatment.dta", type(1:1)
	drop kab - numvillages pmtsurprisesubtreatment pmtpost2listssubtreatment village_order facilitator_code meeting_order o fund_order numhhsls_dec quotaslsb1dec share inc_pop quota quota_final quota_2
	
	drop _m

	gen PMT = (maintreatment==1)
	gen COMMUNITY = (maintreatment==2)
	gen HYBRID = (maintreatment==3)

	rename tokohsubtreatment ELITE 
	replace ELITE = 0 if ELITE==.
	label var ELITE "ELITE treatment"
	
	rename poor10subtreatment POOREST10 
	replace POOREST10 = 0 if POOREST10==.
	label var POOREST10 "10 POOREST treatment"
	
	gen DAYMEETING = 1 if daynightsubtreatment==0
	replace DAYMEETING = 0 if daynightsubtreatment==1
	replace DAYMEETING = 0 if DAYMEETING==.
	drop daynightsubtreatment
	label var DAYMEETING " Day meeting treatment"

	gen ELITEHYBRID = ELITE * HYBRID
	label var ELITEHYBRID "ELITE * HYBDRID"

	tempfile a
	save `a', replace

/* merge with variables in randomization data */

	use "$codeddata\randomizationdata.dta", clear
	mmerge hhea using `a'
	keep if _m==3
	drop _m

	label var ncomplain_receivedbyRT "Number of complain received by RT Head"
	label var D_add "Dummy variable for adding households from the list"
	label var D_subtract "Dummy variable for subtracting households from the list"
	label var ndontagree "number of households that do not agree with the list of beneficiaries"
	
	replace ndontagree=0 if ndontagree==.
	recode c_q11a (4=1) (3=2) (2=3) (1=4)
	label drop c_q11a
	label define c_q11a 1 "1. very disatisfied" 2 "2. a little bit disatisfied" 3 "3. satisfied" 4 "4. very satisfied"
	label val c_q11a c_q11a
	
	compress
	sort hhid

	save "$codeddata/satisfaction_rthead.dta", replace


log close

