/*Appendix Table 2 */
/* last modified Feb 01, 2010 */

clear
clear matrix
set more off
set mem 256m




capture log close
log using "$output\Tables\Appendix\Table2\Table2.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"



*****************************
* Table 3 -- Check on Randomization
******************************

use "$codeddata\randomizationdata.dta", clear

local numvar = 1

//Generate variables for stacked regression for 10 outcomes

expand 10

//Labeling each observation so that each is used only for one category in the stacked regression

bys hhea: egen subsample = seq()

sort hhea
gen indic_1 = 0
replace indic_1 = 1 if subsample ==1
gen outcome = avg_CONSUMPTION if indic_1 == 1

gen indic_2 = 0
replace indic_2 = 1 if subsample ==2
replace outcome = avg_YREDUCATIONHHHEAD if indic_2 == 1

gen indic_3 = 0
replace indic_3 = 1 if subsample ==3
replace outcome = avg_PMTSCORE if indic_3 == 1

gen indic_4 = 0
replace indic_4 = 1 if subsample ==4
replace outcome =  SHAREAGRICULTURALHH if indic_4 == 1

gen indic_5 = 0
replace indic_5 = 1 if subsample ==5
replace outcome = YREDUCATIONRTHEAD if indic_5 == 1

gen indic_6 = 0
replace indic_6 = 1 if subsample ==6
replace outcome = LOGNUMBERHH if indic_6 == 1

gen indic_7 = 0
replace indic_7 = 1 if subsample ==7
replace outcome = DISTANCEKEC if indic_7 == 1

gen indic_8 = 0
replace indic_8 = 1 if subsample ==8
replace outcome = LOGVILLAGESIZE if indic_8 == 1

gen indic_9 = 0
replace indic_9 = 1 if subsample ==9
replace outcome = RELIGIOUSBUILDINGPERHH if indic_9 == 1

gen indic_10 = 0
replace indic_10 = 1 if subsample ==10
replace outcome = PRIMARYSCHOOLPERHH if indic_10 == 1

foreach X of var indic_1 indic_2 indic_3 indic_4 indic_5 indic_6 indic_7 indic_8 indic_9 indic_10 {
		gen `X'_COMMUNITY = `X'*COMMUNITY
		gen `X'_HYBRID = `X'*HYBRID		
}

local COMMUNITY "indic_1_COMMUNITY indic_2_COMMUNITY indic_3_COMMUNITY indic_4_COMMUNITY indic_5_COMMUNITY indic_6_COMMUNITY indic_7_COMMUNITY indic_8_COMMUNITY indic_9_COMMUNITY indic_10_COMMUNITY"
local HYBRID "indic_1_HYBRID indic_2_HYBRID indic_3_HYBRID indic_4_HYBRID indic_5_HYBRID indic_6_HYBRID indic_7_HYBRID indic_8_HYBRID indic_9_HYBRID indic_10_HYBRID"

g str40 varname = ""

replace varname = "Per capita expenditure" in 2
replace varname = "Years of Education of Household head" in 4
replace varname = "PMT score (calculated from baseline survey)" in 6
replace varname = "% of households that are agricultural" in 8
replace varname = "Years of Education of RT head" in 10
replace varname = "Log number of households" in 12
replace varname = "Distance to kecamatan in km" in 14
replace varname = "Log size of villages in hectares" in 16
replace varname = "Religious building per household" in 18
replace varname = "Primary school per household" in 20
replace varname = "Join test" in 23

// Calculate mean

g PMTmean_1 = .
g commmean_1 = .
g hybridmean_1 = .

g PMTmean = ""
g commmean = ""
g hybridmean = ""

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	summ outcome if indic_`i' == 1 & maintreatment == 1
	replace PMTmean_1 = r(mean) in `numvar' 
	replace PMTmean_1 = r(sd) in `numvarse' 
	
	summ outcome if indic_`i' == 1 & maintreatment == 2
	replace commmean_1 = r(mean) in `numvar' 
	replace commmean_1 = r(sd) in `numvarse'

	summ outcome if indic_`i' == 1 & maintreatment == 3
	replace hybridmean_1 = r(mean) in `numvar' 
	replace hybridmean_1 = r(sd) in `numvarse'
	
	local numvar = `numvar' + 1	

}

local numvar = 1
tostring PMTmean_1, replace format(%10.3f) force
tostring commmean_1, replace format(%10.3f) force
tostring hybridmean_1, replace format(%10.3f) force

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	replace PMTmean = PMTmean_1 in `numvar' 
	replace PMTmean = "(" + PMTmean_1 + ")" in `numvarse' 
	
	replace commmean = commmean_1 in `numvar' 
	replace commmean = "(" + commmean_1 + ")" in `numvarse' 

	replace hybridmean = hybridmean_1 in `numvar' 
	replace hybridmean = "(" + hybridmean_1 + ")" in `numvarse' 
	
	local numvar = `numvar' + 1	

}

// Run stacked regressions

** No Fixed Effect

local numvar = 1

g commnofe_1 = .
g hybridnofe_1 = .
g commhybridnofe_1 = .

g pvalcommnofe = .
g pvalhybridnofe = .
g pvalcommhybridnofe = .

g commnofe = ""
g hybridnofe = ""
g commhybridnofe = ""

reg outcome indic_? `COMMUNITY' `HYBRID', cluster(hhea)

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	test indic_`i'_COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[indic_`i'_COMMUNITY] in `numvar'
	replace commnofe_1 = _se[indic_`i'_COMMUNITY] in `numvarse'

	test indic_`i'_HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[indic_`i'_HYBRID] in `numvar'
	replace hybridnofe_1 = _se[indic_`i'_HYBRID] in `numvarse'

	local numvar = `numvar' + 1	

}

local numvar = `numvar' + 2	

testparm indic*_COMMUNITY
replace commnofe_1 = r(p) in `numvar'

testparm indic*_HYBRID
replace hybridnofe_1 = r(p) in `numvar'

testparm indic*_COMMUNITY *_HYBRID

local numvar = 1

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1

	lincom indic_`i'_HYBRID - indic_`i'_COM
	replace commhybridnofe_1 = r(estimate) in `numvar'
	replace commhybridnofe_1 = r(se) in `numvarse'

	test indic_`i'_HYBRID - indic_`i'_COM = 0
	replace pvalcommhybridnofe = r(p) in `numvar'
	
	local numvar = `numvar' + 1	
}

local numvar = `numvar' + 2	

test indic_1_HYBRID - indic_1_COM = 0
test indic_2_HYBRID - indic_2_COM = 0, accum
test indic_3_HYBRID - indic_3_COM = 0, accum
test indic_4_HYBRID - indic_4_COM = 0, accum
test indic_5_HYBRID - indic_5_COM = 0, accum
test indic_6_HYBRID - indic_6_COM = 0, accum
test indic_7_HYBRID - indic_7_COM = 0, accum
test indic_8_HYBRID - indic_8_COM = 0, accum
test indic_9_HYBRID - indic_9_COM = 0, accum
test indic_10_HYBRID - indic_10_COM = 0, accum

replace commhybridnofe_1 = r(p) in `numvar'

local numvar = 1
tostring commnofe_1, replace format(%10.4f) force
tostring hybridnofe_1, replace format(%10.4f) force
tostring commhybridnofe_1, replace format(%10.4f) force

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	replace commnofe = commnofe_1 if pvalcommnofe >=0.1 in `numvar' 
	replace commnofe = commnofe_1 + "*" if (pvalcommnofe >=0.05 & pvalcommnofe <0.1)  in `numvar' 
	replace commnofe = commnofe_1 + "**" if (pvalcommnofe >=0.01 & pvalcommnofe <0.05)  in `numvar' 
	replace commnofe = commnofe_1 + "***" if (pvalcommnofe <0.01)  in `numvar' 

	replace commnofe = "(" + commnofe_1 + ")" in `numvarse' 

	replace hybridnofe = hybridnofe_1 if pvalhybridnofe >=0.1 in `numvar' 
	replace hybridnofe = hybridnofe_1 + "*" if (pvalhybridnofe >=0.05 & pvalhybridnofe <0.1)  in `numvar' 
	replace hybridnofe = hybridnofe_1 + "**" if (pvalhybridnofe >=0.01 & pvalhybridnofe <0.05)  in `numvar' 
	replace hybridnofe = hybridnofe_1 + "***" if (pvalhybridnofe <0.01)  in `numvar' 

	replace hybridnofe = "(" + hybridnofe_1 + ")" in `numvarse' 

	replace commhybridnofe = commhybridnofe_1 if pvalcommhybridnofe >=0.1 in `numvar' 
	replace commhybridnofe = commhybridnofe_1 + "*" if (pvalcommhybridnofe >=0.05 & pvalcommhybridnofe <0.1)  in `numvar' 
	replace commhybridnofe = commhybridnofe_1 + "**" if (pvalcommhybridnofe >=0.01 & pvalcommhybridnofe <0.05)  in `numvar' 
	replace commhybridnofe = commhybridnofe_1 + "***" if (pvalcommhybridnofe <0.01)  in `numvar' 

	replace commhybridnofe = "(" + commhybridnofe_1 + ")" in `numvarse' 
	
	local numvar = `numvar' + 1	
}


local numvar = `numvar' + 2	

replace commnofe = commnofe_1 in `numvar' 
replace hybridnofe = hybridnofe_1 in `numvar' 
replace commhybridnofe = commhybridnofe_1 in `numvar' 

** Fixed Effect

local numvar = 1

g commfe_1 = .
g hybridfe_1 = .
g commhybridfe_1 = .

g pvalcommfe = .
g pvalhybridfe = .
g pvalcommhybridfe = .

g commfe = ""
g hybridfe = ""
g commhybridfe = ""

egen kecagroup_indic = group(kecagroup indic_? indic_??)
areg outcome `COMMUNITY' `HYBRID', absorb(kecagroup_indic) cluster(hhea)

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	test indic_`i'_COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[indic_`i'_COMMUNITY] in `numvar'
	replace commfe_1 = _se[indic_`i'_COMMUNITY] in `numvarse'

	test indic_`i'_HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[indic_`i'_HYBRID] in `numvar'
	replace hybridfe_1 = _se[indic_`i'_HYBRID] in `numvarse'

	local numvar = `numvar' + 1	

}

local numvar = `numvar' + 2	

testparm indic*_COMMUNITY
replace commfe_1 = r(p) in `numvar'

testparm indic*_HYBRID
replace hybridfe_1 = r(p) in `numvar'

testparm indic*_COMMUNITY *_HYBRID

local numvar = 1

forvalues i = 1/10 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1

	lincom indic_`i'_HYBRID - indic_`i'_COM
	replace commhybridfe_1 = r(estimate) in `numvar'
	replace commhybridfe_1 = r(se) in `numvarse'
	
	test indic_`i'_HYBRID - indic_`i'_COM = 0
	replace pvalcommhybridfe = r(p) in `numvar'

	local numvar = `numvar' + 1	
}

local numvar = `numvar' + 2	

test indic_1_HYBRID - indic_1_COM = 0
test indic_2_HYBRID - indic_2_COM = 0, accum
test indic_3_HYBRID - indic_3_COM = 0, accum
test indic_4_HYBRID - indic_4_COM = 0, accum
test indic_5_HYBRID - indic_5_COM = 0, accum
test indic_6_HYBRID - indic_6_COM = 0, accum
test indic_7_HYBRID - indic_7_COM = 0, accum
test indic_8_HYBRID - indic_8_COM = 0, accum
test indic_9_HYBRID - indic_9_COM = 0, accum
test indic_10_HYBRID - indic_10_COM = 0, accum

replace commhybridfe_1 = r(p) in `numvar'

local numvar = 1
tostring commfe_1 hybridfe_1 commhybridfe_1, replace format(%10.4f) force

forvalues i = 1/10 {

	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	replace commfe = commfe_1 if pvalcommfe >=0.1 in `numvar' 
	replace commfe = commfe_1 + "*" if (pvalcommfe >=0.05 & pvalcommfe <0.1)  in `numvar' 
	replace commfe = commfe_1 + "**" if (pvalcommfe >=0.01 & pvalcommfe <0.05)  in `numvar' 
	replace commfe = commfe_1 + "***" if (pvalcommfe <0.01)  in `numvar' 

	replace commfe = "(" + commfe_1 + ")" in `numvarse' 

	replace hybridfe = hybridfe_1 if pvalhybridfe >=0.1 in `numvar' 
	replace hybridfe = hybridfe_1 + "*" if (pvalhybridfe >=0.05 & pvalhybridfe <0.1)  in `numvar' 
	replace hybridfe = hybridfe_1 + "**" if (pvalhybridfe >=0.01 & pvalhybridfe <0.05)  in `numvar' 
	replace hybridfe = hybridfe_1 + "***" if (pvalhybridfe <0.01)  in `numvar' 

	replace hybridfe = "(" + hybridfe_1 + ")" in `numvarse' 

	replace commhybridfe = commhybridfe_1 if pvalcommhybridfe >=0.1 in `numvar' 
	replace commhybridfe = commhybridfe_1 + "*" if (pvalcommhybridfe >=0.05 & pvalcommhybridfe <0.1)  in `numvar' 
	replace commhybridfe = commhybridfe_1 + "**" if (pvalcommhybridfe >=0.01 & pvalcommhybridfe <0.05)  in `numvar' 
	replace commhybridfe = commhybridfe_1 + "***" if (pvalcommhybridfe <0.01)  in `numvar' 

	replace commhybridfe = "(" + commhybridfe_1 + ")" in `numvarse' 
	
	local numvar = `numvar' + 1	

}


local numvar = `numvar' + 2	

replace commfe = commfe_1 in `numvar' 
replace hybridfe = hybridfe_1 in `numvar' 
replace commhybridfe = commhybridfe_1 in `numvar' 

keep varname PMTmean commmean hybridmean commnofe hybridnofe commhybridnofe commfe hybridfe commhybridfe
keep in 1/23

replace PMTmean = "" if PMTmean == "."
replace commmean = "" if commmean == "."
replace hybridmean = "" if hybridmean == "."

foreach X in fe nofe {
	replace comm`X' = "" if comm`X' == "."
	replace hybrid`X' = "" if hybrid`X' == "."
	replace commhybrid`X' = "" if commhybrid`X' == "."

}

save "$output\Tables\Appendix\Table2\AppdxT2_Randomizationcheck.dta", replace

outsheet using "$output\Tables\Appendix\Table2\AppdxTable2" in 1/`numvar', replace

log close
