/* This creates the Appendix Table 4  - timelapsed */
/* Last Modified 01 Feb 2010 */

clear matrix
clear

set more off
set mem 256m

capture log close
log using "$output\Tables\Appendix\Table3\Table3_timelapsed.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

*******************************************************************************************************
* Haterogeneity in "Time Lapsed" Table 4-- Results of Different Targeting Methods on Mistargeting Rate
********************************************************************************************************

****************************************************************************************
** Calculate the time lapsed between the baseline survey and the community meeting / PMT
****************************************************************************************


**Getting the baseline survey dates
use "$data\baseline\hh_cov.dta", clear

keep hhid hhea hhivwdd1 hhivwdd2 hhivwdd3 hhivwmm1 hhivwmm2 hhivwmm3 hhivwyy1 hhivwyy2 hhivwyy3 hhcov6

**remove the HHs which didn't answer the survey
drop if hhcov6==3

destring hhea, replace
rename hhid hhid_suseti

label var hhivwdd1 "Day of First Visit"
label var hhivwdd2 "Day of Second Visit"
label var hhivwdd3 "Day of Third Visit"
label var hhivwmm1 "Month of First Visit"
label var hhivwmm2 "Month of Second Visit"
label var hhivwmm3 "Month of Third Visit"
label var hhivwyy1 "Year of First Visit"
label var hhivwyy2 "Year of Second Visit"
label var hhivwyy3 "Year of Third Visit"

gen survey_day=.
gen survey_month=.
gen survey_year=.

/* taking the date of the survey as the first day of the visits
replace survey_day=hhivwdd1
replace survey_month=hhivwmm1
replace survey_year=hhivwyy1
*/

//taking the date of the survey as the last days of the visit, if there were multiple visits to the same HH
//generally, if more than 1 visit, they happened on consecutive days
forval i = 1/3 {
          replace survey_day=hhivwdd`i' if hhivwdd`i'!=.
	    replace survey_month=hhivwmm`i' if hhivwmm`i'!=.
          replace survey_year=hhivwyy`i' if hhivwyy`i'!=.
		   }


gen survey_date = mdy(survey_month, survey_day, survey_year)
format survey_date %td

tempfile a
save `a'


** Getting community meeting dates
use "$data\mitra\f2_data.dta", clear
keep wilker pw b_q1dd b_q1mm b_q1yy

rename wilker hhea
destring hhea, replace

*keep only first meeting
keep if pw==1

rename b_q1dd meeting_day
label var meeting_day "Day of Community Meeting"

rename b_q1mm meeting_month
label var meeting_month "Month of Community Meeting"

rename b_q1yy meeting_year
label var meeting_year "Year of Community Meeting"

//some dates are in Dec 2009, when it seems from the rest of the data that they should be Dec 2008
replace meeting_year=2008 if meeting_year==2009 & meeting_month==12

gen meeting_date= mdy(meeting_month, meeting_day, meeting_year)
format meeting_date %td

tempfile b
save `b'


**Getting PMT dates
use "$data\bps\pmt_p2k08.dta", clear
keep wilcah hhid tgl1 bln1 thn1

rename wilcah hhea

rename tgl1 PMT_day
label var PMT_day "Day of PMT"

rename bln1 PMT_month
label var PMT_month "Month of PMT"

rename thn1 PMT_year
label var PMT_year "Year of PMT"

gen PMT_date= mdy(PMT_month, PMT_day, PMT_year)
format PMT_date %td

sort hhea hhid
tempfile c
save `c'


use "$codeddata\mistargeting_CORRECTED.dta", clear

mmerge hhea using `b'
drop _m

mmerge hhid_suseti using `a'
drop if _m==2
drop _m

*since hhid is under a slightly different format in c, we need to create a hhid indicator in the master dataset
gen hhid=substr(hhid_suseti,4,3)
destring hhid, replace
sort hhea hhid

destring hhid_suseti, replace
merge hhea hhid using `c'
drop if _m==2
drop _m

gen targeting_date=.
replace targeting_date=meeting_date if meeting_date!=.
replace targeting_date=PMT_date if PMT_date!=.
format targeting_date %td


gen timelapsed=targeting_date - survey_date
//set any non-sensical reports to missing and set all timelasped>100 to zero, the dates do not seem correct: for example, meeting in Dec 2009?
replace timelapsed=. if timelapsed<=0 | timelapsed>100

gen COMMUNITY_timelapsed=COMMUNITY*timelapsed
gen HYBRID_timelapsed=HYBRID*timelapsed


*********************
**FIXED EFFECTS
*********************

areg MISTARGETDUMMY COMMUNITY HYBRID timelapsed COMMUNITY_timelapsed HYBRID_timelapsed, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Appendix\Table3\Table3_timelapsed", excel paren(se) bdec(3) replace

foreach X of var MISTARGETNONPOORDUMMY MISTARGETPOORDUMMY MISTARGETRICHDUMMY  MISTARGETMIDDLEDUMMY MISTARGETNEARPOORDUMMY  MISTARGETVERYPOORDUMMY {
areg `X' COMMUNITY HYBRID timelapsed COMMUNITY_timelapsed HYBRID_timelapsed, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Appendix\Table3\Table3_timelapsed", excel paren(se) bdec(3) append

}

areg CONSUMPTION COMMUNITY HYBRID timelapsed COMMUNITY_timelapsed HYBRID_timelapsed if RTS==1, absorb(kecagroup) cluster(hhea) 
outreg2 using "$output\Tables\Appendix\Table3\Table3_timelapsed", excel paren(se) bdec(3) append


sum MISTARGETDUMMY MISTARGETNONPOORDUMMY MISTARGETPOORDUMMY MISTARGETRICHDUMMY  MISTARGETMIDDLEDUMMY MISTARGETNEARPOORDUMMY  MISTARGETVERYPOORDUMMY if maintreatment==1

log close
