/* This file creates Table 6 in Appendix */
/* Last Modified 01 Feb 10 */

clear matrix
clear

set more off
set mem 256m


capture log close
log using "$output\Tables\Appendix\Table6\Table6_Connectedness.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

***************************************************************************
*Generated 'connected' dummy, HHRELATED, veryconnected and the interactions
***************************************************************************

use "$codeddata\intermediate_data\hh_cr01.dta", clear

bys hhid:gen HHRELATED0 =_N
label var HHRELATED0 "Number of households in RT you are related to"
keep hhid HHRELATED0
bys hhid: keep if _n==1
gen connected=1
label var connected "Have a family connection with at least one other HH in RT"

tempfile a
save `a'

use "$codeddata\mistargeting_CORRECTED.dta", clear

mmerge hhid_suseti using `a', umatch(hhid)

replace HHRELATED0=0 if _m==1
replace connected=0 if _m==1

bys hhea: gen nhhvillage =_N 
gen HHRELATED = HHRELATED0/nhhvillage

gen C_connected = connected*COMMUNITY 
gen H_connected = connected*HYBRID 
gen E_connected = connected*ELITE
gen E_H_connected = connected*HYBRID*ELITE

gen C_HHRELATED = HHRELATED*COMMUNITY 
gen H_HHRELATED = HHRELATED*HYBRID 
gen E_HHRELATED = HHRELATED*ELITE
gen E_H_HHRELATED = HHRELATED*HYBRID*ELITE

gen C_social_elite_connectedness = connected * C_elite_connectedness
gen H_social_elite_connectedness = connected * H_elite_connectedness
gen E_social_elite_connectedness = connected * E_elite_connectedness
gen E_H_social_elite_connectedness = connected * E_H_elite_connectedness

gen C_HHRELATED_elite_connectedness = HHRELATED * C_elite_connectedness
gen H_HHRELATED_elite_connectedness = HHRELATED * H_elite_connectedness
gen E_HHRELATED_elite_connectedness = HHRELATED * E_elite_connectedness
gen E_H_HHR_elite_connectedness = HHRELATED * E_H_elite_connectedness

************
*PANEL A
************

********************************************************************
*Using the connected dummy
********************************************************************
**MISTARGET
areg MISTARGETDUMMY COMMUNITY HYBRID ELITE connected elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_connected H_connected E_connected, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Appendix\Table6\Table6", excel paren(se) bdec(3) replace

areg MISTARGETDUMMY COMMUNITY HYBRID ELITE ELITEHYBRID connected elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness  E_H_elite_connectedness C_connected H_connected E_connected E_H_connected, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Appendix\Table6\Table6", excel paren(se) bdec(3) append

**BENEFICARY
areg RTS COMMUNITY HYBRID ELITE connected elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_connected H_connected E_connected, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Appendix\Table6\Table6", excel paren(se) bdec(3) append

areg RTS COMMUNITY HYBRID ELITE ELITEHYBRID connected elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness E_H_elite_connectedness C_connected H_connected E_connected E_H_connected, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Appendix\Table6\Table6", excel paren(se) bdec(3) append

**POOR VS NON-POOR (RTS)
areg  MISTARGETPOORDUMMY COMMUNITY HYBRID ELITE connected elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_connected H_connected E_connected , absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6", excel paren(se) bdec(3) append

areg MISTARGETNONPOORDUMMY COMMUNITY HYBRID ELITE connected elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_connected H_connected E_connected, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6", excel paren(se) bdec(3) append


**********
*PANEL B
**********

*************************************************************************************
*Using HHRELATED = no. of HH you are related to relative to the no. of HH in village
*************************************************************************************
**MISTARGET
areg MISTARGETDUMMY COMMUNITY HYBRID ELITE HHRELATED elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_HHRELATED H_HHRELATED E_HHRELATED, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6B_Connectedness", excel paren(se) bdec(3) replace

areg MISTARGETDUMMY COMMUNITY HYBRID ELITE ELITEHYBRID HHRELATED elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness  E_H_elite_connectedness C_HHRELATED H_HHRELATED E_HHRELATED E_H_HHRELATED, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6B_Connectedness", excel paren(se) bdec(3) append

**BENEFICARY
areg RTS COMMUNITY HYBRID ELITE HHRELATED elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_HHRELATED H_HHRELATED E_HHRELATED, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6B_Connectedness", excel paren(se) bdec(3) append

areg RTS COMMUNITY HYBRID ELITE ELITEHYBRID HHRELATED elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness E_H_elite_connectedness C_HHRELATED H_HHRELATED E_HHRELATED E_H_HHRELATED, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6B_Connectedness", excel paren(se) bdec(3) append

**POOR VS NON-POOR (RTS)
areg  MISTARGETPOORDUMMY COMMUNITY HYBRID ELITE HHRELATED elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_HHRELATED H_HHRELATED E_HHRELATED, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6B_Connectedness", excel paren(se) bdec(3) append

areg MISTARGETNONPOORDUMMY COMMUNITY HYBRID ELITE HHRELATED elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness C_HHRELATED H_HHRELATED E_HHRELATED, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Appendix\Table6\Table6B_Connectedness", excel paren(se) bdec(3) append


log close

