/* This file makes Table 12 in the targeting analysis */
/* Last Modified 01 Feb 2010 */


clear
clear matrix
set more off
set mem 256m

*cd "F:\Targeting_new"

capture log close
log using "$output\Tables\Table12\Table12.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"


**GENERATING DEMOGRAPHIC VARIABLES

use "$codeddata\coding_suseti_pmt.dta" , clear
gen hh_eleorless=(hheduc1==1 | hheduc2==1)

keep hhsize age14 hhid hh_eleorless
sort hhid
save "$codeddata\Temp_Files\temp_demo.dta", replace
clear

****GENERATING DISABILTY DTAA

use "$data\baseline\hh_ar2.dta", clear
gen disabled=0
replace disabled=1 if ar06!="W"

sort hhid
collapse (max) disabled, by(hhid)
rename hhid hhid_suseti
sort hhid_suseti
save "$codeddata\intermediate_data\disabled", replace

***GENERATING ELITE CONNECTED VARIABLE
use "$codeddata\mistargeting_CORRECTED.dta" , clear
keep hhid_suseti elite_connectedness 
sort hhid_suseti
save "$codeddata\Temp_Files\tempelite", replace

***GENERATING TABACCO/ALCOHOL CONSUMPTION SHARES
use "$data\baseline\hh_ks1.dta", clear
mmerge hhid using "$data\baseline\hh_ks2.dta", type(1:1)
drop _m
/* recode missing values, don't know and not applicable to missing */
foreach var of varlist ks01_1a - ks01_14b{
	gen missing_`var' = (`var'>=999990)
	replace `var'=. if `var'>=999990
}

foreach var of varlist  ks03_15a - ks04_20{
	gen missing_`var' = (`var'>=99999990)
	replace `var'=. if `var'>=99999990
}

egen missing = rsum( missing_ks01_1a- missing_ks04_20 )
egen wfood = rsum(ks01_1a - ks01_14b)
label var wfood "The value of food consumed last week"
gen mfood = wfood * 30/7
label var mfood "Monthly food consumtion"
egen missing_notobalc = rsum( missing_ks01_1a - missing_ks01_13b missing_ks03_15a- missing_ks04_20 )
egen wfood_notobalc=rsum(ks01_1a - ks01_13b)
label var wfood_notobalc "The value of food consumed last week without alcohol and tobacco"
gen mfood_notobalc = wfood_notobalc * 30/7

egen x = rsum(ks03_15a ks03_15c ks03_15d ks03_16a ks03_16d ks03_16e)
egen y = rsum(ks04_15b ks04_16b ks04_16c ks04_17 ks04_18 ks04_19a ks04_19b ks04_19c ks04_19d ks04_20)
gen mnonfood = x + (y/12)
drop x y
label var mnonfood "Monthly non food consumtion"

gen hhconsumption = mfood + mnonfood
replace hhconsumption=. if missing>=4
label var hhconsumption "Monthly household consumtion"
gen hhconsumption_notobalc = mfood_notobalc + mnonfood
replace hhconsumption_notobalc=. if missing_notobalc>=4
label var hhconsumption_notobalc "Monthly household consumtion without tobacco and alcohol"
drop missing*

gen tobacco_alcohol = ((ks01_14a + ks01_14b + ks01_13c)*30/7)/1000
replace tobacco_alcohol=0 if tobacco_alcohol==.
gen share_tobalc=tobacco_alcohol*1000/hhconsumption
//remove outliers
replace tobacco_alcohol=. if share_tobalc>.40
replace hhconsumption_notobalc=. if tobacco_alcohol==.

//create tocalc_dummy: >= the village median
gen hhea=substr(hhid,1,3)
bys hhea: egen tobalc_med = median(tobacco_alcohol)
gen tobalc_dummy= (tobacco_alcohol>=tobalc_med)
replace tobalc_dummy=. if tobacco_alcohol==.

// alternative tobacco dummy >= the overall median
egen tobalc_med2 = median(tobacco_alcohol)
gen tobalc_dummy2= (tobacco_alcohol>=tobalc_med2)
replace tobalc_dummy2=. if tobacco_alcohol==.

mmerge hhid using "$data\baseline\hh_ar1.dta", type(1:1)
drop _m

label var hhsize "Household size"
gen LOGHHSIZE = log(hhsize)
label var LOGHHSIZE "Log household size"

gen CONSUMPTION = (hhconsumption/hhsize)/1000
label var CONSUMPTION "Per capita consumption (in thousand Rp)"
gen CONS_notobalc = (hhconsumption_notobalc/hhsize)/1000
label var CONS_notobalc  "Per capita consumption without tobacco ans alcohol (in thousand Rp)"

gen LOGCONSUMPTION = log(CONSUMPTION)
label var LOGCONSUMPTION "Log per capita consumption"
gen LOGCONS_notobalc = log(CONS_notobalc)
label var LOGCONS_notobalc "Log per capita consumption without tobacco and alcohol"

keep  hhid hhsize tobacco_alcohol share_tobalc tobalc_dummy tobalc_dummy2 hhconsumption hhconsumption_notobalc LOGCONSUMPTION LOGCONS_notobalc
tempfile a11
save `a11'

use "$data\baseline\hh_ar2.dta", clear

gen hhmaleadult_ind=(ar03==1 & ar04a>=18)
bys hhid: egen hhmaleadults = total (hhmaleadult_ind)
collapse hhmaleadults, by (hhid)

mmerge hhid using `a11'

gen tobalc_peradultmale=tobacco_alcohol/hhmaleadults
replace tobalc_peradultmale=0 if hhmaleadults==0
replace tobalc_peradultmale=0 if tobacco_alcohol==0

tempfile a1
save `a1'


***GENERATING SAVINGS VARIABLE
use "$data\baseline\hh_sv.dta", clear
egen total_savings = rsum(sv04a sv04b)
replace total_savings = total_savings/1000
gen share_banksavings = (sv04a/1000)/total_savings
//if savings exist in other form than bank account, set share_banksavings to 0
replace share_banksavings =0 if sv04=="B" & sv01==1
replace total_savings = 0 if sv01!=1
replace total_savings = 0 if total_savings==.
replace share_banksavings=0 if share_banksavings==.

keep hhid total_savings share_banksavings
tempfile a2
save `a2'

***GENERATE DEBT TO INCOME RATIO
use "$data\baseline\hh_bh1.dta", clear
gen loan = (bh04num>=1 & bh04num<=4)
label var loan "Do you have loans?"
label define loan 1 "1.yes" 0 "0. No"
label val loan loan 
keep hhid loan
tempfile a31
save `a31'

use "$data\baseline\hh_bh2.dta", clear
keep hhid bh04col bh05
reshape wide bh05, i(hhid) j(bh04col)

egen outstandingloan = rsum( bh051 bh052 bh053 bh054)
replace outstandingloan=0 if outstandingloan==.
label var outstandingloan "Total outstanding loans"
keep hhid outstandingloan

mmerge hhid using `a31'
replace outstandingloan = 0 if _m==2
drop _m

mmerge hhid using `a1'
drop _m

gen share_debt = outstandingloan / hhconsumption
replace share_debt=0 if outstandingloan==0
replace share_debt=0 if share_debt==.
keep hhid share_debt
tempfile a3
save `a3'

***GENERATING CONNECTEDNESS
use "$data\baseline\hh_cr01.dta", clear
gen hhea = substr(hhid,1,3)
gen family=1
bys hhid:gen HHRELATED =_N
label var HHRELATED "Number of households in RT you are related to"
keep hhid HHRELATED
bys hhid: keep if _n==1
mmerge hhid using "$data\baseline\hh_ar1.dta"
gen hhea = substr(hhid,1,3)
replace HHRELATED = 0 if _m==2
gen connected=(HHRELATED!=0)
bys hhea: egen medHHREL= median(HHRELATED)
gen veryconnected = (HHRELATED>=medHHREL)
keep hhid hhea HHRELATED connected veryconnected
tempfile a4
save `a4'

***GENERATING NUMBER OF FAMILY MEMBERS OUTSIDE VILLAGE AND TRANSFERS
use "$data\baseline\hh_tf1.dta", clear
keep hhid tf01 tf02num tf10 tf11num
gen fam_outside = tf02num
label var fam_outside "Number of family members outside the village"
replace fam_outside=0 if tf01==3 //tf01 is dummy for having family outside village
keep hhid fam_outside tf10 tf01
tempfile a51
save `a51'

use "$data\baseline\hh_tf2.dta", clear
keep hhid tf02line tf08 tf09
reshape wide tf08 tf09, i(hhid) j(tf02line)
egen transfer_outside1 = rsum(tf091 tf092 tf093 tf094 tf095 tf096 tf097)
//set to 0 if they answered that they didn't receive money from any family member outside
replace transfer_outside1=0 if tf081!=1 & tf082!=1 & tf083!=1 & tf084!=1 & tf085!=1 & tf086!=1 & tf087!=1
//set to missing if they answered that they received money from a family member outside
replace transfer_outside1=. if transfer_outside1==. & (tf081==1 | tf082==1 | tf083==1 | tf084==1 | tf085==1 | tf086==1 | tf087==1)
keep hhid transfer_outside1
tempfile a52
save `a52'

use "$data\baseline\hh_tf3.dta", clear
keep hhid tf11line tf15 tf17
replace tf15=. if tf15>5
gen tf17v = tf17 if tf15==1 | tf15==2 //transfer from in same RT
gen tf17o = tf17 if tf15>2 & tf15!=.  //transfer from outside RT
drop tf17
reshape wide tf15 tf17v tf17o, i(hhid) j(tf11line)
egen transfer_vill = rsum(tf17v1 tf17v2 tf17v3 tf17v4 tf17v5 tf17v6)
egen transfer_outside2 = rsum(tf17o1 tf17o2 tf17o3 tf17o4 tf17o5 tf17o6)

keep hhid transfer_vill transfer_outside2
mmerge hhid using `a52'
drop _m
egen transfer_outside = rsum(transfer_outside1 transfer_outside2)

keep hhid transfer_vill transfer_outside
mmerge hhid using `a51'
replace transfer_outside=0 if tf01==3 & tf10==3
replace transfer_outside=transfer_outside/1000
label var transfer_outside "Transfer from relatives who live outside the RT in thousands"
replace transfer_vill=0 if tf10==3
replace transfer_vill=0 if transfer_vill==.
replace transfer_outside=0 if transfer_outside==.
replace transfer_vill=transfer_vill/1000
label var transfer_vill "Transfer from relatives who live inside the RT in thousands"
drop _m tf01 tf10

tempfile a5
save `a5'

***GENERATING PARTICIPATION IN RELIGIOUS GROUPS
use "$data\baseline\hh_pm1.dta", clear
gen relig_participate = (pm01b==1)
label var relig_participate "dummy for participation in religious groups" 
keep hhid relig_participate
tempfile a61
save `a61'

use "$data\baseline\hh_pm2.dta", clear
keep hhid pm04 pm05 pm06
keep if pm04=="B"
gen rhht = pm05 * pm06
bys hhid: gen x=_n
tostring x, replace
gen pm04x = pm04 + x
drop x pm05 pm06 pm04
reshape wide rhht, i(hhid) j(pm04x) string
egen relig_persontimes = rsum(rhhtB1 rhhtB2 rhhtB3 rhhtB4 rhhtB5 rhhtB6 rhhtB7 rhhtB8 rhhtB9 rhhtB10)
keep hhid relig_persontimes
mmerge hhid using `a61'
drop _m
replace relig_persontimes=0 if relig_participate==0
replace relig_persontimes=0 if relig_persontimes==.
label var relig_persontimes "Number of HH members X times participated in religious groups"

tempfile a6
save `a6'

***GENERATING PARTICIPATION IN COMMUNITY PROJECTS
use "$data\baseline\hh_pm1.dta", clear

//dummy for participation in community projects
gen projects_participation = (pm10==1)
label var projects_participation "dummy for participation in community projects"
//dummy for participation in community projects through manpower
gen projects_work = (pm12x==1)
label var projects_work "dummy for participation in community projects through manpower"

gen projects_money = (pm14==1)

egen projects_amountgiven = rsum(pm15a pm15b)
replace projects_amountgiven=projects_amountgiven/1000
replace projects_amountgiven=0 if projects_amountgiven==.
gen projects_personhours = pm12 * pm13dd * pm13hr
replace projects_personhours=0 if projects_personhours==.
label var projects_personhours "Number of HH members X days X hours a day worked on the community project"

keep hhid projects*
tempfile a7
save `a7'

***Adding the PMT score
use "$codeddata\coding_suseti_pmt.dta", clear
keep hhid pcexppred PMTSCORE rank_pmt nhhrank_pmt PMTRANK

tempfile a8
save `a8'

mmerge hhid using `a7'
mmerge hhid using `a6'
mmerge hhid using `a5'
mmerge hhid using `a4'
mmerge hhid using `a3'
mmerge hhid using `a2'
mmerge hhid using `a1'

tempfile a
save `a'


***********************************************************************************************************************
*****MISTARGETING DATA
use "$codeddata\analysis3", clear

**MERGE IN ELITE CONNECTEDNESS
drop elite_connectedness 
sort hhid_suseti
merge hhid_suseti using "$codeddata\Temp_Files\tempelite"
drop _merge

****MERGE IN DISABLED DATA
sort hhid_suseti
merge hhid_suseti using "$codeddata\intermediate_data\disabled"
drop _merge

**MERGE IN RANK DATA
gen hhid=hhid_suseti
sort hhid
merge hhid using "$codeddata/finalranks"

**MERGE IN DEMOGRAPHICS
drop _merge
sort hhid
merge hhid using "$codeddata\Temp_Files\temp_demo"
keep if _merge==3

**MERGING IN THE VARIABLES SAVED IN TEMPFILE a
mmerge hhid using `a'

drop _m

replace ELITE=0 if ELITE==.

**CREATE NEW SHOCK VARIABLES
gen death=(ge01a==1 | ge01b==1)
gen sick=(ge01c==1 | ge01d==1)
gen loss=(ge01e==1 | ge01f==1 | ge01g==1 | ge01h==1 | ge01v==1)
gen MINORITY=(RELIGIOUSMINORITY==1 | ETHICMINORITY==1)

gen HH_deathsick=(ge01a==1 | ge01c==1)
gen mainloss=(ge01e==1 | ge01f==1 | ge01g==1)


**FIXING TREATRANK_1
sort hhea TREATRANK_1
bys hhea: egen rankexp=rank(TREATRANK_1)
bys hhea: egen countrank = count(TREATRANK_1)
gen RANK_exp=(rankexp - 1)/ (countrank-1)

**CODING DEMOGRAPHICS
gen loghhsize=log(hhsize) if hhsize!=.
gen sharekids=age14/hhsize if hhsize!=.

**TOTAL CONSUMPTION
gen TCONSUMPTION=CONSUMPTION*hhsize
gen LOGTCONSUMPTION=log(TCONSUMPTION) if CONSUMPTION!=.

save "$output\Tables\Table12\Table12data.dta", replace

**********************************************************************
**REGRESSIONS
**********************************************************************

*erase "$output\Tables\Table12\Table12.xml"
*erase "$output\Tables\Table12\Table12.txt"

/*
**CONTROL FOR CONSUMPTION
foreach X in PMTSCORE loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol tobalc_peradultmale tobalc_dummy tobalc_dummy2 total_savings share_banksavings share_debt connected fam_outside transfer_vill transfer_outside relig_participate relig_persontimes projects_work projects_money projects_personhours projects_amountgiven {

areg RANK_survey  `X' LOGCONSUMPTION, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12Alt", excel paren(se) bdec(4) append

areg RANK_rthead `X' LOGCONSUMPTION, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12Alt.xml", excel paren(se) bdec(4) append

areg RANK_sw02  `X' LOGCONSUMPTION, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12Alt.xml", excel paren(se) bdec(4) append
  
areg RANK_exp `X' LOGCONSUMPTION if maintreatment==1, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12Alt.xml", excel paren(se) bdec(4) append

areg RANK_exp `X' LOGCONSUMPTION if COMMUNITY==1, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12Alt.xml", excel paren(se) bdec(4) append

areg RANK_exp `X' LOGCONSUMPTION if HYBRID==1, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12Alt.xml", excel paren(se) bdec(4) append

}
*/
**CONTROL FOR ALL with dummies for familiy outside village, religious and community participation
areg RANK_survey LOGCONSUMPTION loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol total_savings share_banksavings share_debt connected fam_outside relig_participate projects_work projects_money, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12", excel paren(se) bdec(3) replace

areg RANK_rthead LOGCONSUMPTION loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol total_savings share_banksavings share_debt connected fam_outside relig_participate projects_work projects_money, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12", excel paren(se) bdec(3) append

areg RANK_sw02 LOGCONSUMPTION loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol total_savings share_banksavings share_debt connected fam_outside relig_participate projects_work projects_money, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12", excel paren(se) bdec(3) append

areg RANK_exp LOGCONSUMPTION loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol total_savings share_banksavings share_debt connected fam_outside relig_participate projects_work projects_money  if maintreatment==1, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12", excel paren(se) bdec(3) append

areg RANK_exp LOGCONSUMPTION loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol total_savings share_banksavings share_debt connected fam_outside relig_participate projects_work projects_money  if COMMUNITY==1, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12", excel paren(se) bdec(3) append

areg RANK_exp LOGCONSUMPTION loghhsize sharekids hh_eleorless elite_connectedness ETHICMINORITY RELIGIOUSMINORITY WIDOW disabled death sick loss tobacco_alcohol total_savings share_banksavings share_debt connected fam_outside relig_participate projects_work projects_money if HYBRID==1, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table12\Table12", excel paren(se) bdec(3) append


log close






