/* This file makes Table 2 */
/* Last Modified 01 Feb 2010 */


clear
clear matrix
set more off
set mem 256m

capture log close
log using "$output\Tables\Table2\Table2.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

******************************
* Table 2 -- Means
******************************

// Randomization data 

	use "$codeddata\randomizationdata.dta", clear

	g str40 varname = ""
	g obs = .
	g mean = .
	g std = .
	g min = .
	g max = .
	local numvar = 1
	replace varname = "Randomization data" in `numvar'

	local numvar = `numvar' + 1

	foreach X of var hhea kecagroup maintreatment avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE PRIMARYSCHOOLPERHH RELIGIOUSBUILDINGPERHH {
	
		 summ `X'
		replace varname = "`X'" in `numvar'
		replace obs = r(N) in `numvar'
		replace mean = r(mean) in `numvar'
		replace std = r(sd) in `numvar'
		replace min = r(min) in `numvar'
		replace max = r(max) in `numvar'
		local numvar = `numvar' + 1
	}
	
	local numvar = `numvar' - 1
	
	keep varname obs mean std min max
	keep in 1/`numvar'
	tempfile t11
	save `t11', replace

// Mistargeting data
		
	use "$codeddata\mistargeting_CORRECTED.dta", clear


	g str40 varname = ""
	g obs = .
	g mean = .
	g std = .
	g min = .
	g max = .
	local numvar = 1

	replace varname = "Household data" in `numvar'

	local numvar = `numvar' + 1
	
	foreach X of var PMT COMMUNITY HYBRID ELITE POOREST10 DAYMEETING ELITEHYBRID RTHEAD CONSUMPTION LOGCONSUMPTION ETHICMINORITY RELIGIOUSMINORITY shock RTS verypoor poor nearpoor middle rich MISTARGETDUMMY- MISTARGETVERYPOORDUMMY E_H_shock-C_elite_connectedness {
	
		 summ `X'
		replace varname = "`X'" in `numvar'
		replace obs = r(N) in `numvar'
		replace mean = r(mean) in `numvar'
		replace std = r(sd) in `numvar'
		replace min = r(min) in `numvar'
		replace max = r(max) in `numvar'
		local numvar = `numvar' + 1
	}
	
	local numvar = `numvar' - 1
	
	keep varname obs mean std min max
	keep in 1/`numvar'
	tempfile t12
	save `t12', replace



// Rank Correlation data
	
	use "$codeddata\rankcorrelation.dta", clear

	g str40 varname = ""
	g obs = .
	g mean = .
	g std = .
	g min = .
	g max = .
	local numvar = 1

	replace varname = "Rank correlation data" in `numvar'

	local numvar = `numvar' + 1

	foreach X of var RANKCORRTREATCONSUMPTION_main  RANKCORRTREATCOMMUNITY_main RANKCORRTREATCOMMUNITY_RT1 RANKCORRTREATSW02_main {
	
		 summ `X'
		replace varname = "`X'" in `numvar'
		replace obs = r(N) in `numvar'
		replace mean = r(mean) in `numvar'
		replace std = r(sd) in `numvar'
		replace min = r(min) in `numvar'
		replace max = r(max) in `numvar'
		local numvar = `numvar' + 1
	}
	
	local numvar = `numvar' - 1
	
	keep varname obs mean std min max
	keep in 1/`numvar'
	tempfile t13
	save `t13', replace

// Community survey
	
	use "$codeddata\satisfaction_community.dta", clear

	g str40 varname = ""
	g obs = .
	g mean = .
	g std = .
	g min = .
	g max = .
	local numvar = 1

	replace varname = "Endline data" in `numvar'

	local numvar = `numvar' + 1

	foreach X of var e_q6 e_q8 e_q14 e_q15num e_q17num {
	
		 summ `X'
		replace varname = "`X'" in `numvar'
		replace obs = r(N) in `numvar'
		replace mean = r(mean) in `numvar'
		replace std = r(sd) in `numvar'
		replace min = r(min) in `numvar'
		replace max = r(max) in `numvar'
		local numvar = `numvar' + 1
	}
	
	local numvar = `numvar' - 1
	
	keep varname obs mean std min max
	keep in 1/`numvar'
	tempfile t14
	save `t14', replace

// Sub village head survey
	
	use "$codeddata\satisfaction_rthead.dta", clear

	g str40 varname = ""
	g obs = .
	g mean = .
	g std = .
	g min = .
	g max = .
	local numvar = 1

	replace varname = "Meeting data" in `numvar'

	local numvar = `numvar' + 1

	foreach X of var c_q3 c_q11a D_add D_subtract ncomplain ndontagree ncomplain_receivedbyRT a_q7 method_meeting sget_money prob_total_HHattend swomen_attend probattend {
	
		 summ `X'
		replace varname = "`X'" in `numvar'
		replace obs = r(N) in `numvar'
		replace mean = r(mean) in `numvar'
		replace std = r(sd) in `numvar'
		replace min = r(min) in `numvar'
		replace max = r(max) in `numvar'
		local numvar = `numvar' + 1
	}
	
	local numvar = `numvar' - 1

	keep varname obs mean std min max
	keep in 1/`numvar'
	tempfile t15
	save `t15', replace

use `t11', clear
append using `t12'
append using `t13'
append using `t14'
append using `t15'

#delimit ;
keep if 
varname=="CONSUMPTION" |
varname=="RTS" |
varname=="MISTARGETDUMMY" |
varname=="MISTARGETNONPOORDUMMY" |
varname=="MISTARGETRICHDUMMY" |
varname=="MISTARGETMIDDLEDUMMY" |
varname=="MISTARGETPOORDUMMY" |
varname=="MISTARGETNEARPOORDUMMY" |
varname=="MISTARGETVERYPOORDUMMY" |
varname=="RANKCORRTREATCONSUMPTION_main" |
varname=="RANKCORRTREATCOMMUNITY_main" |
varname=="RANKCORRTREATCOMMUNITY_RT1" |
varname=="RANKCORRTREATSW02_main";
#delimit cr


save "$output/Tables/Table2/T2_Means.dta", replace

outsheet varname obs mean std min max using "$output/Tables/Table2/T2_Means.out", replace

log close

