/* This file makes Table 3 and Figure 1*/
/* Last Modified 01 Feb 2010 */



clear
clear matrix
set more off
set mem 256m

capture log close
log using "$output\Tables\Table3\Table3.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

************************************************************************
* Table 4 -- Results of Different Targeting Methods on Mistargeting Rate
************************************************************************

use "$codeddata\mistargeting_CORRECTED.dta", clear

**GENERATE INTERACTION OF COMMUNITY AND INCOME STATUS

foreach X of var poor verypoor nearpoor middle rich {
gen COMMUNITY_`X'= COMMUNITY*`X'
gen HYBRID_`X'= HYBRID*`X'
}

**FIXED EFFECTS
areg MISTARGETDUMMY COMMUNITY HYBRID, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table3\Table3", excel paren(se) bdec(3) replace

foreach X of var MISTARGETNONPOORDUMMY MISTARGETPOORDUMMY MISTARGETRICHDUMMY  MISTARGETMIDDLEDUMMY MISTARGETNEARPOORDUMMY  MISTARGETVERYPOORDUMMY {
areg `X' COMMUNITY HYBRID, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table3\Table3", excel paren(se) bdec(3) append

}

areg CONSUMPTION COMMUNITY HYBRID if RTS==1, absorb(kecagroup) cluster(hhea) 
outreg2 using "$output\Tables\Table3\Table3", excel paren(se) bdec(3) append


sum MISTARGETDUMMY MISTARGETNONPOORDUMMY MISTARGETPOORDUMMY MISTARGETRICHDUMMY  MISTARGETMIDDLEDUMMY MISTARGETNEARPOORDUMMY  MISTARGETVERYPOORDUMMY if maintreatment==1


**INTREACTIONS FOR OUR OWN KNOWLEDGE
areg MISTARGETDUMMY COMMUNITY HYBRID COMMUNITY_poor HYBRID_poor poor, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Table3\Table3", excel paren(se) bdec(3) append

areg MISTARGETDUMMY COMMUNITY HYBRID COMMUNITY_nearpoor HYBRID_nearpoor COMMUNITY_verypoor HYBRID_verypoor verypoor nearpoor, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Table3\Table3", excel paren(se) bdec(3) append

areg MISTARGETDUMMY COMMUNITY HYBRID COMMUNITY_middle HYBRID_middle COMMUNITY_nearpoor HYBRID_nearpoor COMMUNITY_verypoor HYBRID_verypoor verypoor nearpoor middle, absorb(kecagroup) cluster(hhea)
*outreg2 using "$output\Tables\Table3\Table3", excel paren(se) bdec(3) append

// PDF Benefeciaries
 graph twoway (kdensity LOGCONSUMPTION if RTS==1 & main==1, lpattern(solid) color(green) lwidth(thick)) (kdensity LOGCONSUMPTION if RTS==1 & main==2, lpattern(dash) color(blue) lwidth(thick)) (kdensity LOGCONSUMPTION if RTS==1 & main==3, lpattern(dot) color(red) lwidth(thick)), title("Beneficiaries") xtitle("Log Consumption") xlabel(4(1)10) ytitle("") ylabel(0(0.2)1) legend(label(1 "PMT") label(2 "COMMUNITY") label(3 "HYBRID") row(1) size(small) width(120))saving("$output\Figures\Figure 1\graph_rts_pdf_bene",replace) xline(5.129 5.823)

// PDF Non Benefeciaries
graph twoway (kdensity LOGCONSUMPTION if RTS==0 & main==1, lpattern(solid) color(green) lwidth(thick)) (kdensity LOGCONSUMPTION if RTS==0 & main==2, lpattern(dash) color(blue) lwidth(thick)) (kdensity LOGCONSUMPTION if RTS==0 & main==3, lpattern(dot) color(red) lwidth(thick)), title("Non Beneficiaries") xtitle("Log Consumption") xlabel(4(1)10) ytitle("") ylabel(0(0.2)1) legend(label(1 "PMT") label(2 "COMMUNITY") label(3 "HYBRID") row(1) size(small) width(120)) saving("$output\Figures\Figure 1\graph_rts_pdf_nonbene",replace) xline(5.129 5.823)

graph combine "$output\Figures\Figure 1\graph_rts_pdf_bene.gph" "$output\Figures\Figure 1\graph_rts_pdf_nonbene.gph", saving("$output\Figures\Figure 1\graph_rts_pdfbene",replace) xsize(7) ysize(4)

log close
