/* This file adds URBAN dummy, INEQUALITY and GENERAL CONNECTED variables to the regressions in Table 4 */
/* Last Modified 01 Feb 2010 */


clear
clear matrix
set more off
set mem 256m

capture log close
log using "$output\Tables\Table4\Table4_Heterogeneity.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

*******************************************************************************************************
* Haterogeneity all variable Table 4 update-- Results of Different Targeting Methods on Mistargeting Rate
********************************************************************************************************

use "$codeddata\intermediate_data\coding_treatment.dta", clear
keep hhea klas 

gen urban_dummy=.
replace urban_dummy=1 if klas==1   //Urban
replace urban_dummy=0 if klas==2   //Rural

tempfile e1
save `e1', replace

use "$codeddata\mistargeting_CORRECTED.dta", clear

mmerge hhea using `e1'
drop _m

gen COMMUNITY_URBAN = COMMUNITY*urban_dummy
gen HYBRID_URBAN = HYBRID*urban_dummy

tempfile temp1
save `temp1'

use "$codeddata\intermediate_data\consumption.dta", clear
keep hhea hhid CONSUMPTION

mmerge hhid using "$codeddata\intermediate_data\rthead.dta"
drop _m

destring hhea, replace
drop if RTHEAD==1
bysort hhea: egen cons_rank=rank(CONSUMPTION), field

drop if cons_rank==8 | cons_rank==1
collapse (max) CONSUMPTION2=CONSUMPTION (min) CONSUMPTION7=CONSUMPTION, by(hhea)
gen inequality=log(CONSUMPTION2/CONSUMPTION7)
egen medinequal = median (inequality)

sort hhea
tempfile e3
save `e3', replace


use "$codeddata\mistargeting_CORRECTED.dta", clear

mmerge hhea using `e3' 
drop _m

gen COMMUNITY_inequality=COMMUNITY*inequality
gen HYBRID_inequality=HYBRID*inequality

gen highINEQUALdummy = (inequality>=medinequal)
gen COMMUNITY_highINEQUALdummy=COMMUNITY*highINEQUALdummy
gen HYBRID_highINEQUALdummy=HYBRID*highINEQUALdummy

tempfile temp2
save `temp2'

use "$codeddata\intermediate_data\hh_cr01.dta", clear

bys hhid:gen HHRELATED =_N
label var HHRELATED "Number of households in RT you are related to"
keep hhid HHRELATED
bys hhid: keep if _n==1
gen connected=1
label var connected "Have a family connection with at least one other HH in RT"

tempfile a
save `a'

use "$codeddata\mistargeting_CORRECTED.dta", clear
mmerge hhid_suseti using `a', umatch(hhid)
replace HHRELATED=0 if _m==1
replace connected=0 if _m==1
bys hhea: gen nhhvillage =_N 
gen share_related = HHRELATED/nhhvillage
egen general_connectedness = mean (share_related), by(hhea)
gen COMMUNITY_connectedness = COMMUNITY * general_connectedness
gen HYBRID_connectedness = HYBRID * general_connectedness
egen medianconnectedness = median (general_connectedness)
gen connectedness_dummy = (general_connectedness>= medianconnectedness)
gen COMMUNITY_connectedness_dummy = COMMUNITY * connectedness_dummy
gen HYBRID_connectedness_dummy = HYBRID * connectedness_dummy

tempfile temp3
save `temp3'

mmerge hhid_suseti using `temp1'
mmerge hhid_suseti using `temp2'


*****************************************************************************
*Fixed effects with dummy versions of all variables
******************************************************************************
areg MISTARGETDUMMY COMMUNITY HYBRID urban_dummy highINEQUALdummy connectedness_dummy COMMUNITY_URBAN HYBRID_URBAN COMMUNITY_highINEQUALdummy HYBRID_highINEQUALdummy COMMUNITY_connectedness_dummy HYBRID_connectedness_dummy, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table4\Table4_Heterogeneity", excel paren(se) bdec(3) replace

foreach X of var MISTARGETNONPOORDUMMY MISTARGETPOORDUMMY MISTARGETRICHDUMMY  MISTARGETMIDDLEDUMMY MISTARGETNEARPOORDUMMY  MISTARGETVERYPOORDUMMY {
areg `X' COMMUNITY HYBRID urban_dummy highINEQUALdummy connectedness_dummy COMMUNITY_URBAN HYBRID_URBAN COMMUNITY_highINEQUALdummy HYBRID_highINEQUALdummy COMMUNITY_connectedness_dummy HYBRID_connectedness_dummy, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table4\Table4_Heterogeneity", excel paren(se) bdec(3) append
}

areg CONSUMPTION COMMUNITY HYBRID urban_dummy highINEQUALdummy connectedness_dummy COMMUNITY_URBAN HYBRID_URBAN COMMUNITY_highINEQUALdummy HYBRID_highINEQUALdummy COMMUNITY_connectedness_dummy HYBRID_connectedness_dummy if RTS==1, absorb(kecagroup) cluster(hhea) 
outreg2 using "$output\Tables\Table4\Table4_Heterogeneity", excel paren(se) bdec(3) append


sum MISTARGETDUMMY MISTARGETNONPOORDUMMY MISTARGETPOORDUMMY MISTARGETRICHDUMMY  MISTARGETMIDDLEDUMMY MISTARGETNEARPOORDUMMY  MISTARGETVERYPOORDUMMY if maintreatment==1


log close
