/* This file makes Table 6 - Satisfaction - in the targeting analysis */
/* Last Modified 01 Feb 10 */


clear
clear matrix
set more off
set mem 256m

capture log close
log using "$output\Tables\Table6\Table6.log",replace


******************************
* Table 6. Satisfaction
******************************

use "$codeddata\satisfaction_community.dta", clear

cap tab kecagroup, gen(kecagroup_)

g str40 varname = ""

replace varname = "Panel A. Community survey" in 2
replace varname = "Is the method applied to determine the targeted households appropriate?" in 3
replace varname = "Are you satisfied with P2K08 activities in this RT in general?" in 6
replace varname = "Is there any poor HH which are not included in the list?" in 9
replace varname = "Number of HH that should be added from list" in 12
replace varname = "Number of HH that should be subtracted from list" in 15

g pmt_1 = .
g pmt = ""

foreach X in fe fec nofe {

	g comm`X'_1 = .
	g hybrid`X'_1 = .

	g comm`X' = ""
	g hybrid`X' = ""
	
	g pvalcomm`X' = .
	g pvalhybrid`X' = .
	g numobs`X' = .
}


local numvar = 2

foreach X of var e_q6 e_q8 {
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
		
	 summ `X' if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg `X' COMMUNITY HYBRID kecagroup_*
	if `numvar' == 3 {
	outreg2 using "$output\Tables\Table6\Table6_PanelA", excel paren(se) bdec(3) replace
	 	**outreg using "output/Table6/Table6", 3aster coefastr se replace title("Table 3: Mistargeting") ctitle("`X'") adds("Control mean",`controlmean') adec(3)
	 	}
	 	else {
	outreg2 using "$output\Tables\Table6\Table6_PanelA", excel paren(se) bdec(3) append
*	 	outreg using "output/Table6/Table6", 3aster coefastr se append ctitle("`X'") adds("Control mean",`controlmean') adec(3)
	}
	
	 test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'


	/* fixed effect with control */
	
	 oprobit `X' COMMUNITY HYBRID kecagroup_* `extvar'
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 oprobit `X' COMMUNITY HYBRID 
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2
	
}

	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
		
	 summ e_q14 if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg e_q14 COMMUNITY HYBRID kecagroup_*, cluster(hhea)
		outreg2 using "$output\Tables\Table6\Table6_PanelA", excel paren(se) bdec(3) append	
**	outreg using "output/Table6/Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
		 test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 probit e_q14 COMMUNITY HYBRID kecagroup_* `extvar', cluster(hhea)
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 probit e_q14 COMMUNITY HYBRID, cluster(hhea)
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2

foreach X of var e_q15num e_q17num {
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	
	 summ `X' if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg `X' COMMUNITY HYBRID kecagroup_*, cluster(hhea)
	outreg2 using "$output\Tables\Table6\Table6_PanelA", excel paren(se) bdec(3) append
** 	outreg using "$output/Table6/Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
	 	test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 reg `X' COMMUNITY HYBRID kecagroup_* `extvar', cluster(hhea)
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 reg `X' COMMUNITY HYBRID, cluster(hhea)
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2
	
}

keep varname pmt* comm* pval* hybrid* numobs*
keep in 1/`numvar'
tempfile T91
save `T91', replace

	// Joint test
	
	use "$codeddata\satisfaction_community.dta", clear	

	g pmt_1 = .
	g pmt = ""
	
	foreach X in fe fec nofe {
	
		g comm`X'_1 = .
		g hybrid`X'_1 = .
	
		g comm`X' = ""
		g hybrid`X' = ""
	}
	
	local numvar = 1

	//Generate variables for stacked regression for 5 outcomes
	
	expand 5
	
	//Labeling each observation so that each is used only for one category in the stacked regression
	
	bys hhid: egen subhousehold = seq()
	
	sort hhid
	gen indic_1 = 0
	replace indic_1 = 1 if subhousehold ==1
	gen outcome = e_q6 if indic_1 == 1
	
	gen indic_2 = 0
	replace indic_2 = 1 if subhousehold ==2
	replace outcome = e_q8 if indic_2 == 1
	
	gen indic_3 = 0
	replace indic_3 = 1 if subhousehold ==3
	replace outcome = e_q14 if indic_3 == 1
	
	gen indic_4 = 0
	replace indic_4 = 1 if subhousehold ==4
	replace outcome = e_q15num if indic_4 == 1
	
	gen indic_5 = 0
	replace indic_5 = 1 if subhousehold ==5
	replace outcome = e_q17num if indic_5 == 1
	
	foreach X of var indic_1 indic_2 indic_3 indic_4 indic_5 {
			gen `X'_COMMUNITY = `X'*COMMUNITY
			gen `X'_HYBRID = `X'*HYBRID	
	}
	  
	local COMMUNITY "indic_1_COMMUNITY indic_2_COMMUNITY indic_3_COMMUNITY indic_4_COMMUNITY indic_5_COMMUNITY"
	local HYBRID "indic_1_HYBRID indic_2_HYBRID indic_3_HYBRID indic_4_HYBRID indic_5_HYBRID"
	
		/* Fixed Effect */
		
		areg outcome indic_? `COMMUNITY' `HYBRID', absorb(kecagroup) cluster(hhea)
		
		testparm indic*_COMMUNITY
		replace commfe_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridfe_1 = r(p) in `numvar'

		/* Fixed Effect with control */
				
		areg outcome indic_? `COMMUNITY' `HYBRID' `extvar', absorb(kecagroup) cluster(hhea)
		
		testparm indic*_COMMUNITY
		replace commfec_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridfec_1 = r(p) in `numvar'

		
		/* No Fixed Effect */
		
		reg outcome indic_? `COMMUNITY' `HYBRID', cluster(hhea)

		testparm indic*_COMMUNITY
		replace commnofe_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridnofe_1 = r(p) in `numvar'
		
		g str40 varname = ""
		
		replace varname = "Joint Test" in 1
		
keep varname pmt* comm* hybrid*
keep in 1/`numvar'
tempfile T92
save `T92', replace

use `T91', clear
append using `T92'
tempfile T93
save `T93', replace


use "$codeddata\satisfaction_rthead.dta", clear

cap tab kecagroup, gen(kecagroup_)

g pmt_1 = .
g pmt = ""

g str40 varname = ""

replace varname = "Panel B:  Subvillage Head Survey" in 2
replace varname = "Is the method applied to determine the targeted households appropriate?" in 3
replace varname = "Are the people satisfied with P2K08 activities in this RT" in 6
replace varname = "Is there any HH that should be added from list?" in 9
replace varname = "Is there any HH that should be subtracted from list?" in 12

foreach X in fe fec nofe {

	g comm`X'_1 = .
	g hybrid`X'_1 = .

	g comm`X' = ""
	g hybrid`X' = ""
	
	g pvalcomm`X' = .
	g pvalhybrid`X' = .
	g numobs`X' = .
}


local numvar = 2

	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	
	 summ c_q3 if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg c_q3 COMMUNITY HYBRID kecagroup_*
		outreg2 using "$output\Tables\Table6\Table6_PanelB", excel paren(se) bdec(3) replace
**	 	outreg using "$output/Table6/Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
	 	test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 probit c_q3 COMMUNITY HYBRID `extvar' kecagroup_*
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 reg c_q3 COMMUNITY HYBRID kecagroup_*
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2

	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
		
	 summ c_q11a if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg c_q11a COMMUNITY HYBRID kecagroup_*
		outreg2 using "$output\Tables\Table6\Table6_PanelB", excel paren(se) bdec(3) append

**	 	outreg using "output/Table6/Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
	 	test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 oprobit c_q11a COMMUNITY HYBRID `extvar' kecagroup_*
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 reg c_q11a COMMUNITY HYBRID kecagroup_*
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2

foreach X of var D_add D_subtract {
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	
	 summ `X' if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg `X' COMMUNITY HYBRID kecagroup_*, cluster(hhea)
		outreg2 using "$output\Tables\Table6\Table6_PanelB", excel paren(se) bdec(3) append
**	 	outreg using "$output/Table6\Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
	 	test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 probit `X' COMMUNITY HYBRID kecagroup_* `extvar', cluster(hhea)
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 probit `X' COMMUNITY HYBRID, cluster(hhea)
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2
	
}

keep varname pmt* comm* pval* hybrid* numobs*
keep in 1/`numvar'
tempfile T94
save `T94', replace

	// Joint test
	
	use "$codeddata\satisfaction_rthead.dta", clear	

	g pmt_1 = .
	g pmt = ""
	
	foreach X in fe fec nofe {
	
		g comm`X'_1 = .
		g hybrid`X'_1 = .
	
		g comm`X' = ""
		g hybrid`X' = ""
	}
	
	local numvar = 1

	//Generate variables for stacked regression for 4 outcomes
	
	expand 4
	
	//Labeling each observation so that each is used only for one category in the stacked regression
	
	bys hhid: egen subhousehold = seq()
	
	sort hhid
	gen indic_1 = 0
	replace indic_1 = 1 if subhousehold ==1
	gen outcome = c_q3 if indic_1 == 1
	
	gen indic_2 = 0
	replace indic_2 = 1 if subhousehold ==2
	replace outcome = c_q11a if indic_2 == 1
	
	gen indic_3 = 0
	replace indic_3 = 1 if subhousehold ==3
	replace outcome = D_add if indic_3 == 1
	
	gen indic_4 = 0
	replace indic_4 = 1 if subhousehold ==4
	replace outcome = D_subtract if indic_4 == 1
	
	foreach X of var indic_1 indic_2 indic_3 indic_4 {
			gen `X'_COMMUNITY = `X'*COMMUNITY
			gen `X'_HYBRID = `X'*HYBRID	
	}
	  
	local COMMUNITY "indic_1_COMMUNITY indic_2_COMMUNITY indic_3_COMMUNITY indic_4_COMMUNITY"
	local HYBRID "indic_1_HYBRID indic_2_HYBRID indic_3_HYBRID indic_4_HYBRID"
	
		/* Fixed Effect */
		
		areg outcome indic_? `COMMUNITY' `HYBRID', absorb(kecagroup) cluster(hhea)
		
		testparm indic*_COMMUNITY
		replace commfe_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridfe_1 = r(p) in `numvar'

		/* Fixed Effect with control */
				
		areg outcome indic_? `COMMUNITY' `HYBRID' `extvar', absorb(kecagroup) cluster(hhea)
		
		testparm indic*_COMMUNITY
		replace commfec_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridfec_1 = r(p) in `numvar'

		
		/* No Fixed Effect */
		
		reg outcome indic_? `COMMUNITY' `HYBRID', cluster(hhea)

		testparm indic*_COMMUNITY
		replace commnofe_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridnofe_1 = r(p) in `numvar'
		
		g str40 varname = ""
		
		replace varname = "Joint Test" in 1

keep varname pmt* comm* hybrid*
keep in 1/`numvar'
tempfile T95
save `T95', replace

use `T94', clear
append using `T95'
tempfile T96
save `T96', replace


use "$codeddata\satisfaction_rthead.dta", clear

cap tab kecagroup, gen(kecagroup_)

g pmt_1 = .
g pmt = ""

g str40 varname = ""

replace varname = "C. Comments" in 2
replace varname = "Number of comments in the comment box" in 3
replace varname = "Number of Complaints in the comment box" in 6
replace varname = "Number of Complaints received by Subvillage Head" in 9
replace varname = "D.  Fund Disbursement" in 11
replace varname = "Did facilitator encounter any difficulty in distributing the fund?" in 12
replace varname = "The fund is distributed in the meeting" in 15
replace varname = "Share household that got the money directly" in 18

foreach X in fe fec nofe {

	g comm`X'_1 = .
	g hybrid`X'_1 = .

	g comm`X' = ""
	g hybrid`X' = ""
	
	g pvalcomm`X' = .
	g pvalhybrid`X' = .
	g numobs`X' = .
}


local numvar = 2
cap erase "$output\Tables\Table6\Table6_PanelC.xml"
cap erase "$output\Tables\Table6\Table6_PanelC.txt"
foreach X of var ncomplain ndontagree ncomplain_receivedbyRT {
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
		
	 summ `X' if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 areg `X' COMMUNITY HYBRID, absorb(kecagroup)
		outreg2 using "$output\Tables\Table6\Table6_PanelC", excel paren(se) bdec(3) append

	 	test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 areg `X' COMMUNITY HYBRID `extvar', absorb(kecagroup)
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 reg `X' COMMUNITY HYBRID
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2
	
}

foreach X of var a_q7 method_meeting {
		
	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
	
	 summ `X' if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 reg `X' COMMUNITY HYBRID kecagroup_*, cluster(hhea)
		outreg2 using "$output\Tables\Table6\Table6_PanelC", excel paren(se) bdec(3) append
**	 	outreg using "$output/Table6/Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
	 	test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 probit `X' COMMUNITY HYBRID kecagroup_* `extvar', cluster(hhea)
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 probit `X' COMMUNITY HYBRID, cluster(hhea)
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2
	
}

	local numvar = `numvar' + 1
	local numvarse = `numvar' + 1
		
	 summ sget_money if maintreatment==1
	replace pmt_1 = r(mean) in `numvar'
	local controlmean = r(mean)
	replace pmt_1 = r(sd) in `numvarse'
	
	/* fixed effect */
	
	 areg sget_money COMMUNITY HYBRID, absorb(kecagroup)
		*outreg2 using "$output\Tables\Table6\Table6", excel paren(se) bdec(3) append
**	 	outreg using "output/Table6/Table6", 3aster coefastr se append  adds("Control mean",`controlmean') adec(3)
	 	
	 test COMMUNITY
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[COMMUNITY] in `numvar'
	replace commfe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfe = r(p) in `numvar'
	replace hybridfe_1 = _b[HYBRID] in `numvar'
	replace hybridfe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfe = e(N) in `numvar'

	/* fixed effect with control */
	
	 areg sget_money COMMUNITY HYBRID `extvar', absorb(kecagroup)
	 test COMMUNITY
	replace pvalcommfec = r(p) in `numvar'
	replace commfec_1 = _b[COMMUNITY] in `numvar'
	replace commfec_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridfec = r(p) in `numvar'
	replace hybridfec_1 = _b[HYBRID] in `numvar'
	replace hybridfec_1 = _se[HYBRID] in `numvarse'
	
	replace numobsfec = e(N) in `numvar'
	
	/* No fixed effect */
	
	 reg sget_money COMMUNITY HYBRID
	 test COMMUNITY
	replace pvalcommnofe = r(p) in `numvar'
	replace commnofe_1 = _b[COMMUNITY] in `numvar'
	replace commnofe_1 = _se[COMMUNITY] in `numvarse'
	 test HYBRID
	replace pvalhybridnofe = r(p) in `numvar'
	replace hybridnofe_1 = _b[HYBRID] in `numvar'
	replace hybridnofe_1 = _se[HYBRID] in `numvarse'
	
	replace numobsnofe = e(N) in `numvar'
	
	local numvar = `numvar' + 2

keep varname pmt* comm* pval* hybrid* numobs*
keep in 1/`numvar'
tempfile T97
save `T97', replace

use `T93', clear
append using `T96'
append using `T97'
tempfile T98
save `T98', replace

// Joint test
	
	use "$codeddata\satisfaction_rthead.dta", clear	

	g pmt_1 = .
	g pmt = ""
	
	foreach X in fe fec nofe {
	
		g comm`X'_1 = .
		g hybrid`X'_1 = .
	
		g comm`X' = ""
		g hybrid`X' = ""
	}
	
	local numvar = 1

	//Generate variables for stacked regression for 5 outcomes
	
	expand 5
	
	//Labeling each observation so that each is used only for one category in the stacked regression
	
	bys hhid: egen subhousehold = seq()
	
	sort hhid
	gen indic_1 = 0
	replace indic_1 = 1 if subhousehold ==1
	gen outcome = ncomplain if indic_1 == 1
	
	gen indic_2 = 0
	replace indic_2 = 1 if subhousehold ==2
	replace outcome = ndontagree if indic_2 == 1
	
	gen indic_3 = 0
	replace indic_3 = 1 if subhousehold ==3
	replace outcome = ncomplain_received if indic_3 == 1
	
	gen indic_4 = 0
	replace indic_4 = 1 if subhousehold ==4
	replace outcome = a_q7 if indic_4 == 1
	
	gen indic_5 = 0
	replace indic_5 = 1 if subhousehold ==5
	replace outcome = method_meeting if indic_5 == 1
	
	*gen indic_6 = 0
	*replace indic_6 = 1 if subhousehold ==6
	*replace outcome = sget_money if indic_6 == 1
	
	foreach X of var indic_1 indic_2 indic_3 indic_4 indic_5 {
			gen `X'_COMMUNITY = `X'*COMMUNITY
			gen `X'_HYBRID = `X'*HYBRID	
	}
	  
	local COMMUNITY "indic_1_COMMUNITY indic_2_COMMUNITY indic_3_COMMUNITY indic_4_COMMUNITY indic_5_COMMUNITY"
	local HYBRID "indic_1_HYBRID indic_2_HYBRID indic_3_HYBRID indic_4_HYBRID indic_5_HYBRID"
	
		/* Fixed Effect */
		
		areg outcome indic_? `COMMUNITY' `HYBRID', absorb(kecagroup) cluster(hhea)
		
		testparm indic*_COMMUNITY
		replace commfe_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridfe_1 = r(p) in `numvar'

		/* Fixed Effect with control */
				
		areg outcome indic_? `COMMUNITY' `HYBRID' `extvar', absorb(kecagroup) cluster(hhea)
		
		testparm indic*_COMMUNITY
		replace commfec_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridfec_1 = r(p) in `numvar'

		
		/* No Fixed Effect */
		
		reg outcome indic_? `COMMUNITY' `HYBRID', cluster(hhea)

		testparm indic*_COMMUNITY
		replace commnofe_1 = r(p) in `numvar'

		testparm indic*_HYBRID
		replace hybridnofe_1 = r(p) in `numvar'
		
		g str40 varname = ""
		
		replace varname = "Joint Test" in 1
		
keep varname pmt* comm* hybrid*
keep in 1/`numvar'
tempfile T99
save `T99', replace

use `T98', clear
append using `T99'


local numvar = 2
tostring *_1, replace format(%10.3f) force
tostring numobs*, replace format(%10.0f) force

forvalues i = 1/17 {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1

	replace pmt = pmt_1 in `numvar' 
	
	replace pmt = "(" + pmt_1 + ")" in `numvarse' 
	
	/* fixed effect */
	replace commfe = commfe_1 if pvalcommfe >=0.1 in `numvar' 
	replace commfe = commfe_1 + "*" if (pvalcommfe >=0.05 & pvalcommfe <0.1)  in `numvar' 
	replace commfe = commfe_1 + "**" if (pvalcommfe >=0.01 & pvalcommfe <0.05)  in `numvar' 
	replace commfe = commfe_1 + "***" if (pvalcommfe <0.01)  in `numvar' 

	replace commfe = "(" + commfe_1 + ")" in `numvarse' 

	replace hybridfe = hybridfe_1 if pvalhybridfe >=0.1 in `numvar' 
	replace hybridfe = hybridfe_1 + "*" if (pvalhybridfe >=0.05 & pvalhybridfe <0.1)  in `numvar' 
	replace hybridfe = hybridfe_1 + "**" if (pvalhybridfe >=0.01 & pvalhybridfe <0.05)  in `numvar' 
	replace hybridfe = hybridfe_1 + "***" if (pvalhybridfe <0.01)  in `numvar' 

	replace hybridfe = "(" + hybridfe_1 + ")" in `numvarse' 

	/* fixed effect with control */
	replace commfec = commfec_1 if pvalcommfec >=0.1 in `numvar' 
	replace commfec = commfec_1 + "*" if (pvalcommfec >=0.05 & pvalcommfec <0.1)  in `numvar' 
	replace commfec = commfec_1 + "**" if (pvalcommfec >=0.01 & pvalcommfec <0.05)  in `numvar' 
	replace commfec = commfec_1 + "***" if (pvalcommfec <0.01)  in `numvar' 

	replace commfec = "(" + commfec_1 + ")" in `numvarse' 

	replace hybridfec = hybridfec_1 if pvalhybridfec >=0.1 in `numvar' 
	replace hybridfec = hybridfec_1 + "*" if (pvalhybridfec >=0.05 & pvalhybridfec <0.1)  in `numvar' 
	replace hybridfec = hybridfec_1 + "**" if (pvalhybridfec >=0.01 & pvalhybridfec <0.05)  in `numvar' 
	replace hybridfec = hybridfec_1 + "***" if (pvalhybridfec <0.01)  in `numvar' 

	replace hybridfec = "(" + hybridfec_1 + ")" in `numvarse' 

	/* No fixed effect */
	replace commnofe = commnofe_1 if pvalcommnofe >=0.1 in `numvar' 
	replace commnofe = commnofe_1 + "*" if (pvalcommnofe >=0.05 & pvalcommnofe <0.1)  in `numvar' 
	replace commnofe = commnofe_1 + "**" if (pvalcommnofe >=0.01 & pvalcommnofe <0.05)  in `numvar' 
	replace commnofe = commnofe_1 + "***" if (pvalcommnofe <0.01)  in `numvar' 

	replace commnofe = "(" + commnofe_1 + ")" in `numvarse' 

	replace hybridnofe = hybridnofe_1 if pvalhybridnofe >=0.1 in `numvar' 
	replace hybridnofe = hybridnofe_1 + "*" if (pvalhybridnofe >=0.05 & pvalhybridnofe <0.1)  in `numvar' 
	replace hybridnofe = hybridnofe_1 + "**" if (pvalhybridnofe >=0.01 & pvalhybridnofe <0.05)  in `numvar' 
	replace hybridnofe = hybridnofe_1 + "***" if (pvalhybridnofe <0.01)  in `numvar' 

	replace hybridnofe = "(" + hybridnofe_1 + ")" in `numvarse' 

	local numvar = `numvar' + 2	
}

keep varname pmt comm* pvalcomm* hybrid* pvalhybrid* numobs*

replace pmt = "" if pmt == "."
replace pmt = "" if pmt == "(.)"

foreach X in fe fec nofe {
	replace comm`X' = "" if comm`X' == "."
	replace comm`X' = "" if comm`X' == "(.)"
	replace hybrid`X' = "" if hybrid`X' == "."
	replace hybrid`X' = "" if hybrid`X' == "(.)"
	replace numobs`X' = "" if numobs`X' == "."

}

preserve
keep varname pmt commnofe hybridnofe numobsnofe
order varname pmt commnofe hybridnofe numobsnofe
save "$output\Tables\Table6\T6_Satisfaction_nofe.dta", replace
outsheet using "$output\Tables\Table6\T6_Satisfaction_nofe", replace
restore

preserve
keep varname pmt commfec hybridfec numobsfec
order varname pmt commfec hybridfec numobsfec
save "$output\Tables\Table6\T6_Satisfaction_fec.dta", replace
outsheet using "$output\Tables\Table6\T6_Satisfaction_fec", replace
restore

keep varname pmt commfe hybridfe numobsfe
order varname pmt commfe hybridfe numobsfe
save "$output\Tables\Table6\T6_Satisfaction_fe.dta", replace
outsheet using "$output\Tables\Table6\T6_Satisfaction_fe", replace

log close
