/* This file makes Table 7 - Elite Treatments- in the targeting analysis */
/* Last Modified 01 Feb 2010 */


clear
clear matrix
set more off
set mem 256m

capture log close
log using "$output\Tables\Table7\Table7.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

*********************************************************8
use "$codeddata/intermediate_data/rthead.dta", clear
keep hhea hhid

gen rtdummy=1

mmerge hhid using "$codeddata/coding_suseti_pmt.dta"

keep hhea hhid hhconsumption hhsize CONSUMPTION LOGCONSUMPTION rtdummy _m

tempfile a
save `a'

drop if _m==2
drop _m
destring hhea, replace

tempfile b
save `b'

use "$codeddata\mistargeting_CORRECTED.dta", clear
mmerge hhid_suseti using `a', umatch(hhid)

gen RTCONS = rtdummy * LOGCONSUMPTION
egen medRTINCOME = median(RTCONS)
egen RTINCOME = total (RTCONS), by(hhea)
gen RTINCOME_dummy = (RTINCOME>=medRTINCOME)

gen COMMUNITY_RTINCOME = COMMUNITY * RTINCOME_dummy
gen HYBRID_RTINCOME = HYBRID * RTINCOME_dummy
gen ELITE_RTINCOME = ELITE * RTINCOME_dummy
gen ELITEHYBRID_RTINCOME = ELITEHYBRID * RTINCOME_dummy
tempfile c
save `c'

******************************
* Table 7. Elite Tratments
******************************

**ATTENDANCE
use "$codeddata\satisfaction_rthead.dta", clear

areg probattend COMMUNITY HYBRID ELITE, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table7\Table7", excel paren(se) bdec(3) replace

clear

**MISTARGET
*use "$codeddata\mistargeting_CORRECTED.dta", clear
use `c', clear
areg MISTARGETDUMMY COMMUNITY HYBRID ELITE, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table7\Table7", excel paren(se) bdec(3) append



******************************************************************
* Are Households Connected to Elites Treated Differently?
******************************************************************

clear
clear matrix
set more off
set mem 256m

version 10

capture log close
log using "$output\Tables\Table7\Table7.log",replace

local extvar "avg_CONSUMPTION avg_EDUCATIONHHHEAD avg_PMTSCORE SHAREAGRICULTURALHH EDUCATIONRTHEAD LOGNUMBERHH DISTANCEKEC LOGVILLAGESIZE RELIGIOUSBUILDINGPERHH PRIMARYSCHOOLPERHH"

*********************************************************
use "$codeddata/intermediate_data/rthead.dta", clear
keep hhea hhid

gen rtdummy=1

mmerge hhid using "$codeddata/coding_suseti_pmt.dta"

keep hhea hhid hhconsumption hhsize CONSUMPTION LOGCONSUMPTION rtdummy _m

tempfile a
save `a'

drop if _m==2
drop _m
destring hhea, replace

tempfile b
save `b'

use "$codeddata\mistargeting_CORRECTED.dta", clear
mmerge hhid_suseti using `a', umatch(hhid)

gen RTCONS = rtdummy * LOGCONSUMPTION
egen medRTINCOME = median(RTCONS)
egen RTINCOME = total (RTCONS), by(hhea)
gen RTINCOME_dummy = (RTINCOME>=medRTINCOME)

gen COMMUNITY_RTINCOME = COMMUNITY * RTINCOME_dummy
gen HYBRID_RTINCOME = HYBRID * RTINCOME_dummy
gen ELITE_RTINCOME = ELITE * RTINCOME_dummy
gen ELITEHYBRID_RTINCOME = ELITEHYBRID * RTINCOME_dummy
gen RTI_elite_connectedness = elite_connectedness * RTINCOME_dummy
gen RTI_E_H_elite_connectedness = E_H_elite_connectedness * RTINCOME_dummy
gen RTI_E_elite_connectedness = E_elite_connectedness * RTINCOME_dummy
gen RTI_C_elite_connectedness = C_elite_connectedness * RTINCOME_dummy
gen RTI_H_elite_connectedness = H_elite_connectedness * RTINCOME_dummy


**MISTARGET
areg MISTARGETDUMMY COMMUNITY HYBRID ELITE elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table7\Table7", excel paren(se) bdec(3) append

areg MISTARGETDUMMY COMMUNITY HYBRID ELITE ELITEHYBRID elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness E_H_elite_connectedness, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table7\Table7", excel paren(se) bdec(3) append


**BENEFICARY
areg RTS COMMUNITY HYBRID ELITE elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table7\Table7", excel paren(se) bdec(3) append

areg RTS COMMUNITY HYBRID ELITE ELITEHYBRID elite_connectedness C_elite_connectedness H_elite_connectedness E_elite_connectedness E_H_elite_connectedness, absorb(kecagroup) cluster(hhea)
outreg2 using "$output\Tables\Table7\Table7", excel paren(se) bdec(3) append



log close

