/*******************************/
/*         Written by:         */
/*      Hendro Hendratno       */
/*  World Bank Office Jakarta  */
/*            Aug-2005         */
/*******************************/
program define headcount

        syntax anything(name=pcexp) [if] [aw fw] [,HC(string)] [GEN(string)] [matrix(string)] [by(varlist)] ID(varlist)

        preserve
        
        capture gen `gen'=1
        local fname $S_FN
        
        if _rc==110 {
           di in error "The variable `gen' exist."
          exit
        }

        if "`id'"=="" {
           di in error "Level of Identification variables"
           exit
        }           
        if "`matrix'"!="" & "`hc'" != "" {
           di in error "Can't use both hc and matrix"
           exit
        }

        if "`matrix'"=="" & "`hc'" == "" {
           di in error "use one of hc or matrix"
           exit
        }

        if ("`matrix'"=="" | "`by'" == "") & ("`hc'"=="") {
           di in error "Use both matrix and by option"
           exit
        }
        
        if "`gen'" == "" {
           di in error "What is the dummy poor variable ?"
           exit
        }        
        if "`by'"~="" {
           tempvar grpvar
           egen `grpvar' = group(`by')
           qui su `grpvar'
           local min = r(min)
           local max = r(max)
        }
           
        if `"`weight'"' != "" {
           tempvar w
           qui gen double `w' `exp' `if' `in'
           local wgt `"[`weight'=`w']"'
        }
        else {
           tempvar w
           qui gen double `w' `exp' `if' `in'=1
           local wgt `"[`weight'=1]"'
        }        
        tempfile temp
        
        if "`if'" != "" {
           qui keep `if'
        }
           
        qui keep `pcexp' `w' `by' `grpvar' `hc' `id'
        tempvar rowvar
        
        if "`weight'" == "" {
           qui gen `rowvar' = 1 if `pcexp'!=.
        }
        else {
           qui gen `rowvar' = `w' if `pcexp'!=.
        }   
        
        qui save `temp',replace

        if "`hc'" ~= "" {
           tempfile headcount
           forvalues group = `min'/`max' {
              qui use `temp' if `grpvar'==`group',clear
              tempfile tmpgroup
              global povline 0
              getheadcount `pcexp',hc(`hc') rowvar(`rowvar') gen(`gen') tmpfile(`tmpgroup') id(`id') povline($povline)
              qui use `tmpgroup',clear
              if `group'==1 {
                 sort `id'
                 qui save `headcount',replace
              }
              else {
                 qui append using `headcount'
                 sort `id'
                 qui save `headcount',replace
              }   
           }   
           qui save `headcount',replace
        }   

        restore
        sort `id'

        qui merge `id' using `headcount'
        tokenize `exp'
        qui gen newwgt = `2'
        qui gen pce = `pcexp'
        qui replace newwgt = tmpwgt if tmpwgt!=.
                       
        qui replace `gen'  = 0 if `gen'==. & `pcexp'!=.
        qui replace pce = povline-1 if (povline==`pcexp') & `gen'==1
                
        drop tmpwgt _merge

        if "`by'"~="" {
           tempvar grpvar
           egen `grpvar' = group(`by')
           qui su `grpvar'
           local min = r(min)
           local max = r(max)
        }

        forvalues group = `min'/`max' {
           qui su povline if `grpvar' == `group'
           qui replace povline = r(mean) if `grpvar' == `group'
        }   
        qui compress
        sort `id'
end
        
program define getheadcount,rclass

        syntax anything(name=pcexp) [if] [,HC(string)] [gen(string)] rowvar(varname) tmpfile(string) id(varlist) povline(string)

        qui if ("`if'"~="") keep `if'
        qui count `if'
        if r(N) == 0 {
           exit
        }   
        
        sort `pcexp'        
        
        tempvar CUSUM TOTSUM PCTNSUM VMAX
        * Create Total Weighted for denominator
        qui gen `CUSUM' = sum(`rowvar')
        qui gen `TOTSUM'= `CUSUM'[_N]
        
        * Create percetile of distribution
        qui gen  `PCTNSUM' = (`CUSUM'/`TOTSUM'[_N])*100
        
        * Calculating the cut of point in the headcount
        qui egen `VMAX' = max(`PCTNSUM') if `PCTNSUM'<=`hc'
        
        qui bys `VMAX' : gen nmax = _N if `VMAX' != .
        
        qui gen `gen' = `PCTNSUM'<=`hc'
        
        sort `pcexp'
        
        /* Keep the Cut of Point of HeadCount+1 and save it into temporary file */ 
        qui su nmax
        local nmax r(max)
        global povline = `pcexp'[`nmax'+1]
        qui keep if _n <=`nmax'+1
        
        qui gen token=99 if _n==`nmax'+1
       
        qui save `tmpfile',replace
        
        local minhc = `PCTNSUM'[`nmax']
        local maxhc = `PCTNSUM'[`nmax'+1]
        local hcbps = `hc'[1]
        local totwgt= `TOTSUM'[1]

        qui keep if _n ==`nmax'+1
        qui expand 2
        
        qui drop token

        local nw1 =   int((`hcbps'-`minhc')/100*`totwgt')
        local nw2 = round((`maxhc'-`hcbps')/100*`totwgt')

        qui gen tmpwgt     = `nw1'
        qui replace tmpwgt = `nw2' in 2
        
        qui replace `gen' = 1 in 1

        * di "`minhc' *** `maxhc' *** `hcbps' *** `nw1' *** `nw2'"

        qui append using `tmpfile'
        qui gen povline = $povline
        qui keep `id' `gen' tmpwgt token povline
        qui drop if token==99
        qui drop token
        qui save `tmpfile',replace
end

   