/* Master do file for "Targeting the Poor: Evidence from a Field Experiment in Indonesia" */

	/* 	Vivi Atalas
		Abhijit Banerjee
		Rema Hanna
		Ben Olken
		Julia Tobias  */
	
/* Last Modified 18 May 2011 */

		/* Notes:
		
		You will need to install the -headcount- command with
		HeadCount.ado (possibly among other commands, though these 
		are available through STATA) for these files to run.  
		It is located in here: "dofiles\adofiles" folder 

		The -fanreg- command is also available in the above folder, 
		as well as here:
		http://emlab.berkeley.edu/users/webfac/emiguel/e270c_s09/ps1.ado.txt
		
		"Table 5 and Figure 2.do" and "Appendix Table 5.do" require Stata 11.
		Creating Figure 2 requires harddrive space between 4 RAM and 20 RAM. */
		
		
		clear matrix
		clear
		set more off
		set mem 256m

		version 10

		capture log close

******************************************************************
/* 1. SET GLOBALS */
******************************************************************
	
		do "C:\Targeting_Indonesia\dofiles\setglobal.do"			/* Sets globals; adjust per location */
	
******************************************************************
/* 2. CODING FILES */
******************************************************************

	/* CLEANING */
													

		do "$dofiles\Coding_files\coding_baseline.do"			/* coding SUSETI data */
						
																/* Create consumption.dta, hhhead.dta, rthead.dta, hhcharacteristic.dta, hh_ar2.dta, 
																hhasset.dta, hh_lk.dta, hh_rank.dta, gendertarget.dta, children.dta, hhshock.dta, indebtness.dta, 
																haji.dta, hh_cr01.dta, nELITE.dta, socialconnection.dta, minority.dta, 
																characteristic_respondent.dta, hhblt.dta */

		do "$dofiles\Coding_files\coding_podes08.do"			/* coding PODES data */
			
																/* Create coding_podes08.dta */

		do "$dofiles\Coding_files\coding_suseti_pmt.do"			/* create pmt result from suseti variables */
			
																/* Create coding_suseti1_pmt.dta */

		do "$dofiles\Coding_files\coding_endline.do"			/* coding SUSETI2 data */
			
																/* Create coding_endline.dta */

		do "$dofiles\Coding_files\coding_bps.do"				/* coding BPS data */
			
																/* Create ud.dta, data_p_rtm.dta, pmt_p2k08.dta, f7b_bps.dta, 
																data_h_rtm.dta, pmt_hybrid.dta, rts_hybrid.dta */

		do "$dofiles\Coding_files\coding_mitra.do"			/* coding Community data */
								
																/* Create f1_hhattend.dta, f2_data.dta, f3_kla.dta, ranking_time.dta, 
																f7b_ranking.dta, RTS_community.dta, f9a.dta, f9b_ub2c.dta */

		do "$dofiles\Coding_files\match_suseti_experiment.do"		/* matching suseti and experiment data */

		

	/* ANALYSIS */

		do "$dofiles\Coding_files\randomizationdata.do"			/* Analysis 0: Test of Balance */
								
																/* Create analysis0.dta */
																/* Cretae analysis0_commhybrid_nofe.xls */


		do "$dofiles\Coding_files\analysis01.do"				/* Analysis 0.1: Who knows what */
								
																/* Create inequality.dta, aggregatevar.dta, analysis01.dta */

		do "$dofiles\Coding_files\analysis0.do"	
		do "$dofiles\Coding_files\analysis1.do"	
		do "$dofiles\Coding_files\analysis2.do"	
		do "$dofiles\Coding_files\analysis3.do"	
		do "$dofiles\Coding_files\analysis8.do"

		do "$dofiles\Coding_files\mistargeting.do"				/* Analysis 1: mistargeting */

		do "$dofiles\Coding_files\rankcorrelation.do"      	   	/* Analysis 2: rank correlation */

		do "$dofiles\Coding_files\satisfaction_community.do"	/* Analysis 4: Buy in variables; data from Endline survey */

		do "$dofiles\Coding_files\satisfaction_rthead.do"		/* Analysis 4: Buy in variables; data from Mitra Samya*/


		do "$dofiles\Coding_Files\aggregatevar_new.do"

		do "$dofiles\Coding_Files\Fix Mistarget.do"

		do "$dofiles\Coding_Files\Creating Rank Data.do"


**************************************************************
/* 3. TABLES AND FIGURES */
**************************************************************

	/* PAPER */
	
		do "$dofiles\Tables_Figures\Table 2"

		do "$dofiles\Tables_Figures\Table 3 and Figure 1"

		do "$dofiles\Tables_Figures\Table 4"

		do "$dofiles\Tables_Figures\Table 5 and Figure 2"

		do "$dofiles\Tables_Figures\Table 6"

		do "$dofiles\Tables_Figures\Table 7"

		do "$dofiles\Tables_Figures\Table 8 and Figure 3"

		do "$dofiles\Tables_Figures\Table 9"

		do "$dofiles\Tables_Figures\Table 10"

		do "$dofiles\Tables_Figures\Table 11"

		do "$dofiles\Tables_Figures\Table 12"
	
	/* APPENDIX */

		do "$dofiles\Tables_Figures\Appendix_Table 2"

		do "$dofiles\Tables_Figures\Appendix_Table 3"

		do "$dofiles\Tables_Figures\Appendix_Table 4"

		do "$dofiles\Tables_Figures\Appendix_Table 5"

		do "$dofiles\Tables_Figures\Appendix_Table 6"

		do "$dofiles\Tables_Figures\Appendix_Table 7"
